# -----------------------------------------------------------------------------
# Project: APC modelling and covariates with application to obesity in England
# Script: HSE_analysis.R
# Date started: 26/03/18
# Last edited: 06/12/18
# Author: Zoe Fannon
# -----------------------------------------------------------------------------
# Estimates APC models. Run following HSE_dataclean.R
# Step 1: small remaining modifications to data, check for perfect separation
# Step 2: Generate descriptive statistics (first tables, then plots)
# Step 3: estimate four models for each sex (BMI, log BMI, log weight, 
#   obesity indicator)
# -----------------------------------------------------------------------------
# INTRO
# -----------------------------------------------------------------------------
#### Setup ####
# Libraries
library(plyr)
library(reshape)
library(readstata13)
library(plotly)
library(xtable)
library(ggplot2)
library(Cairo)
library(tseries)

# Directory
setwd("C:/Users/Zoe/Documents/Economics/DPhil_thesis/C1_BMI_indivWcovariates")
setwd("replication")
# Individual APC functions
source("R_scripts/revised.functions2.R")
source("R_scripts/TS_logit_functions.R")
source("R_scripts/further_functions.R")

# Define directory into which graphs and tables are placed
storage <- "Graphs_tables/"

#### Clean Data: censoring ####
data12 <- read.csv("Data_modified/for_analysis.csv")

## Censor observations where NSSEC3 is NA
# Note this removes all years prior to 2001. 
# Only c. 300 observations dropped after 2001
data13 <- data12[!(is.na(data12$nssec3)), ]

## Drop income variables
data13 <- data13[, !names(data13) %in% c("eqvinc", "Deqvinc", 
                                         "LDeqvinc", "LDeqvinc2")]

## Split into M/F
data13_M <- data13[data13$is.female==0, ]
data13_F <- data13[data13$is.female==1, ]

# MEN
# Drop unnecessary X variable
data14_M <- data13_M[, -1]

# Add cell name
if (!"cell.name" %in% colnames(data14_M)) {
  cell.name <- paste("ik", as.character(data14_M$age), 
                     as.character(data14_M$cohort), sep="_")
  data14_M <- cbind(cell.name, data14_M)
} else {
  warning("Variable cell.name must be unique identifier of age-cohort cells; 
          if preexisting variable cell.name has alternate meaning please rename")
}
# Check for perfect separation
men.cell.name.count <- as.data.frame(with(data14_M,table(cell.name, obese)))
men.cell.name.zeros <- men.cell.name.count[men.cell.name.count$Freq==0, ]
#View(men.cell.name.zeros)

# WOMEN
# Drop unnecessary X variable
data14_F <- data13_F[, -1]

# Add cell name
if (!"cell.name" %in% colnames(data14_F)) {
  cell.name <- paste("ik", as.character(data14_F$age), 
                     as.character(data14_F$cohort), sep="_")
  data14_F <- cbind(cell.name, data14_F)
} else {
  warning("Variable cell.name must be unique identifier of age-cohort cells; 
          if preexisting variable cell.name has alternate meaning please rename")
}
# Check for perfect separation
wom.cell.name.count <- as.data.frame(with(data14_F,table(cell.name, obese)))
wom.cell.name.zeros <- wom.cell.name.count[wom.cell.name.count$Freq==0, ]
#View(wom.cell.name.zeros)

## Select age range due to perfect separation
# There are no observations of non-obese men age 27 in 1982 cohort. Thus need to 
  # censor to begin at age 28. Note this matters for estimation of the logit TS 
  # model only. 
data14_M <- data14_M[data14_M$age>=28, ]
data14_F <- data14_F[data14_F$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data15_M <- data14_M[data14_M$cohort<= (max(data14_M$cohort)-5) &
                       data14_M$cohort>= (min(data14_M$cohort)+5), ]
data15_F <- data14_F[data14_F$cohort<= (max(data14_F$cohort)-5) &
                       data14_F$cohort>= (min(data14_F$cohort)+5), ]

#### Clean data: variable adjustments ####

# switch definition of ever.smoked
truth <- data15_M$ever.smoked - data15_M$now.smoke
data15_M$ever.smoked <- truth

truth <- data15_F$ever.smoked - data15_F$now.smoke
data15_F$ever.smoked <- truth

rm(truth)

# switch reference variable for drink dummies
drink.never <- 1 - data15_M$drink.rare - data15_M$drink.casual - 
  data15_M$drink.freq
data16_M <- cbind(data15_M, drink.never)
data16_M <- data16_M[, !names(data16_M) %in% "drink.casual"]

drink.never <- 1 - data15_F$drink.rare - data15_F$drink.casual - 
  data15_F$drink.freq
data16_F <- cbind(data15_F, drink.never)
data16_F <- data16_F[, !names(data16_F) %in% "drink.casual"]

# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_M <- model.matrix(~nssec3-1,data16_M)
vars.nssec3_M <- vars.nssec3_M[, -4] # set routine/manual as reference group
colnames(vars.nssec3_M) <- gsub(" ", "_", colnames(vars.nssec3_M))
data17_M <- cbind(data16_M, vars.nssec3_M)

vars.nssec3_F <- model.matrix(~nssec3-1,data16_F)
vars.nssec3_F <- vars.nssec3_F[, -4] # set routine/manual as reference group
colnames(vars.nssec3_F) <- gsub(" ", "_", colnames(vars.nssec3_F))
data17_F <- cbind(data16_F, vars.nssec3_F)

# Access labels
list.nssec3 <- colnames(vars.nssec3_M)
ethnicity <- c("black", "asian", "mixeth", "otheth")
education <- c("lessHS", "someHE", "collegegrad")

# Cleanup
rm(cell.name, men.cell.name.count, men.cell.name.zeros, wom.cell.name.zeros,
   wom.cell.name.count, drink.never, vars.nssec3_M, vars.nssec3_F)
rm(data13, data13_M, data13_F, data14_M, data14_F, data15_M, data15_F,
   data16_M, data16_F)

# -----------------------------------------------------------------------------
# DESCRIPTIVES
# -----------------------------------------------------------------------------
#### Table of descriptive statistics ####

# Define internal headers
sidebar <- c("Total sample size", "Continuous variables", NA, "age", "period", 
             "cohort", "BMI", "height (cm)", "weight (kg)", 
             "Categorical variables", "Ethnicity", NA, "NSSEC (3 level)", NA,
             "Education level", NA, "Drinking", NA, "Smoking", NA)

cont.var.heads <- c("min", "mean", "median", "max")

eth.heads <- c("black", "white", "Asian", "mixed", "other (incl. Arab)")

nssec3.heads <- c("Routine/manual", "Intermediate", "Manager/Professional", 
                  "Other")

educ.heads <- c("Below GCSE", "GCSE", "Some 3rd level", "Degree")

drink.heads <- c("Never", "Rare", "Casual", "Frequent")

smoke.heads <- c("Never smoked", "Former smoker", "Current smoker")


## MEN ####

#continuous variables

ds.age_M <- round(c(min(data17_M$age), mean(data17_M$age), 
                    median(data17_M$age), max(data17_M$age)), 0)

ds.period_M <- round(c(min(data17_M$period), mean(data17_M$period), 
                       median(data17_M$period), max(data17_M$period)), 0)

ds.cohort_M <- round(c(min(data17_M$cohort), mean(data17_M$cohort), 
                       median(data17_M$cohort), max(data17_M$cohort)), 0)

ds.bmivalid_M <- round(c(min(data17_M$bmivalid), mean(data17_M$bmivalid), 
                         median(data17_M$bmivalid), max(data17_M$bmivalid)),2)

ds.htvalid_M <- round(c(min(data17_M$htvalid), mean(data17_M$htvalid), 
                        median(data17_M$htvalid), max(data17_M$htvalid)), 2)

ds.wtvalid_M <- round(c(min(data17_M$wtvalid), mean(data17_M$wtvalid), 
                        median(data17_M$wtvalid), max(data17_M$wtvalid)), 2)

ds.cont.vars <- rbind(ds.age_M, ds.period_M, ds.cohort_M, ds.bmivalid_M,
                      ds.htvalid_M, ds.wtvalid_M)

# categorical variables

n.white_M <- nrow(data17_M) - (sum(data17_M$black) + sum(data17_M$asian) +
                                 sum(data17_M$mixeth) + sum(data17_M$otheth))
ds.eth_M <- c(sum(data17_M$black), n.white_M, sum(data17_M$asian), 
              sum(data17_M$mixeth), sum(data17_M$otheth))

n.routine_M <- nrow(data17_M) - (sum(data17_M$nssec3Intermediate_occupations) +
                 sum(data17_M$nssec3Intermediate_occupations) +
                 sum(data17_M$nssec3Managerial_and_professional_occupations) + 
                 sum(data17_M$nssec3Other))
ds.nssec3_M <- c(n.routine_M, sum(data17_M$nssec3Intermediate_occupations),
                 sum(data17_M$nssec3Managerial_and_professional_occupations),
                 sum(data17_M$nssec3Other))

n.HS_M <- nrow(data17_M) - (sum(data17_M$lessHS) + sum(data17_M$someHE) +
                              sum(data17_M$collegegrad))
ds.educ_M <- c(sum(data17_M$lessHS), n.HS_M, sum(data17_M$someHE), 
             sum(data17_M$collegegrad))

n.casual_M <- nrow(data17_M) - (sum(data17_M$drink.freq) + 
                          sum(data17_M$drink.never) + sum(data17_M$drink.rare))
ds.drink_M <- c(sum(data17_M$drink.never), sum(data17_M$drink.rare), 
                n.casual_M, sum(data17_M$drink.freq))

n.never_M <- nrow(data17_M) - (sum(data17_M$now.smoke) + 
                                 sum(data17_M$ever.smoked))
ds.smoke_M <- c(n.never_M, sum(data17_M$ever.smoked), sum(data17_M$now.smoke))

# open the table
tab_M <- matrix(nrow=(1+1+7+1+2*5), ncol=6, data=NA)

tab_M[1:20, 1] <- sidebar

tab_M[1, 2] <- nrow(data17_M)

tab_M[2, 2:5] <- cont.var.heads
tab_M[4:9, 2:5] <- ds.cont.vars

tab_M[11, 2:6] <- eth.heads
tab_M[12, 2:6] <- ds.eth_M

tab_M[13, 2:5] <- nssec3.heads
tab_M[14, 2:5] <- ds.nssec3_M

tab_M[15, 2:5] <- educ.heads
tab_M[16, 2:5] <- ds.educ_M

tab_M[17, 2:5] <- drink.heads
tab_M[18, 2:5] <- ds.drink_M

tab_M[19, 2:4] <- smoke.heads
tab_M[20, 2:4] <- ds.smoke_M

## WOMEN ####

#continuous variables

ds.age_F <- round(c(min(data17_F$age), mean(data17_F$age), 
                    median(data17_F$age), max(data17_F$age)), 0)

ds.period_F <- round(c(min(data17_F$period), mean(data17_F$period), 
                       median(data17_F$period), max(data17_F$period)), 0)

ds.cohort_F <- round(c(min(data17_F$cohort), mean(data17_F$cohort), 
                       median(data17_F$cohort), max(data17_F$cohort)), 0)

ds.bmivalid_F <- round(c(min(data17_F$bmivalid), mean(data17_F$bmivalid), 
                         median(data17_F$bmivalid), max(data17_F$bmivalid)),2)

ds.htvalid_F <- round(c(min(data17_F$htvalid), mean(data17_F$htvalid), 
                        median(data17_F$htvalid), max(data17_F$htvalid)), 2)

ds.wtvalid_F <- round(c(min(data17_F$wtvalid), mean(data17_F$wtvalid), 
                        median(data17_F$wtvalid), max(data17_F$wtvalid)), 2)

ds.cont.vars <- rbind(ds.age_F, ds.period_F, ds.cohort_F, ds.bmivalid_F,
                      ds.htvalid_F, ds.wtvalid_F)

# categorical variables

n.white_F <- nrow(data17_F) - (sum(data17_F$black) + sum(data17_F$asian) +
                                 sum(data17_F$mixeth) + sum(data17_F$otheth))
ds.eth_F <- c(sum(data17_F$black), n.white_F, sum(data17_F$asian), 
              sum(data17_F$mixeth), sum(data17_F$otheth))

n.routine_F <- nrow(data17_F) - (sum(data17_F$nssec3Intermediate_occupations) +
                                   sum(data17_F$nssec3Intermediate_occupations) +
                                   sum(data17_F$nssec3Managerial_and_professional_occupations) + 
                                   sum(data17_F$nssec3Other))
ds.nssec3_F <- c(n.routine_F, sum(data17_F$nssec3Intermediate_occupations),
                 sum(data17_F$nssec3Managerial_and_professional_occupations),
                 sum(data17_F$nssec3Other))

n.HS_F <- nrow(data17_F) - (sum(data17_F$lessHS) + sum(data17_F$someHE) +
                              sum(data17_F$collegegrad))
ds.educ_F <- c(sum(data17_F$lessHS), n.HS_F, sum(data17_F$someHE), 
               sum(data17_F$collegegrad))

n.casual_F <- nrow(data17_F) - (sum(data17_F$drink.freq) + 
                                  sum(data17_F$drink.never) + sum(data17_F$drink.rare))
ds.drink_F <- c(sum(data17_F$drink.never), sum(data17_F$drink.rare), 
                n.casual_F, sum(data17_F$drink.freq))

n.never_F <- nrow(data17_F) - (sum(data17_F$now.smoke) + 
                                 sum(data17_F$ever.smoked))
ds.smoke_F <- c(n.never_F, sum(data17_F$ever.smoked), sum(data17_F$now.smoke))

# open the table
tab_F <- matrix(nrow=(1+1+7+1+2*5), ncol=6, data=NA)

tab_F[1:20, 1] <- sidebar

tab_F[1, 2] <- nrow(data17_F)

tab_F[2, 2:5] <- cont.var.heads
tab_F[4:9, 2:5] <- ds.cont.vars

tab_F[11, 2:6] <- eth.heads
tab_F[12, 2:6] <- ds.eth_F

tab_F[13, 2:5] <- nssec3.heads
tab_F[14, 2:5] <- ds.nssec3_F

tab_F[15, 2:5] <- educ.heads
tab_F[16, 2:5] <- ds.educ_F

tab_F[17, 2:5] <- drink.heads
tab_F[18, 2:5] <- ds.drink_F

tab_F[19, 2:4] <- smoke.heads
tab_F[20, 2:4] <- ds.smoke_F

## Combine tables and print all ####
tab_both <- cbind(tab_M, tab_F[, 2:6])

xtable.tab_M <- xtable(tab_M,
                 align=c("l", "l", rep("r", ncol(tab_M)-1)))
print(xtable.tab_M, file=paste(storage, "tab_M.tex", sep=""),
      floating=FALSE,
      booktabs=TRUE, 
      include.rownames=FALSE,
      include.colnames=FALSE)

xtable.tab_F <- xtable(tab_F,
                       align=c("l", "l", rep("r", ncol(tab_F)-1)))
print(xtable.tab_F, file=paste(storage, "tab_F.tex", sep=""),
      floating=FALSE,
      booktabs=TRUE, 
      include.rownames=FALSE,
      include.colnames=FALSE)

xtable.tab_both <- xtable(tab_both,
                       align=c("l", "l", rep("r", ncol(tab_both)-1)))
print(xtable.tab_both, file=paste(storage, "tab_both.tex", sep=""),
      floating=FALSE,
      booktabs=TRUE, 
      include.rownames=FALSE,
      include.colnames=FALSE)

#### Plots ####
#### MEN ####
d17_M.popcount_AP <- count(data17_M, c("period", "age"))
names(d17_M.popcount_AP)[3] <- "Count"

popcount_hmp_M_AP <- ggplot(d17_M.popcount_AP, aes(period, age)) +
  theme_bw() +    # white background
  xlab('\nPeriod') +
  ylab('Age\n') +
  scale_y_reverse(limits=c(82, 25), expand=c(0,0)) + #expand runs data to axis
  scale_x_continuous(limits=c(2001, 2018), expand=(c(0,0))) +
  geom_tile(aes(fill = Count)) +  #what to use for the tiling variable
  scale_fill_gradientn(colours=c("white", "black"), 
                       space = 'Lab', name="Count\n", limits=c(5, 160)) +   
  # count\n creates space between the title of the legend and the rest
  # geom_segment and geom_text elements build arrows
  geom_segment(aes(x=2015.5, y=30, xend=2015.5, yend=39), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # age
  geom_text(aes(x=2015.2, y=36, label="A"), size=6) +
  geom_segment(aes(x=2015.56, y=40, xend=2017.5, yend=40), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # period
  geom_text(aes(x=2017.2, y=42, label="P"), size=6) +
  geom_segment(aes(x=2015.56, y=39.6, xend=2017.5, yend=30), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # cohort
  geom_text(aes(x=2017.2, y=34, label="C"), size=6) +
  theme(axis.text=element_text(size=18),
        axis.title=element_text(size=24, face="bold"),
        axis.ticks=element_blank(),   # gets rid of tick lines
        panel.border=element_blank(),
        panel.grid.major=element_line(color='#eeeeee'),  # grey grid lines
        legend.title=element_text(size=20, face="bold"),
        legend.key.size = unit(1.2, "cm"),
        legend.text=element_text(size=18),
        legend.position = c(.97, .05),  # puts legend inside plot
        legend.justification = c("right", "bottom"))

popcount_hmp_M_AP
dev.copy(postscript, paste(storage, "popcount_hmp_M_AP.eps", sep=""))
dev.off()


# Heatmap with mean BMI
d17_M.BMImeans <- ddply(data17_M, .variables = c("period", "age"),
                        function(dfr, colnm){mean(dfr[, colnm])}, "bmivalid")
colnames(d17_M.BMImeans)[3] <- "mean.bmi"

BMImeans_hmp_M <- ggplot(d17_M.BMImeans, aes(period, age)) +
  theme_bw() +
  xlab('\nPeriod') +
  ylab('Age\n') +
  scale_x_continuous(limits=c(2001, 2018), expand=(c(0,0))) +
  scale_y_reverse(limits=c(82, 25), expand=c(0,0)) +
  geom_tile(aes(fill = mean.bmi)) +
  scale_fill_gradientn(colours=c("white", "black"), 
                       space = 'Lab', name="Mean BMI\n", limits=c(24, 32)) +   
  # count\n creates space between the title of the legend and the rest
  # geom_segment and geom_text elements build arrows
  geom_segment(aes(x=2015.5, y=30, xend=2015.5, yend=39), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # age
  geom_text(aes(x=2015.2, y=36, label="A"), size=6) +
  geom_segment(aes(x=2015.56, y=40, xend=2017.5, yend=40), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # period
  geom_text(aes(x=2017.2, y=42, label="P"), size=6) +
  geom_segment(aes(x=2015.56, y=39.6, xend=2017.5, yend=30), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # cohort
  geom_text(aes(x=2017.2, y=34, label="C"), size=6) +
  theme(axis.text=element_text(size=18),
        axis.title=element_text(size=24, face="bold"),
        axis.ticks=element_blank(),   # gets rid of tick lines
        panel.border=element_blank(),
        panel.grid.major=element_line(color='#eeeeee'),  # grey grid lines
        legend.title=element_text(size=20, face="bold"),
        legend.key.size = unit(1.2, "cm"),
        legend.text=element_text(size=18),
        legend.position = c(.97, .05),  # puts legend inside plot
        legend.justification = c("right", "bottom"))

BMImeans_hmp_M 
dev.copy(postscript, paste(storage, "BMImeans_hmp_M.eps", sep=""))
dev.off()

#### WOMEN ####

d17_F.popcount_AP <- count(data17_F, c("period", "age"))
names(d17_F.popcount_AP)[3] <- "Count"

## Heatmap with count of observations

popcount_hmp_F_AP <- ggplot(d17_F.popcount_AP, aes(period, age)) +
  theme_bw() +    # white background
  xlab('\nPeriod') +
  ylab('Age\n') +
  scale_y_reverse(limits=c(82, 25), expand=c(0,0)) + #expand runs data to axis
  scale_x_continuous(limits=c(2001, 2018), expand=(c(0,0))) +
  geom_tile(aes(fill = Count)) +  #what to use for the tiling variable
  scale_fill_gradientn(colours=c("white", "black"), 
                       space = 'Lab', name="Count\n", limits=c(5, 160)) +   
  # count\n creates space between the title of the legend and the rest
  # geom_segment and geom_text elements build arrows
  geom_segment(aes(x=2015.5, y=30, xend=2015.5, yend=39), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # age
  geom_text(aes(x=2015.2, y=36, label="A"), size=6) +
  geom_segment(aes(x=2015.56, y=40, xend=2017.5, yend=40), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # period
  geom_text(aes(x=2017.2, y=42, label="P"), size=6) +
  geom_segment(aes(x=2015.56, y=39.6, xend=2017.5, yend=30), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # cohort
  geom_text(aes(x=2017.2, y=34, label="C"), size=6) +
  theme(axis.text=element_text(size=18),
        axis.title=element_text(size=24, face="bold"),
        axis.ticks=element_blank(),   # gets rid of tick lines
        panel.border=element_blank(),
        panel.grid.major=element_line(color='#eeeeee'),  # grey grid lines
        legend.title=element_text(size=20, face="bold"),
        legend.key.size = unit(1.2, "cm"),
        legend.text=element_text(size=18),
        legend.position = c(.97, .05),  # puts legend inside plot
        legend.justification = c("right", "bottom"))

popcount_hmp_F_AP
dev.copy(postscript, paste(storage, "popcount_hmp_F_AP.eps", sep=""))
dev.off()

# Heatmap with mean BMI
d17_F.BMImeans <- ddply(data17_F, .variables = c("period", "age"),
                        function(dfr, colnm){mean(dfr[, colnm])}, "bmivalid")
colnames(d17_F.BMImeans)[3] <- "mean.bmi"

BMImeans_hmp_F <- ggplot(d17_F.BMImeans, aes(period, age)) +
  theme_bw() +
  xlab('\nPeriod') +
  ylab('Age\n') +
  scale_y_reverse(limits=c(82, 25), expand=c(0,0)) + #expand runs data to axis
  scale_x_continuous(limits=c(2001, 2018), expand=(c(0,0))) +
  geom_tile(aes(fill = mean.bmi)) +
  scale_fill_gradientn(colours=c("white", "black"), 
                       space = 'Lab', name="Mean BMI\n", limits=c(24, 32)) +   
  # count\n creates space between the title of the legend and the rest
  # geom_segment and geom_text elements build arrows
  geom_segment(aes(x=2015.5, y=30, xend=2015.5, yend=39), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # age
  geom_text(aes(x=2015.2, y=36, label="A"), size=6) +
  geom_segment(aes(x=2015.56, y=40, xend=2017.5, yend=40), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # period
  geom_text(aes(x=2017.2, y=42, label="P"), size=6) +
  geom_segment(aes(x=2015.56, y=39.6, xend=2017.5, yend=30), colour="black", 
               size = 1, arrow=arrow(length=unit(.2, "cm"))) + # cohort
  geom_text(aes(x=2017.2, y=34, label="C"), size=6) +
  theme(axis.text=element_text(size=18),
        axis.title=element_text(size=24, face="bold"),
        axis.ticks=element_blank(),   # gets rid of tick lines
        panel.border=element_blank(),
        panel.grid.major=element_line(color='#eeeeee'),  # grey grid lines
        legend.title=element_text(size=20, face="bold"),
        legend.key.size = unit(1.2, "cm"),
        legend.text=element_text(size=18),
        legend.position = c(.97, .05),  # puts legend inside plot
        legend.justification = c("right", "bottom"))

BMImeans_hmp_F 
dev.copy(postscript, paste(storage, "BMImeans_hmp_F.eps", sep=""))
dev.off()
# -----------------------------------------------------------------------------
# MODELS
# -----------------------------------------------------------------------------
# Here we run four different models, first for men, then for women. We also
# run specification tests. 
# First model: BMI in terms of ethnicity, NSSEC3, alcohol consumption, smoking,
# and education
# Second model (as in the paper): log BMI in terms of ethnicity, NSSEC3, 
# alcohol consumption, smoking, and education
# Third model: log weight in terms of ethnicity, NSSEC3, alcohol consumption, 
# smoking, education, log height, square of log height
# Fourth model (as in the paper): obesity indicator in terms of ethnicity, 
# NSSEC3, alcohol consumption, smoking, and education

#### MEN ####
# Construct all variables that will be needed in later specifications
Lbmi <- log(data17_M$bmivalid)
Lwtvalid <- log(data17_M$wtvalid)
htvalidm <- data17_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data17_M$age.fin.ed^2

data17_Mbdh <- cbind(data17_M, Lbmi, Lwtvalid, Lhtvalid, Lhtvalid_sq, 
                     age.fin.ed_sq)

rm(Lbmi, Lwtvalid, Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)
#### Data Excerpt ####
excerpt <- data17_Mbdh[1:10, names(data17_Mbdh) %in% c("cell.name", "pserial",
                                                 "age", "period", "bmivalid", 
                                                 "obese","smoke", 
                                                 "ever.smoked", "now.smoke",
                                                 "ethgrp", "Lbmi")]
xtable.excerpt <- xtable(excerpt,
                         align=rep("r", ncol(excerpt)+1))
print(xtable.excerpt, file=paste(storage, "data_excerpt.tex", sep=""),
      floating=FALSE,
      include.rownames=FALSE,
      booktabs=TRUE)
## BMI and NSSEC3 ####

## list covariates to avoid repetition
bmi.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education)

## Which model?
# Ftable
cc.bmi_01nssec3_M.ethhabits.ftable <- apc.indiv.Ftable(
  data17_M, datatype="AP hexag", dep.var="bmivalid", covariates=bmi.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# Direct tests
# AC to Cd
ACtoCd <- apc.indiv.ftest.fullapc(data17_M, datatype = "AP hexag",
              model.design = "AC", reduced.model.design = "Cd", 
              dep.var = "bmivalid", covariates = bmi.covariates,
              n.coh.excl.start = 5, n.coh.excl.end = 5)
# PC to Cd
PCtoCd <- apc.indiv.ftest.fullapc(data17_M, datatype = "AP hexag",
              model.design = "PC", reduced.model.design = "Cd", 
              dep.var = "bmivalid", covariates = bmi.covariates,
              n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- c(ACtoCd$p.value, PCtoCd$p.value)
directs.names <- c("ACtoCd", "PCtoCd")
cc.bmi_01nssec3_M.ethhabits.directs <- rbind(directs.names, directs.p.values)

## APC model
cc.bmi_01nssec3_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.bmi_01nssec3_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.bmi_01nssec3_M.apc.ethhabits.collin, dep.var = "bmivalid", 
  covariates = bmi.covariates, model.design = "APC")

cc.bmi_01nssec3_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.bmi_01nssec3_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.bmi_01nssec3_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.bmi_01nssec3_M.apc.ethhabits.fit, 
  main.outer = "BMI on APC with NSSEC3 01-14, men, detrended")

cc.bmi_01nssec3_M.apc.ethhabits.cov <- round(
  cc.bmi_01nssec3_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage,"cc_bmi_01nssec3_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

## AC model (reduction based on Ftable and APC model)
cc.bmi_01nssec3_M.ac.ethhabits.model <- apc.indiv.design.model(
  cc.bmi_01nssec3_M.apc.ethhabits.collin, dep.var = "bmivalid",
  covariates=bmi.covariates, model.design = "AC")

cc.bmi_01nssec3_M.ac.ethhabits.fit <- apc.indiv.fit.model(
  cc.bmi_01nssec3_M.ac.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.bmi_01nssec3_M.ac.ethhabits.plot <- var.apc.plot.fit(
  cc.bmi_01nssec3_M.ac.ethhabits.fit, 
  main.outer = "BMI on AC with NSSEC3 01-14, men, detrended")

cc.bmi_01nssec3_M.ac.ethhabits.cov <- round(
  cc.bmi_01nssec3_M.ac.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_bmi_01nssec3_M_ac_ethhabits_plot.eps", sep=""))
dev.off()

# Spec Tests on AC model
dev.off()
residuals <- cc.bmi_01nssec3_M.ac.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)
hist(residuals, breaks=4000)
qqnorm(residuals); qqline(residuals)

residuals_sq <- cc.bmi_01nssec3_M.ac.ethhabits.fit$residuals^2
reset.hetero <- tidy.spec.test(data17_M, dep.var = "bmivalid", 
                               covariates = bmi.covariates,
                               model.design="AC", datatype = "AP hexag",
                               n.coh.excl.start = 5,
                               n.coh.excl.end = 5, fit.model = 
                                 cc.bmi_01nssec3_M.ac.ethhabits.fit)
cc.bmi_01nssec3_M.ac.spectable <- messy.spec.table(JB, reset.hetero)

## print tables
xtable.cc.bmi_01nssec3_M.ethhabits.ftable <- xtable(
  cc.bmi_01nssec3_M.ethhabits.ftable, 
  display = xdisplay(cc.bmi_01nssec3_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.bmi_01nssec3_M.ethhabits.ftable)+1)), 
  caption="BMI on APC and NSSEC3, men, 01-14", 
  label="cc.bmi_01nssec3_M.ethhabits.ftable")
print.xtable(xtable.cc.bmi_01nssec3_M.ethhabits.ftable, 
             file=paste(storage, "cc.bmi_01nssec3_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.bmi_01nssec3_M.ethhabits.directs <- xtable(
  cc.bmi_01nssec3_M.ethhabits.directs,
  display = xdisplay(cc.bmi_01nssec3_M.ethhabits.directs),
  align=rep("p{1.5cm}", (ncol(cc.bmi_01nssec3_M.ethhabits.directs)+1)),
  caption="Direct tests between submodels, BMI on APC and NNSEC3, men,
  01-14", label="cc.bmi_01nssec3_M.ethhabits.directs")
print.xtable(xtable.cc.bmi_01nssec3_M.ethhabits.directs, 
             file=paste(storage, "cc.bmi_01nssec3_M.ethhabits.directs.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.bmi_01nssec3_M.apc.ethhabits.cov <- xtable(
  cc.bmi_01nssec3_M.apc.ethhabits.cov, 
  display=xdisplay(cc.bmi_01nssec3_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.bmi_01nssec3_M.apc.ethhabits.cov)+1)),
  caption="BMI on APC and NSSEC3, men, 01-14", 
  label="cc.bmi_01nssec3_M.apc.ethhabits.cov")
print.xtable(xtable.cc.bmi_01nssec3_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.bmi_01nssec3_M.apc.ethhabits.cov.tex", 
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

xtable.cc.bmi_01nssec3_M.ac.ethhabits.cov <- xtable(
  cc.bmi_01nssec3_M.ac.ethhabits.cov, 
  display=xdisplay(cc.bmi_01nssec3_M.ac.ethhabits.cov), 
  align=rep("c", (ncol(cc.bmi_01nssec3_M.ac.ethhabits.cov)+1)),
  caption="BMI on AC and NSSEC3, men, 01-14", 
  label="cc.bmi_01nssec3_M.ac.ethhabits.cov")
print.xtable(xtable.cc.bmi_01nssec3_M.ac.ethhabits.cov, 
             file=paste(storage, "cc.bmi_01nssec3_M.ac.ethhabits.cov.tex", 
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

xtable.cc.bmi_01nssec3_M.ac.spectable <- xtable(
  cc.bmi_01nssec3_M.ac.spectable,
  display = xdisplay(cc.bmi_01nssec3_M.ac.spectable),
  align = rep("c", (ncol(cc.bmi_01nssec3_M.ac.spectable)+1)),
  caption = "BMI on AC and NSSEC3, men, 01-14",
  label = "cc.bmi_01nssec3_M.ac.spectable")
print.xtable(xtable.cc.bmi_01nssec3_M.ac.spectable,
             file = paste(storage, "cc.bmi_01nssec3_M.ac.spectable.tex",
                          sep=""),
             booktabs=TRUE, caption.placement = "top")

## remove things from this estimation round
rm(list=ls(pattern="cc.bmi_01nssec3_M"))

## Log BMI, NSSEC3, educ categorical ####

# list covariates to avoid repetition
Lbmi.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education)

# Ftable
cc.Lbmi_01nssec3_M.ethhabits.ftable <- apc.indiv.Ftable(
  data17_Mbdh, datatype="AP hexag", dep.var="Lbmi", covariates=Lbmi.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# Direct tests
# Cd to AC
CdtoAC <- apc.indiv.ftest.fullapc(data17_Mbdh, datatype = "AP hexag",
                                  model.design = "AC", reduced.model.design = "Cd", 
                                  dep.var = "Lbmi", covariates = Lbmi.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# Cd to PC
CdtoPC <- apc.indiv.ftest.fullapc(data17_Mbdh, datatype = "AP hexag",
                                  model.design = "PC", reduced.model.design = "Cd", 
                                  dep.var = "Lbmi", covariates = Lbmi.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- round(c(CdtoAC$p.value, CdtoPC$p.value), 3)
directs.names <- c("CdtoAC", "CdtoPC")
cc.Lbmi_01nssec3_M.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.Lbmi_01nssec3_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_Mbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec3_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec3_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = Lbmi.covariates, model.design = "APC")

cc.Lbmi_01nssec3_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec3_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec3_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec3_M.apc.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.Lbmi_01nssec3_M.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec3_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec3_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# Design matrix excerpt 
full.design <- cc.Lbmi_01nssec3_M.apc.ethhabits.model$full.design
choice <- c("level", "age slope", "cohort slope", "DD_age_30", "DD_age_45",
            "DD_age_46", "DD_age_47", "DD_period_2009", "DD_cohort_1960", 
            "DD_cohort_1981")
design.excerpt <- full.design[1:10, names(full.design) %in% choice]
xtable.design.excerpt <- xtable(design.excerpt,
                         align=rep("r", ncol(design.excerpt)+1))
print(xtable.design.excerpt, file=paste(storage, "design_excerpt.tex", sep=""),
      floating=FALSE,
      include.rownames=FALSE,
      booktabs=TRUE)

# Spec Tests on APC model
dev.off()
residuals <- cc.Lbmi_01nssec3_M.apc.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)

reset.hetero <- tidy.spec.test(data17_Mbdh, dep.var = "Lbmi", 
                               covariates = Lbmi.covariates,
                               model.design="APC", datatype = "AP hexag",
                               n.coh.excl.start = 5,
                               n.coh.excl.end = 5, fit.model = 
                                 cc.Lbmi_01nssec3_M.apc.ethhabits.fit)

cc.Lbmi_01nssec3_M.apc.spectable <- messy.spec.table(JB, reset.hetero)

# AC model (reduction based on Ftable and APC model)
cc.Lbmi_01nssec3_M.ac.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec3_M.apc.ethhabits.collin, dep.var = "Lbmi",
  covariates=Lbmi.covariates, model.design = "AC")

cc.Lbmi_01nssec3_M.ac.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec3_M.ac.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec3_M.ac.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec3_M.ac.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.Lbmi_01nssec3_M.ac.ethhabits.cov <- round(
  cc.Lbmi_01nssec3_M.ac.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_Lbmi_01nssec3_M_ac_ethhabits_plot.eps", sep=""))
dev.off()

# Spec Tests on AC model
dev.off()
residuals <- cc.Lbmi_01nssec3_M.ac.ethhabits.fit$residuals

JB <- jarque.bera.test(residuals)
reset.hetero <- tidy.spec.test(data17_Mbdh, dep.var = "Lbmi", 
                               covariates = Lbmi.covariates,
                               model.design="AC", datatype = "AP hexag",
                               n.coh.excl.start = 5,
                               n.coh.excl.end = 5, fit.model = 
                                 cc.Lbmi_01nssec3_M.ac.ethhabits.fit)

cc.Lbmi_01nssec3_M.ac.spectable <- messy.spec.table(JB, reset.hetero)

# Residual plot
combo <- as.data.frame(cbind(cc.Lbmi_01nssec3_M.ac.ethhabits.fit$fitted.values,
                             residuals))

n = length(residuals)
mean = mean(residuals)
sd = sd(residuals)
binwidth = 0.01 # passed to geom_histogram and stat_function
set.seed(1)
df <- data.frame(x = rnorm(n, mean, sd))

hist_M.ac_resid <- ggplot(combo, aes(x = residuals, mean = mean(residuals),
                         sd = sd(residuals), binwidth = binwidth, 
                         n = n)) +
  theme_bw() +
  geom_histogram(binwidth = binwidth, 
                 colour = "white", fill = "blue", size = 0.1) +
  stat_function(fun = function(x) dnorm(x, mean = mean, sd = sd) * n * binwidth,
                color = "darkred", size = 1)
hist_M.ac_resid

dev.copy(postscript, paste(storage, "hist_M_ac_resid.eps", sep=""))
dev.off() 

# print tables
xtablify.F(cc.Lbmi_01nssec3_M.ethhabits.ftable,
           "cc.Lbmi_01nssec3_M.ethhabits.ftable")

xtable.cc.Lbmi_01nssec3_M.ethhabits.directs <- xtable(
  cc.Lbmi_01nssec3_M.ethhabits.directs,
  align=c("l", rep("r", ncol(cc.Lbmi_01nssec3_M.ethhabits.directs))))
print(xtable.cc.Lbmi_01nssec3_M.ethhabits.directs, 
      floating = FALSE,
      file=paste(storage, "cc.Lbmi_01nssec3_M.ethhabits.directs.tex",
                 sep=""), 
      booktabs=TRUE,
      include.colnames=FALSE)

xtable.cc.Lbmi_01nssec3_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec3_M.apc.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.Lbmi_01nssec3_M.apc.ethhabits.cov))))
print(xtable.cc.Lbmi_01nssec3_M.apc.ethhabits.cov, 
      floating = FALSE,
      file=paste(storage, "cc.Lbmi_01nssec3_M.apc.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)

xtable.cc.Lbmi_01nssec3_M.ac.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec3_M.ac.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.Lbmi_01nssec3_M.ac.ethhabits.cov))),
  digits=4)
print(xtable.cc.Lbmi_01nssec3_M.ac.ethhabits.cov, 
      floating = FALSE, 
      file=paste(storage,"cc.Lbmi_01nssec3_M.ac.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)

xtable.cc.Lbmi_01nssec3_M.apc.spectable <- xtable(
  cc.Lbmi_01nssec3_M.apc.spectable,
  align = c("l", "l", rep("r", ncol(cc.Lbmi_01nssec3_M.apc.spectable)-1)))
print(xtable.cc.Lbmi_01nssec3_M.apc.spectable, 
      floating=FALSE,
      file = paste(storage, "cc.Lbmi_01nssec3_M.apc.spectable.tex", sep=""),
      booktabs=TRUE, 
      include.rownames = FALSE)

xtable.cc.Lbmi_01nssec3_M.ac.spectable <- xtable(
  cc.Lbmi_01nssec3_M.ac.spectable,
  align = c("l", "l", rep("r", ncol(cc.Lbmi_01nssec3_M.ac.spectable)-1)))
print(xtable.cc.Lbmi_01nssec3_M.ac.spectable, 
      floating=FALSE,
      file = paste(storage, "cc.Lbmi_01nssec3_M.ac.spectable.tex", sep=""),
      booktabs=TRUE, 
      include.rownames = FALSE)

## remove things from this estimation round
rm(list=ls(pattern="cc.Lbmi_01nssec3_M"))

## Log weight and log height, NSSEC3, educ categorical ####

# list covariates to avoid repetition
Lwt.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education,
  "Lhtvalid", "Lhtvalid_sq")

## Which model?
# Ftable
cc.Lwt_01nssec3_M.ethhabits.ftable <- apc.indiv.Ftable(
  data17_Mbdh, datatype="AP hexag", dep.var="Lwtvalid", 
  covariates=Lwt.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# Direct tests
# AC to Cd
ACtoCd <- apc.indiv.ftest.fullapc(data17_Mbdh, datatype = "AP hexag",
                        model.design = "AC", reduced.model.design = "Cd", 
                        dep.var = "Lwtvalid", covariates = Lwt.covariates,
                        n.coh.excl.start = 5, n.coh.excl.end = 5)
# PC to Cd
PCtoCd <- apc.indiv.ftest.fullapc(data17_Mbdh, datatype = "AP hexag",
                        model.design = "PC", reduced.model.design = "Cd", 
                        dep.var = "Lwtvalid", covariates = Lwt.covariates,
                        n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- c(ACtoCd$p.value, PCtoCd$p.value)
directs.names <- c("ACtoCd", "PCtoCd")
cc.Lwt_01nssec3_M.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.Lwt_01nssec3_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_Mbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lwt_01nssec3_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lwt_01nssec3_M.apc.ethhabits.collin, dep.var = "Lwtvalid", 
  covariates = Lwt.covariates, model.design = "APC")

cc.Lwt_01nssec3_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lwt_01nssec3_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lwt_01nssec3_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lwt_01nssec3_M.apc.ethhabits.fit, 
  main.outer = "Log weight on APC with NSSEC3 01-14, men, detrended")

cc.Lwt_01nssec3_M.apc.ethhabits.cov <- round(
  cc.Lwt_01nssec3_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lwt_01nssec3_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# AC model (reduction based on Ftable and APC model)
cc.Lwt_01nssec3_M.ac.ethhabits.model <- apc.indiv.design.model(
  cc.Lwt_01nssec3_M.apc.ethhabits.collin, dep.var = "Lwtvalid",
  covariates=Lwt.covariates, model.design = "AC")

cc.Lwt_01nssec3_M.ac.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lwt_01nssec3_M.ac.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lwt_01nssec3_M.ac.ethhabits.plot <- var.apc.plot.fit(
  cc.Lwt_01nssec3_M.ac.ethhabits.fit, 
  main.outer = "Log weight on AC with NSSEC3 01-14, men, detrended")

cc.Lwt_01nssec3_M.ac.ethhabits.cov <- round(
  cc.Lwt_01nssec3_M.ac.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_Lwt_01nssec3_M_ac_ethhabits_plot.eps", sep=""))
dev.off()

# Spec Tests on AC model
dev.off()
residuals <- cc.Lwt_01nssec3_M.ac.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)
hist(residuals, breaks=4000)
qqnorm(residuals); qqline(residuals)

residuals_sq <- cc.Lwt_01nssec3_M.ac.ethhabits.fit$residuals^2
reset.hetero <- tidy.spec.test(data17_Mbdh, dep.var = "Lwtvalid", 
                                covariates = Lwt.covariates,
                                model.design="AC", datatype = "AP hexag",
                                n.coh.excl.start = 5,
                                n.coh.excl.end = 5, fit.model = 
                                  cc.Lwt_01nssec3_M.ac.ethhabits.fit)
cc.Lwt_01nssec3_M.ac.spectable <- messy.spec.table(JB, reset.hetero)

# print tables
xtable.cc.Lwt_01nssec3_M.ethhabits.ftable <- xtable(
  cc.Lwt_01nssec3_M.ethhabits.ftable, 
  display = xdisplay(cc.Lwt_01nssec3_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lwt_01nssec3_M.ethhabits.ftable)+1)), 
  caption="Log weight on APC and NSSEC3, men, 01-14", 
  label="cc.Lwt_01nssec3_M.ethhabits.ftable")
print.xtable(xtable.cc.Lwt_01nssec3_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lwt_01nssec3_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lwt_01nssec3_M.ethhabits.directs <- xtable(
  cc.Lwt_01nssec3_M.ethhabits.directs,
  display = xdisplay(cc.Lwt_01nssec3_M.ethhabits.directs),
  align=rep("p{1.5cm}", (ncol(cc.Lwt_01nssec3_M.ethhabits.directs)+1)),
  caption="Direct tests between submodels, log weight on APC and NNSEC3, men,
  01-14", label="cc.Lwt_01nssec3_M.ethhabits.directs")
print.xtable(xtable.cc.Lwt_01nssec3_M.ethhabits.directs, 
             file=paste(storage, "cc.Lwt_01nssec3_M.ethhabits.directs.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lwt_01nssec3_M.apc.ethhabits.cov <- xtable(
  cc.Lwt_01nssec3_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lwt_01nssec3_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lwt_01nssec3_M.apc.ethhabits.cov)+1)),
  caption="Log weight on APC and NSSEC3, men, 01-14", 
  label="cc.Lwt_01nssec3_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lwt_01nssec3_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lwt_01nssec3_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

xtable.cc.Lwt_01nssec3_M.ac.ethhabits.cov <- xtable(
  cc.Lwt_01nssec3_M.ac.ethhabits.cov, 
  display=xdisplay(cc.Lwt_01nssec3_M.ac.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lwt_01nssec3_M.ac.ethhabits.cov)+1)),
  caption="Log weight on AC and NSSEC3, men, 01-14", 
  label="cc.Lwt_01nssec3_M.ac.ethhabits.cov")
print.xtable(xtable.cc.Lwt_01nssec3_M.ac.ethhabits.cov, 
             file=paste(storage, "cc.Lwt_01nssec3_M.ac.ethhabits.cov.tex", 
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

xtable.cc.Lwt_01nssec3_M.ac.spectable <- xtable(
  cc.Lwt_01nssec3_M.ac.spectable,
  display = xdisplay(cc.Lwt_01nssec3_M.ac.spectable),
  align = rep("c", (ncol(cc.Lwt_01nssec3_M.ac.spectable)+1)),
  caption = "Log weight on AC and NSSEC3, men, 01-14",
  label = "cc.Lwt_01nssec3_M.ac.spectable")
print.xtable(xtable.cc.Lwt_01nssec3_M.ac.spectable,
             file = paste(storage, "cc.Lwt_01nssec3_M.ac.spectable.tex", 
                          sep=""),
             booktabs=TRUE, caption.placement = "top")

## remove things from this estimation round
rm(list=ls(pattern="cc.Lwt_01nssec3_M"))

## Obese and NSSEC3, squares ####

# list covariates to avoid repetition
obese.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education)

# LRtable
cc.obese_01nssec3_M.ethhabits.LRtable <- apc.indiv.LRtable.TS(
  data17_Mbdh, datatype="AP hexag", dep.var="obese", covariates=obese.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5, maxit.loop=30, maxit.linesearch.TS = 60, 
  init.TS="zero")

# Direct tests
# Cd to AC
CdtoAC <- apc.indiv.LRtest.fullapc(data17_Mbdh, datatype = "AP hexag",
                                  model.design = "AC", reduced.model.design = "Cd", 
                                  dep.var = "obese", covariates = obese.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# Cd to PC
CdtoPC <- apc.indiv.LRtest.fullapc(data17_Mbdh, datatype = "AP hexag",
                                  model.design = "PC", reduced.model.design = "Cd", 
                                  dep.var = "obese", covariates = obese.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# Ad to AC
AdtoAC <- apc.indiv.LRtest.fullapc(data17_Mbdh, datatype = "AP hexag",
                                  model.design = "AC", reduced.model.design = "Ad", 
                                  dep.var = "obese", covariates = obese.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- round(c(CdtoAC$p.value, CdtoPC$p.value, AdtoAC$p.value),3)
directs.names <- c("CdtoAC", "CdtoPC", "AdtoAC")
cc.obese_01nssec3_M.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.obese_01nssec3_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_Mbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.obese_01nssec3_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.obese_01nssec3_M.apc.ethhabits.collin, dep.var = "obese", 
  covariates = obese.covariates, model.design = "APC")

cc.obese_01nssec3_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.obese_01nssec3_M.apc.ethhabits.model, model.family="binomial",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.obese_01nssec3_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.obese_01nssec3_M.apc.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.obese_01nssec3_M.apc.ethhabits.cov <- round(
  cc.obese_01nssec3_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_obese_01nssec3_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# PC model (reduction based on LRtable and APC model)
cc.obese_01nssec3_M.pc.ethhabits.model <- apc.indiv.design.model(
  cc.obese_01nssec3_M.apc.ethhabits.collin, dep.var = "obese",
  covariates=obese.covariates, model.design = "PC")

cc.obese_01nssec3_M.pc.ethhabits.fit <- apc.indiv.fit.model(
  cc.obese_01nssec3_M.pc.ethhabits.model, model.family="binomial",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.obese_01nssec3_M.pc.ethhabits.plot <- var.apc.plot.fit(
  cc.obese_01nssec3_M.pc.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.obese_01nssec3_M.pc.ethhabits.cov <- round(
  cc.obese_01nssec3_M.pc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_obese_01nssec3_M_pc_ethhabits_plot.eps", sep = ""))
dev.off()

# Cd model (reduction based on LRtable and APC model)
cc.obese_01nssec3_M.cd.ethhabits.model <- apc.indiv.design.model(
  cc.obese_01nssec3_M.apc.ethhabits.collin, dep.var = "obese",
  covariates=obese.covariates, model.design = "Cd")

cc.obese_01nssec3_M.cd.ethhabits.fit <- apc.indiv.fit.model(
  cc.obese_01nssec3_M.cd.ethhabits.model, model.family="binomial",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.obese_01nssec3_M.cd.ethhabits.plot <- var.apc.plot.fit(
  cc.obese_01nssec3_M.cd.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.obese_01nssec3_M.cd.ethhabits.cov <- round(
  cc.obese_01nssec3_M.cd.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_obese_01nssec3_M_cd_ethhabits_plot.eps", sep=""))
dev.off()

xtablify.LR(cc.obese_01nssec3_M.ethhabits.LRtable,
            "cc.obese_01nssec3_M.ethhabits.LRtable")

xtable.cc.obese_01nssec3_M.ethhabits.directs <- xtable(
  cc.obese_01nssec3_M.ethhabits.directs,
  align=c("l", rep("r", ncol(cc.obese_01nssec3_M.ethhabits.directs))))
print(xtable.cc.obese_01nssec3_M.ethhabits.directs, 
     floating = FALSE,
     file=paste(storage, "cc.obese_01nssec3_M.ethhabits.directs.tex",
                        sep=""), 
     booktabs=TRUE,
     include.colnames=FALSE)

xtable.cc.obese_01nssec3_M.apc.ethhabits.cov <- xtable(
  cc.obese_01nssec3_M.apc.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.obese_01nssec3_M.apc.ethhabits.cov))))
print(xtable.cc.obese_01nssec3_M.apc.ethhabits.cov, 
     floating=FALSE,
     file=paste(storage, "cc.obese_01nssec3_M.apc.ethhabits.cov.tex",
                        sep=""),
     booktabs=TRUE)

xtable.cc.obese_01nssec3_M.pc.ethhabits.cov <- xtable(
  cc.obese_01nssec3_M.pc.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.obese_01nssec3_M.pc.ethhabits.cov))))
print(xtable.cc.obese_01nssec3_M.pc.ethhabits.cov, 
      floating=FALSE,
      file=paste(storage, "cc.obese_01nssec3_M.pc.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)

xtable.cc.obese_01nssec3_M.cd.ethhabits.cov <- xtable(
  cc.obese_01nssec3_M.cd.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.obese_01nssec3_M.cd.ethhabits.cov))),
  digits=3)
print(xtable.cc.obese_01nssec3_M.cd.ethhabits.cov, 
      floating=FALSE,
      file=paste(storage, "cc.obese_01nssec3_M.cd.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)

## remove things from this estimation round
rm(list=ls(pattern="cc.obese_01nssec3_M"))

#### WOMEN ####
# Construct all variables that will be needed in later specifications
Lbmi <- log(data17_F$bmivalid)
Lwtvalid <- log(data17_F$wtvalid)
htvalidm <- data17_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data17_F$age.fin.ed^2

data17_Fbdh <- cbind(data17_F, Lbmi, Lwtvalid, Lhtvalid, Lhtvalid_sq, 
                     age.fin.ed_sq)

rm(Lbmi, htvalidm, Lwtvalid, Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

## BMI and NSSEC3 ####

## list covariates to avoid repetition
bmi.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education)

# Ftable
cc.bmi_01nssec3_F.ethhabits.ftable <- apc.indiv.Ftable(
  data17_F, datatype="AP hexag", dep.var="bmivalid", covariates=bmi.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# Direct tests
# AC to Ad
ACtoAd <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                  model.design = "AC", reduced.model.design = "Ad", 
                                  dep.var = "bmivalid", covariates = bmi.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# AP to Ad
APtoAd <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                  model.design = "AP", reduced.model.design = "Ad", 
                                  dep.var = "bmivalid", covariates = bmi.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# Ad to A
AdtoA <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                 model.design = "Ad", reduced.model.design = "A", 
                                 dep.var = "bmivalid", covariates = bmi.covariates,
                                 n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- c(ACtoAd$p.value, APtoAd$p.value, AdtoA$p.value)
directs.names <- c("ACtoAd", "APtoAd", "AdtoA")
cc.bmi_01nssec3_F.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.bmi_01nssec3_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.bmi_01nssec3_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.bmi_01nssec3_F.apc.ethhabits.collin, dep.var = "bmivalid", 
  covariates = bmi.covariates, model.design = "APC")

cc.bmi_01nssec3_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.bmi_01nssec3_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.bmi_01nssec3_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.bmi_01nssec3_F.apc.ethhabits.fit, 
  main.outer = "BMI on APC with NSSEC3 01-14, women, detrended")

cc.bmi_01nssec3_F.apc.ethhabits.cov <- round(
  cc.bmi_01nssec3_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_bmi_01nssec3_F_apc_ethhabits_plot.eps",sep=""))
dev.off()

# Ad model (reduction based on Ftable and APC model)
cc.bmi_01nssec3_F.ad.ethhabits.model <- apc.indiv.design.model(
  cc.bmi_01nssec3_F.apc.ethhabits.collin, dep.var = "bmivalid",
  covariates=bmi.covariates, model.design = "Ad")

cc.bmi_01nssec3_F.ad.ethhabits.fit <- apc.indiv.fit.model(
  cc.bmi_01nssec3_F.ad.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.bmi_01nssec3_F.ad.ethhabits.plot <- var.apc.plot.fit(
  cc.bmi_01nssec3_F.ad.ethhabits.fit, 
  main.outer = "BMI on Ad with NSSEC3 01-14, women, detrended")

cc.bmi_01nssec3_F.ad.ethhabits.cov <- round(
  cc.bmi_01nssec3_F.ad.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_bmi_01nssec3_F_ad_ethhabits_plot.eps",
               sep = ""))
dev.off()

# Spec Tests on Ad model
dev.off()
residuals <- cc.bmi_01nssec3_F.ad.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)
hist(residuals, breaks=4000)
qqnorm(residuals); qqline(residuals)

residuals_sq <- cc.bmi_01nssec3_F.ad.ethhabits.fit$residuals^2
reset.hetero <- tidy.spec.test(data17_Fbdh, dep.var = "bmivalid", 
                               covariates = bmi.covariates,
                               model.design="Ad", datatype = "AP hexag",
                               n.coh.excl.start = 5,
                               n.coh.excl.end = 5, fit.model = 
                                 cc.bmi_01nssec3_F.ad.ethhabits.fit)
cc.bmi_01nssec3_F.ad.spectable <- messy.spec.table(JB, reset.hetero)

# Cumulants (taken from inside JB test)
x <- residuals
n <- length(x)
m1 <- sum(x)/n
m2 <- sum((x - m1)^2)/n
m3 <- sum((x - m1)^3)/n
m4 <- sum((x - m1)^4)/n
b1 <- (m3/m2^(3/2))^2
b2 <- (m4/m2^2)
STATISTIC <- n * b1/6 + n * (b2 - 3)^2/24

skew.val <- sqrt(b1)
excesskurt.val <- (b2-3)

skew.stat <- n * b1/6
excesskurt.stat <- n * (b2 - 3)^2/24

p.skew <- 1 - pchisq(skew.stat, df=1)
p.excesskurt <- 1 - pchisq(excesskurt.stat, df=1)
# all above copied by hand into Ad table (for now)

# print tables
xtable.cc.bmi_01nssec3_F.ethhabits.ftable <- xtable(
  cc.bmi_01nssec3_F.ethhabits.ftable, 
  display = xdisplay(cc.bmi_01nssec3_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.bmi_01nssec3_F.ethhabits.ftable)+1)), 
  caption="BMI on APC and NSSEC3, women, 01-14", 
  label="cc.bmi_01nssec3_F.ethhabits.ftable")
print.xtable(xtable.cc.bmi_01nssec3_F.ethhabits.ftable, 
             file=paste(storage, "cc.bmi_01nssec3_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.bmi_01nssec3_F.ethhabits.directs <- xtable(
  cc.bmi_01nssec3_F.ethhabits.directs,
  display = xdisplay(cc.bmi_01nssec3_F.ethhabits.directs),
  align=rep("p{1.5cm}", (ncol(cc.bmi_01nssec3_F.ethhabits.directs)+1)),
  caption="Direct tests between submodels, BMI on APC and NNSEC3, women,
  01-14", label="cc.bmi_01nssec3_F.ethhabits.directs")
print.xtable(xtable.cc.bmi_01nssec3_F.ethhabits.directs, 
             file=paste(storage, "cc.bmi_01nssec3_F.ethhabits.directs.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.bmi_01nssec3_F.apc.ethhabits.cov <- xtable(
  cc.bmi_01nssec3_F.apc.ethhabits.cov, 
  display=xdisplay(cc.bmi_01nssec3_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.bmi_01nssec3_F.apc.ethhabits.cov)+1)),
  caption="BMI on APC and NSSEC3, women, 01-14", 
  label="cc.bmi_01nssec3_F.apc.ethhabits.cov")
print.xtable(xtable.cc.bmi_01nssec3_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.bmi_01nssec3_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

xtable.cc.bmi_01nssec3_F.ad.ethhabits.cov <- xtable(
  cc.bmi_01nssec3_F.ad.ethhabits.cov, 
  display=xdisplay(cc.bmi_01nssec3_F.ad.ethhabits.cov), 
  align=rep("c", (ncol(cc.bmi_01nssec3_F.ad.ethhabits.cov)+1)),
  caption="BMI on Ad and NSSEC3, women, 01-14", 
  label="cc.bmi_01nssec3_F.ad.ethhabits.cov")
print.xtable(xtable.cc.bmi_01nssec3_F.ad.ethhabits.cov, 
             file=paste(storage, "cc.bmi_01nssec3_F.ad.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

xtable.cc.bmi_01nssec3_F.ad.spectable <- xtable(
  cc.bmi_01nssec3_F.ad.spectable,
  display = xdisplay(cc.bmi_01nssec3_F.ad.spectable),
  align = rep("c", (ncol(cc.bmi_01nssec3_F.ad.spectable)+1)),
  caption = "BMI on Ad and NSSEC3, women, 01-14",
  label = "cc.bmi_01nssec3_F.ad.spectable")
print.xtable(xtable.cc.bmi_01nssec3_F.ad.spectable,
             file = paste(storage, "cc.bmi_01nssec3_F.ad.spectable.tex",
                          sep=""),
             booktabs=TRUE, caption.placement = "top")

## remove things from this estimation round
rm(list=ls(pattern="cc.bmi_01nssec3_F"))

## Log BMI, NSSEC3, educ categorical ####

# list covariates to avoid repetition
Lbmi.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education)

# Ftable
cc.Lbmi_01nssec3_F.ethhabits.ftable <- apc.indiv.Ftable(
  data17_Fbdh, datatype="AP hexag", dep.var="Lbmi", covariates=Lbmi.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# Direct tests
# Ad to AC
AdtoAC <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                  model.design = "AC", reduced.model.design = "Ad", 
                                  dep.var = "Lbmi", covariates = Lbmi.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# Ad to AP
AdtoAP <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                  model.design = "AP", reduced.model.design = "Ad", 
                                  dep.var = "Lbmi", covariates = Lbmi.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# A to Ad
AtoAd <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                 model.design = "Ad", reduced.model.design = "A", 
                                 dep.var = "Lbmi", covariates = Lbmi.covariates,
                                 n.coh.excl.start = 5, n.coh.excl.end = 5)


directs.p.values <- round(c(AdtoAC$p.value, AdtoAP$p.value, AtoAd$p.value),3)
directs.names <- c("AdtoAC", "AdtoAP", "AtoAd")
cc.Lbmi_01nssec3_F.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.Lbmi_01nssec3_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_Fbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec3_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec3_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = Lbmi.covariates, model.design = "APC")

cc.Lbmi_01nssec3_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec3_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec3_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec3_F.apc.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.Lbmi_01nssec3_F.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec3_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec3_F_apc_ethhabits_plot.eps",
               sep=""))
dev.off()

# Spec Tests on APC model
dev.off()
residuals <- cc.Lbmi_01nssec3_F.apc.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)

reset.hetero <- tidy.spec.test(data17_Fbdh, dep.var = "Lbmi", 
                               covariates = Lbmi.covariates,
                               model.design="APC", datatype = "AP hexag",
                               n.coh.excl.start = 5,
                               n.coh.excl.end = 5, fit.model = 
                                 cc.Lbmi_01nssec3_F.apc.ethhabits.fit)

cc.Lbmi_01nssec3_F.apc.spectable <- messy.spec.table(JB, reset.hetero)

# Ad model (reduction based on Ftable and APC model)
cc.Lbmi_01nssec3_F.ad.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec3_F.apc.ethhabits.collin, dep.var = "Lbmi",
  covariates=Lbmi.covariates, model.design = "Ad")

cc.Lbmi_01nssec3_F.ad.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec3_F.ad.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec3_F.ad.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec3_F.ad.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.Lbmi_01nssec3_F.ad.ethhabits.cov <- round(
  cc.Lbmi_01nssec3_F.ad.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_Lbmi_01nssec3_F_ad_ethhabits_plot.eps", sep=""))
dev.off()

# Spec Tests on Ad model
dev.off()
residuals <- cc.Lbmi_01nssec3_F.ad.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)

reset.hetero <- tidy.spec.test(data17_Fbdh, dep.var = "Lbmi", 
                               covariates = Lbmi.covariates,
                               model.design="Ad", datatype = "AP hexag",
                               n.coh.excl.start = 5,
                               n.coh.excl.end = 5, fit.model = 
                                 cc.Lbmi_01nssec3_F.ad.ethhabits.fit)

cc.Lbmi_01nssec3_F.ad.spectable <- messy.spec.table(JB, reset.hetero)

# Cumulants (taken from inside JB test)
x <- residuals
n <- length(x)
m1 <- sum(x)/n
m2 <- sum((x - m1)^2)/n
m3 <- sum((x - m1)^3)/n
m4 <- sum((x - m1)^4)/n
b1 <- (m3/m2^(3/2))^2
b2 <- (m4/m2^2)
STATISTIC <- n * b1/6 + n * (b2 - 3)^2/24

skew.val <- sqrt(b1)
excesskurt.val <- (b2-3)

skew.stat <- n * b1/6
excesskurt.stat <- n * (b2 - 3)^2/24

p.skew <- 1 - pchisq(skew.stat, df=1)
p.excesskurt <- 1 - pchisq(excesskurt.stat, df=1)
# all above copied by hand into Ad table (for now)

# Residual plot
combo <- as.data.frame(cbind(cc.Lbmi_01nssec3_F.ad.ethhabits.fit$fitted.values,
                             residuals))

n = length(residuals)
mean = mean(residuals)
sd = sd(residuals)
binwidth = 0.01 # passed to geom_histogram and stat_function
set.seed(1)
df <- data.frame(x = rnorm(n, mean, sd))

hist_F.ad_resid <- ggplot(combo, aes(x = residuals, mean = mean(residuals),
                                     sd = sd(residuals), binwidth = binwidth, 
                                     n = n)) +
  theme_bw() +
  geom_histogram(binwidth = binwidth, 
                 colour = "white", fill = "grey", size = 0.1) +
  stat_function(fun = function(x) dnorm(x, mean = mean, sd = sd) * n * binwidth,
                color = "black", size = 1)
hist_F.ad_resid

dev.copy(postscript, paste(storage, "hist_F_ad_resid.eps", sep=""))
dev.off() 

# print tables
xtablify.F(cc.Lbmi_01nssec3_F.ethhabits.ftable,
           "cc.Lbmi_01nssec3_F.ethhabits.ftable")

xtable.cc.Lbmi_01nssec3_F.ethhabits.directs <- xtable(
  cc.Lbmi_01nssec3_F.ethhabits.directs,
  align=c("l", rep("r", ncol(cc.Lbmi_01nssec3_F.ethhabits.directs))))
print(xtable.cc.Lbmi_01nssec3_F.ethhabits.directs, 
      floating=FALSE,
      file=paste(storage, "cc.Lbmi_01nssec3_F.ethhabits.directs.tex",
                        sep=""), 
      booktabs=TRUE,
      include.colnames=FALSE)

xtable.cc.Lbmi_01nssec3_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec3_F.apc.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.Lbmi_01nssec3_F.apc.ethhabits.cov))))
print(xtable.cc.Lbmi_01nssec3_F.apc.ethhabits.cov, 
      floating=FALSE,
      file=paste(storage, "cc.Lbmi_01nssec3_F.apc.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)

xtable.cc.Lbmi_01nssec3_F.ad.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec3_F.ad.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.Lbmi_01nssec3_F.ad.ethhabits.cov))),
  digits=4)
print(xtable.cc.Lbmi_01nssec3_F.ad.ethhabits.cov, 
     floating=FALSE,
     file=paste(storage, "cc.Lbmi_01nssec3_F.ad.ethhabits.cov.tex",
                        sep=""), 
     booktabs=TRUE)

xtable.cc.Lbmi_01nssec3_F.apc.spectable <- xtable(
  cc.Lbmi_01nssec3_F.apc.spectable,
  align = c("l", "l", rep("r", ncol(cc.Lbmi_01nssec3_F.apc.spectable)-1)))
print(xtable.cc.Lbmi_01nssec3_F.apc.spectable, 
      floating=FALSE,
      file = paste(storage, "cc.Lbmi_01nssec3_F.apc.spectable.tex", sep=""),
      booktabs=TRUE, 
      include.rownames = FALSE)

xtable.cc.Lbmi_01nssec3_F.ad.spectable <- xtable(
  cc.Lbmi_01nssec3_F.ad.spectable,
  align = c("l", "l", rep("r", ncol(cc.Lbmi_01nssec3_F.ad.spectable)-1)))
print(xtable.cc.Lbmi_01nssec3_F.ad.spectable, 
      floating=FALSE,
      file = paste(storage, "cc.Lbmi_01nssec3_F.ad.spectable.tex", sep=""),
      booktabs=TRUE, 
      include.rownames = FALSE)

## remove things from this estimation round
rm(list=ls(pattern="cc.Lbmi_01nssec3_F"))

## Log weight and log height, NSSEC3, squares ####

# list covariates to avoid repetition
Lwt.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education, "Lhtvalid",
  "Lhtvalid_sq")

# Ftable
cc.Lwt_01nssec3_F.ethhabits.ftable <- apc.indiv.Ftable(
  data17_Fbdh, datatype="AP hexag", dep.var="Lwtvalid", 
  covariates=Lwt.covariates, n.coh.excl.start = 5, n.coh.excl.end = 5)

## Direct tests
# AC to Ad
ACtoAd <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                  model.design = "AC", reduced.model.design = "Ad", 
                                  dep.var = "Lwtvalid", covariates = Lwt.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# AP to Cd
APtoAd <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                  model.design = "AP", reduced.model.design = "Ad", 
                                  dep.var = "Lwtvalid", covariates = Lwt.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
# Ad to A
AdtoA <- apc.indiv.ftest.fullapc(data17_Fbdh, datatype = "AP hexag",
                                 model.design = "Ad", reduced.model.design = "A", 
                                 dep.var = "Lwtvalid", covariates = Lwt.covariates,
                                 n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- c(ACtoAd$p.value, APtoAd$p.value, AdtoA$p.value)
directs.names <- c("ACtoAd", "APtoAd", "AdtoA")
cc.Lwt_01nssec3_F.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.Lwt_01nssec3_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_Fbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lwt_01nssec3_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lwt_01nssec3_F.apc.ethhabits.collin, dep.var = "Lwtvalid", 
  covariates = Lwt.covariates, model.design = "APC")

cc.Lwt_01nssec3_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lwt_01nssec3_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lwt_01nssec3_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lwt_01nssec3_F.apc.ethhabits.fit, 
  main.outer = "Log weight on APC with NSSEC3 01-14, women, detrended")

cc.Lwt_01nssec3_F.apc.ethhabits.cov <- round(
  cc.Lwt_01nssec3_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lwt_01nssec3_F_apc_ethhabits_plot.eps",sep=""))
dev.off()

# Ad model (reduction based on Ftable and AdPC model)
cc.Lwt_01nssec3_F.ad.ethhabits.model <- apc.indiv.design.model(
  cc.Lwt_01nssec3_F.apc.ethhabits.collin, dep.var = "Lwtvalid",
  covariates=Lwt.covariates, model.design = "Ad")

cc.Lwt_01nssec3_F.ad.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lwt_01nssec3_F.ad.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lwt_01nssec3_F.ad.ethhabits.plot <- var.apc.plot.fit(
  cc.Lwt_01nssec3_F.ad.ethhabits.fit, 
  main.outer = "Log weight on Ad with NSSEC3 01-14, women, detrended")

cc.Lwt_01nssec3_F.ad.ethhabits.cov <- round(
  cc.Lwt_01nssec3_F.ad.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_Lwt_01nssec3_F_ad_ethhabits_plot.eps", sep=""))
dev.off()

# Spec Tests on Ad model
dev.off()
residuals <- cc.Lwt_01nssec3_F.ad.ethhabits.fit$residuals
JB <- jarque.bera.test(residuals)
hist(residuals, breaks=4000)
qqnorm(residuals); qqline(residuals)

residuals_sq <- cc.Lwt_01nssec3_F.ad.ethhabits.fit$residuals^2
reset.hetero <- tidy.spec.test(data17_Fbdh, dep.var = "Lwtvalid", 
                                covariates = Lwt.covariates,
                                model.design="Ad", datatype = "AP hexag",
                                n.coh.excl.start = 5,
                                n.coh.excl.end = 5, fit.model = 
                                  cc.Lwt_01nssec3_F.ad.ethhabits.fit)
cc.Lwt_01nssec3_F.ad.spectable <- messy.spec.table(JB, reset.hetero)

# print tables
xtable.cc.Lwt_01nssec3_F.ethhabits.ftable <- xtable(
  cc.Lwt_01nssec3_F.ethhabits.ftable, 
  display = xdisplay(cc.Lwt_01nssec3_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lwt_01nssec3_F.ethhabits.ftable)+1)), 
  caption="Log weight on APC and NSSEC3, women, 01-14", 
  label="cc.Lwt_01nssec3_F.ethhabits.ftable")
print.xtable(xtable.cc.Lwt_01nssec3_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lwt_01nssec3_F.ethhabits.ftable.tex", 
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lwt_01nssec3_F.ethhabits.directs <- xtable(
  cc.Lwt_01nssec3_F.ethhabits.directs,
  display = xdisplay(cc.Lwt_01nssec3_F.ethhabits.directs),
  align=rep("p{1.5cm}", (ncol(cc.Lwt_01nssec3_F.ethhabits.directs)+1)),
  caption="Direct tests between submodels, log weight on APC and NNSEC3, women,
  01-14", label="cc.Lwt_01nssec3_F.ethhabits.directs")
print.xtable(xtable.cc.Lwt_01nssec3_F.ethhabits.directs, 
             file=paste(storage, "cc.Lwt_01nssec3_F.ethhabits.directs.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lwt_01nssec3_F.apc.ethhabits.cov <- xtable(
  cc.Lwt_01nssec3_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lwt_01nssec3_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lwt_01nssec3_F.apc.ethhabits.cov)+1)),
  caption="Log weight on APC and NSSEC3, women, 01-14", 
  label="cc.Lwt_01nssec3_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lwt_01nssec3_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lwt_01nssec3_F.apc.ethhabits.cov.tex",
                        sep=""),
             booktabs=TRUE, caption.placement = "top")

xtable.cc.Lwt_01nssec3_F.ad.ethhabits.cov <- xtable(
  cc.Lwt_01nssec3_F.ad.ethhabits.cov, 
  display=xdisplay(cc.Lwt_01nssec3_F.ad.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lwt_01nssec3_F.ad.ethhabits.cov)+1)),
  caption="Log weight on Ad and NSSEC3, women, 01-14", 
  label="cc.Lwt_01nssec3_F.ad.ethhabits.cov")
print.xtable(xtable.cc.Lwt_01nssec3_F.ad.ethhabits.cov, 
             file=paste(storage, "cc.Lwt_01nssec3_F.ad.ethhabits.cov.tex",
                        sep=""),
             booktabs=TRUE, caption.placement = "top")

xtable.cc.Lwt_01nssec3_F.ad.spectable <- xtable(
  cc.Lwt_01nssec3_F.ad.spectable,
  display = xdisplay(cc.Lwt_01nssec3_F.ad.spectable),
  align = rep("c", (ncol(cc.Lwt_01nssec3_F.ad.spectable)+1)),
  caption = "Log weight on Ad and NSSEC3, women, 01-14",
  label = "cc.Lwt_01nssec3_F.ad.spectable")
print.xtable(xtable.cc.Lwt_01nssec3_F.ad.spectable,
             file = paste(storage, "cc.Lwt_01nssec3_F.ad.spectable.tex",
                          sep=""),
             booktabs=TRUE, caption.placement = "top")


## Obese and NSSEC3, educ categorical ####

# list covariates to avoid repetition
obese.covariates <- c(
  ethnicity, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke", education)

# LRtable
cc.obese_01nssec3_F.ethhabits.LRtable <- apc.indiv.LRtable.TS(
  data17_Fbdh, datatype="AP hexag", dep.var="obese", 
  covariates=obese.covariates, n.coh.excl.start = 5, n.coh.excl.end = 5,
  maxit.linesearch.TS = 60, maxit.loop=30, init.TS = "zero")

# Direct tests
# Ad to AC
AdtoAC <- apc.indiv.LRtest.fullapc(data17_Fbdh, datatype = "AP hexag",
                               model.design = "AC", reduced.model.design = "Ad", 
                               dep.var = "obese", covariates = obese.covariates,
                               n.coh.excl.start = 5, n.coh.excl.end = 5)
# Ad to AP
AdtoAP <- apc.indiv.LRtest.fullapc(data17_Fbdh, datatype = "AP hexag",
                               model.design = "AP", reduced.model.design = "Ad", 
                               dep.var = "obese", covariates = obese.covariates,
                               n.coh.excl.start = 5, n.coh.excl.end = 5)
# A to Ad
AtoAd <- apc.indiv.LRtest.fullapc(data17_Fbdh, datatype = "AP hexag",
                              model.design = "Ad", reduced.model.design = "A", 
                              dep.var = "obese", covariates = obese.covariates,
                              n.coh.excl.start = 5, n.coh.excl.end = 5)
# t to Ad
ttoAd <- apc.indiv.LRtest.fullapc(data17_Fbdh, datatype = "AP hexag",
                              model.design = "Ad", reduced.model.design = "t", 
                              dep.var = "obese", covariates = obese.covariates,
                              n.coh.excl.start = 5, n.coh.excl.end = 5)
# t to A
ttoA <- apc.indiv.LRtest.fullapc(data17_Fbdh, datatype = "AP hexag",
                              model.design = "A", reduced.model.design = "t", 
                              dep.var = "obese", covariates = obese.covariates,
                              n.coh.excl.start = 5, n.coh.excl.end = 5)

directs.p.values <- round(c(AdtoAC$p.value, AdtoAP$p.value, AtoAd$p.value, 
                            ttoAd$p.value, ttoA$p.value), 3)
directs.names <- c("AdtoAC", "AdtoAP", "AtoAd", "ttoAd", "ttoA")
cc.obese_01nssec3_F.ethhabits.directs <- rbind(directs.names, directs.p.values)

# APC model
cc.obese_01nssec3_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data17_Fbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.obese_01nssec3_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.obese_01nssec3_F.apc.ethhabits.collin, dep.var = "obese", 
  covariates = obese.covariates, model.design = "APC")

cc.obese_01nssec3_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.obese_01nssec3_F.apc.ethhabits.model, model.family="binomial",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.obese_01nssec3_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.obese_01nssec3_F.apc.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.obese_01nssec3_F.apc.ethhabits.cov <- round(
  cc.obese_01nssec3_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_obese_01nssec3_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# Ad model (reduction based on LRtable and APC model)
cc.obese_01nssec3_F.ad.ethhabits.model <- apc.indiv.design.model(
  cc.obese_01nssec3_F.apc.ethhabits.collin, dep.var = "obese",
  covariates=obese.covariates, model.design = "Ad")

cc.obese_01nssec3_F.ad.ethhabits.fit <- apc.indiv.fit.model(
  cc.obese_01nssec3_F.ad.ethhabits.model, model.family="binomial",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.obese_01nssec3_F.ad.ethhabits.plot <- var.apc.plot.fit(
  cc.obese_01nssec3_F.ad.ethhabits.fit, main.outer="",
  cex=1.8, theight=1.2, mar=c(3, 3, 3, 1), oma = c(2, 1, 2, 1))

cc.obese_01nssec3_F.ad.ethhabits.cov <- round(
  cc.obese_01nssec3_F.ad.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript, 
         paste(storage, "cc_obese_01nssec3_F_ad_ethhabits_plot.eps", sep=""))
dev.off()


xtablify.LR(cc.obese_01nssec3_F.ethhabits.LRtable,
            "cc.obese_01nssec3_F.ethhabits.LRtable")

xtable.cc.obese_01nssec3_F.ethhabits.directs <- xtable(
  cc.obese_01nssec3_F.ethhabits.directs,
  align=c("l", rep("r", ncol(cc.obese_01nssec3_F.ethhabits.directs))))
print(xtable.cc.obese_01nssec3_F.ethhabits.directs, 
     floating=FALSE,
     file=paste(storage, "cc.obese_01nssec3_F.ethhabits.directs.tex",
                        sep=""), 
     booktabs=TRUE,
     include.colnames=FALSE)

xtable.cc.obese_01nssec3_F.apc.ethhabits.cov <- xtable(
  cc.obese_01nssec3_F.apc.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.obese_01nssec3_F.apc.ethhabits.cov))))
print(xtable.cc.obese_01nssec3_F.apc.ethhabits.cov, 
      floating=FALSE,
      file=paste(storage, "cc.obese_01nssec3_F.apc.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)

xtable.cc.obese_01nssec3_F.ad.ethhabits.cov <- xtable(
  cc.obese_01nssec3_F.ad.ethhabits.cov, 
  align=c("l", rep("r", ncol(cc.obese_01nssec3_F.ad.ethhabits.cov))),
  digits=3)
print(xtable.cc.obese_01nssec3_F.ad.ethhabits.cov,
      floating=FALSE,
      file=paste(storage, "cc.obese_01nssec3_F.ad.ethhabits.cov.tex",
                        sep=""), 
      booktabs=TRUE)


## remove things from this estimation round
rm(list=ls(pattern="cc.obese_01nssec3_F"))

# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------