# -----------------------------------------------------------------------------
# Project: APC modelling and covariates with application to obesity in England
# Script: HSE_dataclean.R
# Date started: 26/03/18
# Last edited: 06/12/18
# Author: Zoe Fannon
# -----------------------------------------------------------------------------
# Uses data directly following gettinghsedata.do
# Cleaning script.
# Drops data based on implausible BMI values and NAs in key variables.
# Modifies variables for analysis. Saves datasets as .csv and .dta.

# -----------------------------------------------------------------------------
# INTRO
# -----------------------------------------------------------------------------

#### Setup ####
# Libraries
library(plyr)
library(reshape)
library(readstata13)
library(plotly) # note this calls ggplot2
library(xtable)
library(ggplot2)
library(Cairo)

# Directory
setwd("C:/Users/Zoe/Documents/Economics/DPhil_thesis/C1_BMI_indivWcovariates")
setwd("replication")
# Individual APC functions
source("R_scripts/revised.functions2.R")
source("R_scripts/TS_logit_functions.R")

# -----------------------------------------------------------------------------
# DATA CLEANING
# -----------------------------------------------------------------------------

#### Get data ####
data1 <- read.dta13(
  "Data_modified/Reduced and recoded HSE files/1991_2014HSE.dta")
deflator1 <- read.csv(paste("Data_modified/",
 "GDP_Deflators_Qtrly_National_Accounts_December_2016_update.csv", sep=""))

#### Cut some data ####
# This reduces the dataset by about half
  
## Drop implausible values from BMI.
data2 <- data1[(data1$bmivalid >= 12 & data1$bmivalid <= 60) | 
                 is.na(data1$bmivalid),]
 
## Drop NAs in essential variables: bmivalid, smoke, educend, ethgrp, dnoft
data3 <- data2[!is.na(data2$bmivalid) &!is.na(data2$smoke) 
              &!is.na(data2$educend) &!is.na(data2$ethgrp)
              &!is.na(data2$dnoft),]

## Modify to include topqual3 as an essential variable
count(is.na(data2$topqual2) &  !is.na(data2$topqual3))
count(is.na(data2$topqual3) &  !is.na(data2$topqual2))

data3 <- data3[!is.na(data3$topqual3),]

dataBMI <- data2[!is.na(data2$bmivalid),]            

## Censor age: at top to eliminate NAs, at bottom to drop non-adults
# Bottom censor also enables merging of educend categories.
data4 <- data3[(data3$age<=80 & data3$age>=20), ]
dataBMI4 <- dataBMI[(dataBMI$age<=80 & dataBMI$age>=20), ]

rm(data2, data3, dataBMI)

#### Variable modifications to data4 ####

## add cohort and rename year
data5 <- rename(.data = data4, period=year) 
cohort <- data5$period-data5$age
data5 <- cbind(data5, cohort)

## Variable adjustments
# adjust educend
age.fin.ed <- ifelse(data5$educend=="Never went to school", 0,
                ifelse(data5$educend=="14 or under", 14,
                  ifelse(data5$educend=="15", 15,
                    ifelse(data5$educend=="16", 16,
                      ifelse(data5$educend=="17", 17,
                       ifelse(data5$educend=="18", 18,
                        ifelse(data5$educend=="19 or over", 19,
                         ifelse(data5$educend=="Not yet finished", 19, 
                          NA))))))))

# adjust topqual3
lessHS <- ifelse(data5$topqual3 %in% c(5, 7),1,
                 ifelse(data5$topqual3==6 & age.fin.ed<16, 1, 0))
someHE <- ifelse(data5$topqual3 %in% c(2, 3), 1,
                 ifelse(data5$topqual3==6 & age.fin.ed==19, 1, 0))
collegegrad <- ifelse(data5$topqual3==1, 1, 0)
GCSE <- ifelse(data5$topqual3==4, 1,
               ifelse(data5$topqual3==6 & age.fin.ed %in% c(16, 17, 18), 1, 0))
remainder <- lessHS+someHE+collegegrad+GCSE

count(remainder)
count(data5$topqual3==6)

# adjust sex
is.female <- ifelse(data5$sex=="Female", 1, 0)

# adjust ethgrp
# BASELINE: white
black <- ifelse(data5$ethgrp=="Black", 1, 0)
asian <- ifelse(data5$ethgrp=="Asian", 1, 0)
mixeth <- ifelse(data5$ethgrp=="Mixed/multiple ethnic background",1 , 0)
otheth <- ifelse(data5$ethgrp=="Any other ethnic group", 1, 0)

# adjust smoke
# Done so that past smokers and current smokers are grouped in the first
  # and the second is the additional effect of still smoking now
  # BASELINE: never smoker
ever.smoked <- ifelse(data5$smoke=="never regular", 0, 1)
now.smoke <- ifelse(data5$smoke=="current", 1, 0)

# adjust drink
# BASELINE: not at all
drink.lev1 <- ifelse(data5$dnoft=="Not at all in the last 12 months", 0, 1)
              # all except non-drinkers
drink.lev2 <- ifelse(drink.lev1==1,
                     ifelse(data5$dnoft=="Once or twice a year", 0, 1), 0)
              # exclude those once/twice year
drink.lev3 <- ifelse(drink.lev2==1,
                     ifelse(data5$dnoft=="Once every couple of months", 0, 1),
                     0) # exclude couple of months
drink.lev4 <- ifelse(drink.lev3==1,
                     ifelse(data5$dnoft=="Once or twice a month", 0, 1), 0)
              # exclude once/twice month
drink.lev5 <- ifelse(drink.lev4==1,
                     ifelse(data5$dnoft=="Once or twice a week", 0, 1), 0) 
              # exclude once/twice week
drink.lev6 <- ifelse(drink.lev5==1,
                     ifelse(data5$dnoft=="Three or four days a week", 0, 1),
                     0) # exclude 3/4 days week
drink.lev7 <- ifelse(drink.lev6==1,
                     ifelse(data5$dnoft=="Five or six days a week", 0, 1),
                     0) # exclude 5/6 days week

# Repackaging of drink variables
# fewer levels and don't impose cumulative restriction
drink.rare <- ifelse(drink.lev1==1, ifelse(drink.lev4==0, 1, 0), 0)
drink.casual <- ifelse(drink.lev4==1, ifelse(drink.lev6==0, 1, 0), 0)
drink.freq <- ifelse(drink.lev6==1, 1, 0)

# obesity
obese <- ifelse(data5$bmivalid>=30, 1, 0)

## Combine into single dataset
data6 <- cbind(data5, age.fin.ed, is.female, ever.smoked, now.smoke,
               drink.lev1, drink.lev2, drink.lev3, drink.lev4, drink.lev5,
               drink.lev6, drink.lev7, black, asian, mixeth, otheth,
               obese, drink.rare, drink.casual, drink.freq,
               lessHS, someHE, GCSE, collegegrad)

rm(data4, data5, age.fin.ed, is.female, ever.smoked, now.smoke,
   drink.lev1, drink.lev2, drink.lev3, drink.lev4, drink.lev5,
   drink.lev6, drink.lev7, black, asian, mixeth, otheth,
   obese, drink.rare, drink.casual, drink.freq, cohort, remainder)

## Deflate Income
# Start by working with deflator data
deflator2 <- deflator1[c("X.5", "X.6")]
deflator2 <- rename(.data = deflator2, period=X.5, deflator=X.6)
deflator3 <- deflator2[-c(1:6, 68:93), ]
# need to convert from factors into numeric. Go factor->character->numeric 
periodvec.ch <- as.character(deflator3$period)
periodvec.nm <- as.numeric(periodvec.ch)
deflatvec.ch <- as.character(deflator3$deflator)
deflatvec.nm <- as.numeric(deflatvec.ch)

rm(periodvec.ch, deflatvec.ch, deflator2, deflator3)

# combine into new dataframe
deflator4 <- data.frame(periodvec.nm, deflatvec.nm)
deflator4 <- rename(deflator4, period=periodvec.nm, deflator=deflatvec.nm)

# merge with main data
data7 <- merge(data6, deflator4, by="period")
Deqvinc <- data7$eqvinc * 100 / data7$deflator
data8 <- cbind(data7, Deqvinc)

rm(periodvec.nm, deflatvec.nm, Deqvinc, data6, data7)
rm(deflator1, deflator4)

## Take logs and square of income
LDeqvinc <- log(data8$Deqvinc)
LDeqvinc2 <- LDeqvinc^2

# combine into single dataset
data9 <- cbind(data8, LDeqvinc, LDeqvinc2)

rm(data8, LDeqvinc, LDeqvinc2)

#### Final dropping and storage of data4 ####

# drop columns that are not of interest (which have NA)
# Longill, limitill have very few NAs so could keep if interested
data10 <- data9[, !names(data9) %in% c("eqv5", "area", "limitill", "samptype",
                                     "cholest", "sclass", "psu", "eqvpop",
                                     "tablewt", "cluster", "samtyp", "longill",
                                     "year1", "waistvalid", "hipvalid", "WHR",
                                     "gorVH", "manual", "eqvpop3", 
                                     "topqual2", "topqual3")]

# save the dataset
write.csv(data10, "Data_modified/for_analysis.csv")

# change names so OK for Stata
colnames(data10)[18:28] <- c("age_fin_ed", "is_female", "ever_smoked", 
                             "now_smoke", "drink_lev1", "drink_lev2",
                             "drink_lev3", "drink_lev4","drink_lev5",
                             "drink_lev6", "drink_lev7")
colnames(data10)[34:36] <- c("drink_rare", "drink_casual", "drink_freq")

save.dta13(data10, "Data_modified/for_analysis.dta")

rm(data1, data8, data9)

#### Modifications to dataBMI4 ####

## add cohort and rename year
dataBMI5 <- rename(.data = dataBMI4, period=year) 
cohort <- dataBMI5$period-dataBMI5$age
dataBMI5 <- cbind(dataBMI5, cohort)

# adjust sex
is.female <- ifelse(dataBMI5$sex=="Female", 1, 0)

# obesity
obese <- ifelse(dataBMI5$bmivalid>=30, 1, 0)

# combine all
dataBMI6 <- cbind(dataBMI5, is.female, obese)

# drop columns that are not of interest
dataBMI <- dataBMI6[, !names(dataBMI6) %in% c("eqv5", "area", "limitill", "samptype",
                                       "cholest", "sclass", "psu", "eqvpop",
                                       "tablewt", "cluster", "samtyp", "longill",
                                       "year1", "waistvalid", "hipvalid", "WHR",
                                       "gorVH", "manual", "eqvpop3", "nssec3",
                                       "topqual2", "topqual3", "smoke", "nssec8",
                                       "dnoft", "educend", "eqvinc", "ethgrp")]
rm(dataBMI4, dataBMI5, dataBMI6, is.female, obese, cohort)

# save the dataset
write.csv(dataBMI, "Data_modified/dataBMI.csv")
save.dta13(dataBMI, "Data_modified/dataBMI.dta")


#### Final removal of both datasets ####
rm(data10, dataBMI)

# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------
