# -----------------------------------------------------------------------------
# Project: APC modelling and covariates with application to obesity in England
# Script: HSE_robustcheck.R
# Date started: 26/03/18
# Last edited: 06/12/18
# Author: Zoe Fannon
# -----------------------------------------------------------------------------
# Robustness checks on model specification. Run after HSE_analysis.R
# Step 1: small remaining modifications to data
# Step 2: alternative models using the same data as the main specification
#         (1) change to NSSEC definition
# Step 3: alternative models using different data but the same number of waves
#         (1) income instead of NSSEC
#         (2) dataset selected based on both NSSEC and income
#         (3) randomly selected subset of 2000/year (three seeds)
#         (4) longer age range
#         (5) no covariates with more data
#         (6) no covariates with original data
# Step 4: alternative models with more waves
#         (1) back to 1997 with income instead of NSSEC
#         (2) back to 1992 with no covariates
#         (3) back to 1992 no covariates, same cohorts as original analysis
# -----------------------------------------------------------------------------
# INTRO
# -----------------------------------------------------------------------------
#### Setup ####
# Libraries
library(plyr)
library(reshape)
library(readstata13)
library(plotly)
library(xtable)
library(ggplot2)
library(Cairo)
library(tseries)

# Directory
setwd("C:/Users/Zoe/Documents/Economics/DPhil_thesis/C1_BMI_indivWcovariates")
setwd("replication")
# Individual APC functions
source("R_scripts/revised.functions2.R")
source("R_scripts/TS_logit_functions.R")
source("R_scripts/further_functions.R")

# Define directory into which graphs and tables are placed
storage <- "Graphs_tables/robustcheck/"

#### Clean data: read in, split, add cell name ####

# Read in data
data12 <- read.csv("Data_modified/for_analysis.csv")

# Split into M/F
data13_M <- data12[data12$is.female==0, ]
data13_F <- data12[data12$is.female==1, ]

# MEN
# Drop unnecessary X variable
data14_M <- data13_M[, -1]

# Add cell name
if (!"cell.name" %in% colnames(data14_M)) {
  cell.name <- paste("ik", as.character(data14_M$age), 
                     as.character(data14_M$cohort), sep="_")
  data14_M <- cbind(cell.name, data14_M)
} else {
  warning("Variable cell.name must be unique identifier of age-cohort cells; 
          if preexisting variable cell.name has alternate meaning please rename")
}

# WOMEN
# Drop unnecessary X variable
data14_F <- data13_F[, -1]

# Add cell name
if (!"cell.name" %in% colnames(data14_F)) {
  cell.name <- paste("ik", as.character(data14_F$age), 
                     as.character(data14_F$cohort), sep="_")
  data14_F <- cbind(cell.name, data14_F)
} else {
  warning("Variable cell.name must be unique identifier of age-cohort cells; 
          if preexisting variable cell.name has alternate meaning please rename")
}

#### Clean data: variable adjustments ####

# switch reference variable for drink dummies
drink.never <- 1 - data14_M$drink.rare - data14_M$drink.casual - data14_M$drink.freq
data15_M <- cbind(data14_M, drink.never)
data15_M <- data15_M[, !names(data15_M) %in% "drink.casual"]

drink.never <- 1 - data14_F$drink.rare - data14_F$drink.casual - data14_F$drink.freq
data15_F <- cbind(data14_F, drink.never)
data15_F <- data15_F[, !names(data15_F) %in% "drink.casual"]

# Access labels
ethnicity <- c("black", "asian", "mixeth", "otheth")
education <- c("lessHS", "someHE", "collegegrad")

# Cleanup
rm(data13_F, data13_M, data14_F, data14_M, cell.name, drink.never)

#### Data that's BMI only ####

# Read in data
dataBMI <- read.csv("Data_modified/dataBMI.csv")

# Split into M/F
dataBMI_M <- dataBMI[dataBMI$is.female==0, ]
dataBMI_F <- dataBMI[dataBMI$is.female==1, ]

# MEN
# Drop unnecessary X variable
dataBMI2_M <- dataBMI_M[, -1]

# Add cell name
if (!"cell.name" %in% colnames(dataBMI2_M)) {
  cell.name <- paste("ik", as.character(dataBMI2_M$age), 
                     as.character(dataBMI2_M$cohort), sep="_")
  dataBMI2_M <- cbind(cell.name, dataBMI2_M)
} else {
  warning("Variable cell.name must be unique identifier of age-cohort cells; 
          if preexisting variable cell.name has alternate meaning please rename")
}

# WOMEN
# Drop unnecessary X variable
dataBMI2_F <- dataBMI_F[, -1]

# Add cell name
if (!"cell.name" %in% colnames(dataBMI2_F)) {
  cell.name <- paste("ik", as.character(dataBMI2_F$age), 
                     as.character(dataBMI2_F$cohort), sep="_")
  dataBMI2_F <- cbind(cell.name, dataBMI2_F)
} else {
  warning("Variable cell.name must be unique identifier of age-cohort cells; 
          if preexisting variable cell.name has alternate meaning please rename")
}

# Cleanup
rm(dataBMI_M, dataBMI_F)


# -----------------------------------------------------------------------------
# SAME DATA AS MAIN ANALYSIS, DIFFERENT SPECIFICATIONS
# -----------------------------------------------------------------------------
# In this section we consider the following variants
  # (1) use NSSEC8 rather than NSSEC3 

#### MEN ####
## Final data modifications ####

## Drop income
data16_M <- data15_M[!names(data15_M) %in% c("eqvinc", "Deqvinc", 
                                             "LDeqvinc", "LDeqvinc2")]

## Censor observations with NSSEC NA 
# Note it is the same observations for both 3 and 8
data16_M <- data16_M[!(is.na(data16_M$nssec3)), ]
data16_M <- data16_M[!(is.na(data16_M$nssec8)), ]

# Select age range due to perfect separation
# This will be the same as in main specification => don't need to check for it
data16_M <- data16_M[data16_M$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data17_M <- data16_M[data16_M$cohort<= (max(data16_M$cohort)-5) &
                       data16_M$cohort>= (min(data16_M$cohort)+5), ]

## Variable adjustments and addition
# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_M <- model.matrix(~nssec3-1,data17_M)
vars.nssec3_M <- vars.nssec3_M[, -4] # set routine and manual as reference group
colnames(vars.nssec3_M) <- gsub(" ", "_", colnames(vars.nssec3_M))
# Access label
list.nssec3 <- colnames(vars.nssec3_M)

# convert NSSEC8 factor to dummy variables, rename
vars.nssec8 <- model.matrix(~nssec8-1,data17_M)
vars.nssec8 <- vars.nssec8[, -4] # set routine and manual as reference group
colnames(vars.nssec8) <- gsub(" ", "_", colnames(vars.nssec8))
# Access label
list.nssec8 <- colnames(vars.nssec8)

# Construct more variables that will be needed in later specifications
Lbmi <- log(data17_M$bmivalid)
Lwtvalid <- log(data17_M$wtvalid)
htvalidm <- data17_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data17_M$age.fin.ed^2

# Add all variables to data
data17_Mbdh <- cbind(data17_M, vars.nssec3_M, vars.nssec8, Lbmi, Lwtvalid, 
                     Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# build new dataset with all variables
data18M <- data17_Mbdh

# drop construction tools
rm(data16_M, data17_M, data17_Mbdh,  vars.nssec3_M,
   vars.nssec8, age.fin.ed_sq, htvalidm, Lbmi, Lhtvalid, Lhtvalid_sq, Lwtvalid)

## Log BMI, NSSEC8 ####

# list covariates to avoid repetition
n8.covariates <- c(
  ethnicity, education, list.nssec8, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01nssec8_M.ethhabits.ftable <- apc.indiv.Ftable(
  data18M, datatype="AP hexag", dep.var="Lbmi", covariates=n8.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nssec8_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data18M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec8_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec8_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = n8.covariates, model.design = "APC")

cc.Lbmi_01nssec8_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec8_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec8_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec8_M.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with NSSEC8 01-14, men, detrended")

cc.Lbmi_01nssec8_M.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec8_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec8_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nssec8_M.ethhabits.ftable <- xtable(
  cc.Lbmi_01nssec8_M.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01nssec8_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec8_M.ethhabits.ftable)+1)), 
  caption="log BMI on APC and nssec8, men, 01-14", 
  label="cc.Lbmi_01nssec8_M.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01nssec8_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01nssec8_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01nssec8_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec8_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01nssec8_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01nssec8_M.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and nssec8, men, 01-14", 
  label="cc.Lbmi_01nssec8_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01nssec8_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01nssec8_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nssec8"))

#### WOMEN ####
## Final data modifications ####

## Drop income
data16_F <- data15_F[!names(data15_F) %in% c("eqvinc", "Deqvinc", 
                                             "LDeqvinc", "LDeqvinc2")]

## Censor observations with NSSEC NA 
# Note it is the same observations for both 3 and 8
data16_F <- data16_F[!(is.na(data16_F$nssec3)), ]
data16_F <- data16_F[!(is.na(data16_F$nssec8)), ]

# Select age range due to perfect separation
# This will be the same as in main specification => don't need to check for it
data16_F <- data16_F[data16_F$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data17_F <- data16_F[data16_F$cohort<= (max(data16_F$cohort)-5) &
                       data16_F$cohort>= (min(data16_F$cohort)+5), ]

## Variable adjustments and addition
# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_F <- model.matrix(~nssec3-1,data17_F)
vars.nssec3_F <- vars.nssec3_F[, -4] # set routine and manual as reference group
colnames(vars.nssec3_F) <- gsub(" ", "_", colnames(vars.nssec3_F))
# Access label
list.nssec3 <- colnames(vars.nssec3_F)

# convert NSSEC8 factor to dummy variables, rename
vars.nssec8 <- model.matrix(~nssec8-1,data17_F)
vars.nssec8 <- vars.nssec8[, -4] # set routine and manual as reference group
colnames(vars.nssec8) <- gsub(" ", "_", colnames(vars.nssec8))
# Access label
list.nssec8 <- colnames(vars.nssec8)

# Construct more variables that will be needed in later specifications
Lbmi <- log(data17_F$bmivalid)
Lwtvalid <- log(data17_F$wtvalid)
htvalidm <- data17_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data17_F$age.fin.ed^2

# Add all variables to data
data17_Fbdh <- cbind(data17_F, vars.nssec3_F, vars.nssec8, Lbmi, Lwtvalid, 
                     Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# build new dataset with all variables
data18F <- data17_Fbdh

# drop construction tools
rm(data16_F, data17_F, data17_Fbdh,  vars.nssec3_F,
   vars.nssec8, age.fin.ed_sq, htvalidm, Lbmi, Lhtvalid, Lhtvalid_sq, Lwtvalid)

## Log BMI, NSSEC8 ####

# list covariates to avoid repetition
n8.covariates <- c(
  ethnicity, education, list.nssec8, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01nssec8_F.ethhabits.ftable <- apc.indiv.Ftable(
  data18F, datatype="AP hexag", dep.var="Lbmi", covariates=n8.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nssec8_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data18F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec8_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec8_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = n8.covariates, model.design = "APC")

cc.Lbmi_01nssec8_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec8_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec8_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec8_F.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with NSSEC8 01-14, women, detrended")

cc.Lbmi_01nssec8_F.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec8_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec8_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nssec8_F.ethhabits.ftable <- xtable(
  cc.Lbmi_01nssec8_F.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01nssec8_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec8_F.ethhabits.ftable)+1)), 
  caption="log BMI on APC and nssec8, women, 01-14", 
  label="cc.Lbmi_01nssec8_F.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01nssec8_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01nssec8_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01nssec8_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec8_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01nssec8_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01nssec8_F.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and nssec8, women, 01-14", 
  label="cc.Lbmi_01nssec8_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01nssec8_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01nssec8_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nssec8"))


# -----------------------------------------------------------------------------
# EXTRA MODELS USING SLIGHTLY DIFFERENT DATA
# -----------------------------------------------------------------------------
#### MEN ####
## Log BMI, log income and log income sq ####
## Data modifications 
# The main difference here is that selection is based on income rather
# than NSSEC NAs

## Drop NSSEC
data19_M <- data15_M[!names(data15_M) %in% c("nssec8", "nssec3")]

## Censor observations with income NA 
# Note it is the same observations for both 3 and 8
data20_M <- data19_M[!(is.na(data19_M$eqvinc)), ]
data20_M <- data20_M[!(is.na(data20_M$LDeqvinc)), ]

# Check for perfect separation
men.cell.name.count <- as.data.frame(with(data20_M,table(cell.name, obese)))
men.cell.name.zeros <- men.cell.name.count[men.cell.name.count$Freq==0, ]
View(men.cell.name.zeros)

# Select age range due to perfect separation
# Difficult in that there are clearly concerns with the early ages, to 24, but
# also missing a few middle observations. Can't censor all for that and 
# since working with continuous data it doesn't strictly matter. Age range 
# chosen to reflect main analysis.
data20_M <- data20_M[data20_M$age>=28, ]

# Shorten by period to be commensurate with the nssec data
data20_M <- data20_M[data20_M$period>=2001, ]

## Censor five cohorts each end to improve stability of estimates
data21_M <- data20_M[data20_M$cohort<= (max(data20_M$cohort)-5) &
                       data20_M$cohort>= (min(data20_M$cohort)+5), ]

## Variable adjustments and addition

# Construct more variables that will be needed in later specifications
Lbmi <- log(data21_M$bmivalid)
Lwtvalid <- log(data21_M$wtvalid)
htvalidm <- data21_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data21_M$age.fin.ed^2

# Add all variables to data
data22_M <- cbind(data21_M, Lbmi, Lwtvalid, 
                  Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data19_M, data20_M, data21_M, age.fin.ed_sq, htvalidm, Lbmi,
   Lhtvalid, Lhtvalid_sq, Lwtvalid)

# list covariates to avoid repetition
inc.covariates <- c(
  ethnicity, education, "LDeqvinc", "LDeqvinc2", "drink.rare", 
  "drink.never", "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01inc_M.ethhabits.ftable <- apc.indiv.Ftable(
  data22_M, datatype="AP hexag", dep.var="Lbmi", covariates=inc.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01inc_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data22_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01inc_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01inc_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = inc.covariates, model.design = "APC")

cc.Lbmi_01inc_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01inc_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01inc_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01inc_M.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with income 01-14, men, detrended")

cc.Lbmi_01inc_M.apc.ethhabits.cov <- round(
  cc.Lbmi_01inc_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01inc_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01inc_M.ethhabits.ftable <- xtable(
  cc.Lbmi_01inc_M.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01inc_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01inc_M.ethhabits.ftable)+1)), 
  caption="log BMI on APC and income, men, 01-14", 
  label="cc.Lbmi_01inc_M.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01inc_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01inc_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01inc_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01inc_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01inc_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01inc_M.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and income, men, 01-14", 
  label="cc.Lbmi_01inc_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01inc_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01inc_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01inc"))

## Further data restriction (on income and NSSEC) ####

## Censor observations with income or NSSEC NA 
# Note it is the same observations for both 3 and 8
data23_M <- data15_M[!(is.na(data15_M$eqvinc)), ]
data23_M <- data23_M[!(is.na(data23_M$nssec3)), ]

# Check for perfect separation
men.cell.name.count <- as.data.frame(with(data23_M,table(cell.name, obese)))
men.cell.name.zeros <- men.cell.name.count[men.cell.name.count$Freq==0, ]
View(men.cell.name.zeros)

# Select age range due to perfect separation
# Lots of missing cells, again continuous so can mirror main analysis
data23_M <- data23_M[data23_M$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data24_M <- data23_M[data23_M$cohort<= (max(data23_M$cohort)-5) &
                       data23_M$cohort>= (min(data23_M$cohort)+5), ]

## Variable adjustments and addition
# Construct more variables that will be needed in later specifications
Lbmi <- log(data24_M$bmivalid)
Lwtvalid <- log(data24_M$wtvalid)
htvalidm <- data24_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data24_M$age.fin.ed^2

# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_M <- model.matrix(~nssec3-1,data24_M)
vars.nssec3_M <- vars.nssec3_M[, -4] # set routine and manual as reference group
colnames(vars.nssec3_M) <- gsub(" ", "_", colnames(vars.nssec3_M))
# Access label
list.nssec3 <- colnames(vars.nssec3_M)

# Add all variables to data
data25_M <- cbind(data24_M, Lbmi, Lwtvalid, vars.nssec3_M,
                  Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data23_M, data24_M, age.fin.ed_sq, htvalidm, Lbmi, vars.nssec3_M,
   Lhtvalid, Lhtvalid_sq, Lwtvalid)


## Log BMI, log income and log income sq

# Ftable
cc.Lbmi_01incSS_M.ethhabits.ftable <- apc.indiv.Ftable(
  data25_M, datatype="AP hexag", dep.var="Lbmi", covariates=inc.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01incSS_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data25_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01incSS_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01incSS_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = inc.covariates, model.design = "APC")

cc.Lbmi_01incSS_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01incSS_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01incSS_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01incSS_M.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with income 01-14, men, detrended")

cc.Lbmi_01incSS_M.apc.ethhabits.cov <- round(
  cc.Lbmi_01incSS_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01incSS_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01incSS_M.ethhabits.ftable <- xtable(
  cc.Lbmi_01incSS_M.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01incSS_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01incSS_M.ethhabits.ftable)+1)), 
  caption="log BMI on APC and income, men, 01-14", 
  label="cc.Lbmi_01incSS_M.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01incSS_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01incSS_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01incSS_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01incSS_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01incSS_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01incSS_M.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and income, men, 01-14", 
  label="cc.Lbmi_01incSS_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01incSS_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01incSS_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01incSS"))

## NSSEC3

# list covariates to avoid repetition
n3.covariates <- c(
  ethnicity, education, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01nssec3SS_M.ethhabits.ftable <- apc.indiv.Ftable(
  data25_M, datatype="AP hexag", dep.var="Lbmi", covariates=n3.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nssec3SS_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data25_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec3SS_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec3SS_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = n3.covariates, model.design = "APC")

cc.Lbmi_01nssec3SS_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec3SS_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec3SS_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec3SS_M.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with nssec3 01-14, men, detrended")

cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec3SS_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec3SS_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nssec3SS_M.ethhabits.ftable <- xtable(
  cc.Lbmi_01nssec3SS_M.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01nssec3SS_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec3SS_M.ethhabits.ftable)+1)), 
  caption="log BMI on APC and nssec3, men, 01-14", 
  label="cc.Lbmi_01nssec3SS_M.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01nssec3SS_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01nssec3SS_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and nssec3, men, 01-14", 
  label="cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01nssec3SS_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nssec3SS"))

rm(data22_M, data25_M)

## Subset 2000 of data18 ####
min(count(data18M$period))
# min in a period is 1380, so randomly select 1000

# equal number of observations
d18M_eq <- matrix(nrow=length(unique(data18M$period))*1000, ncol=ncol(data18M))
d18M_eq <- as.data.frame(d18M_eq)
colnames(d18M_eq) <- colnames(data18M)

for (k in c(45832, 50032, 1129)){
  set.seed(k)
  
  for (i in 1:length(unique(data18M$period))){
    d18M_year <- data18M[data18M$period==(2000+i), ]
    d18M_eq_year <- d18M_year[sample.int(nrow(d18M_year), 1000), ]
    d18M_eq[(1000*(i-1)+1):(1000*i), 1:ncol(data18M)] <- d18M_eq_year
  }
  
  data26_M <- d18M_eq[d18M_eq$is.female==0, ]

  ## First: check count of observations per cell
  d26_M.popcount <- count(data26_M, c("cohort", "age"))
  d26_M.popcount.c <- cast(d26_M.popcount, cohort~age, value="freq")

  #### Analysis BMI all covariates
  cc.Lbmi_01nssec3_M.ftable <- apc.indiv.Ftable(data26_M, datatype="AP hexag",
                                  dep.var="Lbmi", covariates=n3.covariates,
                                  n.coh.excl.start = 5, n.coh.excl.end = 5)
  cc.Lbmi_01nssec3_M.apc.collin <- apc.indiv.design.collinear(data26_M, 
                                  datatype="AP hexag",
                                  n.coh.excl.end = 5, n.coh.excl.start=5)
  cc.Lbmi_01nssec3_M.apc.model <- apc.indiv.design.model(
                          cc.Lbmi_01nssec3_M.apc.collin, dep.var = "Lbmi", 
                          covariates = n3.covariates, model.design = "APC")
  cc.Lbmi_01nssec3_M.apc.fit <- apc.indiv.fit.model(
                        cc.Lbmi_01nssec3_M.apc.model, model.family="gaussian",
                        n.coh.excl.start = 5, n.coh.excl.end = 5)
  cc.Lbmi_01nssec3_M.apc.plot <- var.apc.plot.fit(cc.Lbmi_01nssec3_M.apc.fit, 
                    main.outer = paste(
                    "APC model for Log BMI on nssec3, men, seed=",
                    k, sep=""))
  cc.Lbmi_01nssec3_M.apc.cov <- round(
                    cc.Lbmi_01nssec3_M.apc.fit$coefficients.covariates, 4)
  
  # print plot
  dev.copy(postscript, paste(storage, "cc_bmi_01nssec3_Meq", k,
                             "_apc_ethhabits_plot.eps", sep=""))
  dev.off()
  
  # print tables
  xtable.cc.Lbmi_01nssec3_M.ftable <- xtable(cc.Lbmi_01nssec3_M.ftable, 
                display = xdisplay(cc.Lbmi_01nssec3_M.ftable), 
                align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec3_M.ftable)+1)), 
                caption=paste("Log BMI on APC and nssec3, men, seed=", 
                              k, sep=""), 
                label=paste("cc.Lbmi_01nssec3_Meq", k, ".ftable", sep=""))
  print.xtable(xtable.cc.Lbmi_01nssec3_M.ftable, file=paste(storage, 
                "cc.Lbmi_01nssec3_Meq", k, ".ftable.tex", sep=""), 
                booktabs=TRUE, caption.placement="top")
  
  xtable.cc.Lbmi_01nssec3_M.apc.cov <- xtable(cc.Lbmi_01nssec3_M.apc.cov,
                display=xdisplay(cc.Lbmi_01nssec3_M.apc.cov), 
                align=rep("c", (ncol(cc.Lbmi_01nssec3_M.apc.cov)+1)),
                caption=paste("Log BMI on APC and nssec3, men, seed=",
                              k, sep=""), 
                label=paste("cc.Lbmi_01nssec3_Meq", k, ".apc.cov", sep=""))
  print.xtable(xtable.cc.Lbmi_01nssec3_M.apc.cov, file=paste(storage,
                "cc.Lbmi_01nssec3_Meq", k, ".apc.cov.tex", sep=""),
                booktabs=TRUE, caption.placement = "top")

}

rm(list=ls(pattern="Lbmi_01nssec3"))

## Use the full age range ####

## Data adjustments
# Drop income
data27_M <- data15_M[!names(data15_M) %in% c("eqvinc", "Deqvinc", 
                                             "LDeqvinc", "LDeqvinc2")]
# Censor observations with NSSEC NA 
data27_M <- data27_M[!(is.na(data27_M$nssec3)), ]

# Censor five cohorts each end to improve stability of estimates
data28_M <- data27_M[data27_M$cohort<= (max(data27_M$cohort)-5) &
                       data27_M$cohort>= (min(data27_M$cohort)+5), ]

## Variable adjustments and addition
# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_M <- model.matrix(~nssec3-1,data28_M)
vars.nssec3_M <- vars.nssec3_M[, -4] # set routine and manual as reference group
colnames(vars.nssec3_M) <- gsub(" ", "_", colnames(vars.nssec3_M))
# Access label
list.nssec3 <- colnames(vars.nssec3_M)

# Construct more variables that will be needed in later specifications
Lbmi <- log(data28_M$bmivalid)
Lwtvalid <- log(data28_M$wtvalid)
htvalidm <- data28_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data28_M$age.fin.ed^2

# Add all variables to data
data28_Mbdh <- cbind(data28_M, vars.nssec3_M, Lbmi, Lwtvalid, 
                     Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data27_M, data28_M, vars.nssec3_M,
   age.fin.ed_sq, htvalidm, Lbmi, Lhtvalid, Lhtvalid_sq, Lwtvalid)

## Analysis on log BMI

# list covariates to avoid repetition
n3.covariates <- c(
  ethnicity, education, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01nssec320_M.ethhabits.ftable <- apc.indiv.Ftable(
  data28_Mbdh, datatype="AP hexag", dep.var="Lbmi", covariates=n3.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nssec320_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data28_Mbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec320_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec320_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = n3.covariates, model.design = "APC")

cc.Lbmi_01nssec320_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec320_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec320_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec320_M.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with nssec3 01-14, men, detrended, age 20-80")

cc.Lbmi_01nssec320_M.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec320_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec320_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nssec320_M.ethhabits.ftable <- xtable(
  cc.Lbmi_01nssec320_M.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01nssec320_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec320_M.ethhabits.ftable)+1)), 
  caption="log BMI on APC and nssec3, men, 01-14, age 20-80", 
  label="cc.Lbmi_01nssec320_M.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01nssec320_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01nssec320_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01nssec320_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec320_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01nssec320_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01nssec320_M.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and nssec3, men, 01-14, age 20-80", 
  label="cc.Lbmi_01nssec320_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01nssec320_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01nssec320_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nssec320"))
rm(data28_Mbdh)

## Use the full BMI data and no covariates ####

## Final data tidying
# Censor age as per main analysis
dataBMI3_M <- dataBMI2_M[dataBMI2_M$age >=28, ]

# Shorten by period to ensure commensurate
dataBMI3_M <- dataBMI3_M[dataBMI3_M$period >=2001, ]

# Censor five cohorts each end to improve stability of estimates
dataBMI4_M <- dataBMI3_M[dataBMI3_M$cohort<= (max(dataBMI3_M$cohort)-5) &
                       dataBMI3_M$cohort>= (min(dataBMI3_M$cohort)+5), ]


# Construct more variables that will be needed in later specifications
Lbmi <- log(dataBMI4_M$bmivalid)
Lwtvalid <- log(dataBMI4_M$wtvalid)
htvalidm <- dataBMI4_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2

# Add all variables to data
dataBMI5_M <- cbind(dataBMI4_M, Lbmi, Lwtvalid, 
                     Lhtvalid, Lhtvalid_sq)

# drop construction tools
rm(dataBMI3_M, dataBMI4_M, htvalidm, Lbmi, Lhtvalid, Lhtvalid_sq, Lwtvalid)

## Analysis on log BMI

# Ftable
cc.Lbmi_01nocovsBD_M.ftable <- apc.indiv.Ftable(
  dataBMI5_M, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nocovsBD_M.apc.collin <- apc.indiv.design.collinear(
  dataBMI5_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nocovsBD_M.apc.model <- apc.indiv.design.model(
  cc.Lbmi_01nocovsBD_M.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_01nocovsBD_M.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nocovsBD_M.apc.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nocovsBD_M.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_01nocovsBD_M.apc.fit, 
  main.outer = "log BMI on APC no covariates 01-14, men, detrended, all data")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nocovsBD_M_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nocovsBD_M.ftable <- xtable(
  cc.Lbmi_01nocovsBD_M.ftable, 
  display = xdisplay(cc.Lbmi_01nocovsBD_M.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nocovsBD_M.ftable)+1)), 
  caption="log BMI on APC no covariates, men, 01-14, 20-80", 
  label="cc.Lbmi_01nocovsBD_M.ftable")
print.xtable(xtable.cc.Lbmi_01nocovsBD_M.ftable, 
             file=paste(storage, "cc.Lbmi_01nocovsBD_M.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nocovsBD"))
rm(dataBMI5_M)


## no covariates, original data ####

## Analysis on log BMI

# Ftable
cc.Lbmi_01nocovsSD_M.ftable <- apc.indiv.Ftable(
  data18M, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nocovsSD_M.apc.collin <- apc.indiv.design.collinear(
  data18M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nocovsSD_M.apc.model <- apc.indiv.design.model(
  cc.Lbmi_01nocovsSD_M.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_01nocovsSD_M.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nocovsSD_M.apc.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nocovsSD_M.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_01nocovsSD_M.apc.fit, 
  main.outer = "log BMI on APC no covariates 01-14, men, detrended, small data")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nocovsSD_M_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nocovsSD_M.ftable <- xtable(
  cc.Lbmi_01nocovsSD_M.ftable, 
  display = xdisplay(cc.Lbmi_01nocovsSD_M.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nocovsSD_M.ftable)+1)), 
  caption="log BMI on APC no covariates, men, 01-14, small data", 
  label="cc.Lbmi_01nocovsSD_M.ftable")
print.xtable(xtable.cc.Lbmi_01nocovsSD_M.ftable, 
             file=paste(storage, "cc.Lbmi_01nocovsSD_M.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nocovsSD"))

#### WOMEN ####
## Log BMI, log income and log income sq ####
## Data modifications 
# The main difference here is that selection is based on income rather
# than NSSEC NAs

## Drop NSSEC
data19_F <- data15_F[!names(data15_F) %in% c("nssec8", "nssec3")]

## Censor observations with income NA 
# Note it is the same observations for both 3 and 8
data20_F <- data19_F[!(is.na(data19_F$eqvinc)), ]
data20_F <- data20_F[!(is.na(data20_F$LDeqvinc)), ]

# Check for perfect separation
women.cell.name.count <- as.data.frame(with(data20_F,table(cell.name, obese)))
women.cell.name.zeros <- women.cell.name.count[women.cell.name.count$Freq==0, ]
View(women.cell.name.zeros)

# Select age range due to perfect separation
# Difficult in that there are clearly concerns with the early ages, to 24, but
# also missing a few middle observations. Can't censor all for that and 
# since working with continuous data it doesn't strictly matter.. Use the same 
# age range as main analysis.
data20_F <- data20_F[data20_F$age>=28, ]

# Shorten by period to be commensurate with the nssec data
data20_F <- data20_F[data20_F$period>=2001, ]

## Censor five cohorts each end to improve stability of estimates
data21_F <- data20_F[data20_F$cohort<= (max(data20_F$cohort)-5) &
                       data20_F$cohort>= (min(data20_F$cohort)+5), ]

## Variable adjustments and addition

# Construct more variables that will be needed in later specifications
Lbmi <- log(data21_F$bmivalid)
Lwtvalid <- log(data21_F$wtvalid)
htvalidm <- data21_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data21_F$age.fin.ed^2

# Add all variables to data
data22_F <- cbind(data21_F, Lbmi, Lwtvalid, 
                  Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data19_F, data20_F, data21_F, age.fin.ed_sq, htvalidm, Lbmi,
   Lhtvalid, Lhtvalid_sq, Lwtvalid)

# list covariates to avoid repetition
inc.covariates <- c(
  ethnicity, education, "LDeqvinc", "LDeqvinc2", "drink.rare", 
  "drink.never", "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01inc_F.ethhabits.ftable <- apc.indiv.Ftable(
  data22_F, datatype="AP hexag", dep.var="Lbmi", covariates=inc.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01inc_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data22_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01inc_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01inc_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = inc.covariates, model.design = "APC")

cc.Lbmi_01inc_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01inc_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01inc_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01inc_F.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with income 01-14, women, detrended")

cc.Lbmi_01inc_F.apc.ethhabits.cov <- round(
  cc.Lbmi_01inc_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01inc_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01inc_F.ethhabits.ftable <- xtable(
  cc.Lbmi_01inc_F.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01inc_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01inc_F.ethhabits.ftable)+1)), 
  caption="log BMI on APC and income, women, 01-14", 
  label="cc.Lbmi_01inc_F.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01inc_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01inc_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01inc_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01inc_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01inc_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01inc_F.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and income, women, 01-14", 
  label="cc.Lbmi_01inc_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01inc_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01inc_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01inc"))

## Further data restriction (on income and NSSEC) ####

## Censor observations with income or NSSEC NA 
# Note it is the same observations for both 3 and 8
data23_F <- data15_F[!(is.na(data15_F$eqvinc)), ]
data23_F <- data23_F[!(is.na(data23_F$nssec3)), ]

# Check for perfect separation
women.cell.name.count <- as.data.frame(with(data23_F,table(cell.name, obese)))
women.cell.name.zeros <- women.cell.name.count[women.cell.name.count$Freq==0, ]
View(women.cell.name.zeros)

# Select age range due to perfect separation
# Lots of missing cells, again continuous so can copy main analysis
data23_F <- data23_F[data23_F$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data24_F <- data23_F[data23_F$cohort<= (max(data23_F$cohort)-5) &
                       data23_F$cohort>= (min(data23_F$cohort)+5), ]

## Variable adjustments and addition
# Construct more variables that will be needed in later specifications
Lbmi <- log(data24_F$bmivalid)
Lwtvalid <- log(data24_F$wtvalid)
htvalidm <- data24_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data24_F$age.fin.ed^2

# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_F <- model.matrix(~nssec3-1,data24_F)
vars.nssec3_F <- vars.nssec3_F[, -4] # set routine and manual as reference group
colnames(vars.nssec3_F) <- gsub(" ", "_", colnames(vars.nssec3_F))
# Access label
list.nssec3 <- colnames(vars.nssec3_F)

# Add all variables to data
data25_F <- cbind(data24_F, Lbmi, Lwtvalid, vars.nssec3_F,
                  Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data23_F, data24_F, age.fin.ed_sq, htvalidm, Lbmi, vars.nssec3_F,
   Lhtvalid, Lhtvalid_sq, Lwtvalid)


## Log BMI, log income and log income sq

# Ftable
cc.Lbmi_01incSS_F.ethhabits.ftable <- apc.indiv.Ftable(
  data25_F, datatype="AP hexag", dep.var="Lbmi", covariates=inc.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01incSS_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data25_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01incSS_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01incSS_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = inc.covariates, model.design = "APC")

cc.Lbmi_01incSS_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01incSS_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01incSS_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01incSS_F.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with income 01-14, women, detrended")

cc.Lbmi_01incSS_F.apc.ethhabits.cov <- round(
  cc.Lbmi_01incSS_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01incSS_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01incSS_F.ethhabits.ftable <- xtable(
  cc.Lbmi_01incSS_F.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01incSS_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01incSS_F.ethhabits.ftable)+1)), 
  caption="log BMI on APC and income, women, 01-14", 
  label="cc.Lbmi_01incSS_F.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01incSS_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01incSS_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01incSS_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01incSS_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01incSS_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01incSS_F.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and income, women, 01-14", 
  label="cc.Lbmi_01incSS_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01incSS_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01incSS_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01incSS"))

## NSSEC3

# list covariates to avoid repetition
n3.covariates <- c(
  ethnicity, education, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01nssec3SS_F.ethhabits.ftable <- apc.indiv.Ftable(
  data25_F, datatype="AP hexag", dep.var="Lbmi", covariates=n3.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nssec3SS_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data25_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec3SS_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec3SS_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = n3.covariates, model.design = "APC")

cc.Lbmi_01nssec3SS_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec3SS_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec3SS_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec3SS_F.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with nssec3 01-14, women, detrended")

cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec3SS_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec3SS_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nssec3SS_F.ethhabits.ftable <- xtable(
  cc.Lbmi_01nssec3SS_F.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01nssec3SS_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec3SS_F.ethhabits.ftable)+1)), 
  caption="log BMI on APC and nssec3, women, 01-14", 
  label="cc.Lbmi_01nssec3SS_F.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01nssec3SS_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01nssec3SS_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and nssec3, women, 01-14", 
  label="cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01nssec3SS_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nssec3SS"))

rm(data22_F, data25_F)

## Subset 1000 of data18 ####
min(count(data18F$period))
# min in a period is 1494, so randomly select 1000

# equal number of observations
d18F_eq <- matrix(nrow=length(unique(data18F$period))*1000, ncol=ncol(data18F))
d18F_eq <- as.data.frame(d18F_eq)
colnames(d18F_eq) <- colnames(data18F)



for (k in c(45832, 50032, 1129)){
  set.seed(k)
  
  for (i in 1:length(unique(data18F$period))){
    d18F_year <- data18F[data18F$period==(2000+i), ]
    d18F_eq_year <- d18F_year[sample.int(nrow(d18F_year), 1000), ]
    d18F_eq[(1000*(i-1)+1):(1000*i), 1:ncol(data18F)] <- d18F_eq_year
  }
  
  data26_F <- d18F_eq[d18F_eq$is.female==1, ]
  
  ## First: check count of observations per cell
  d26_F.popcount <- count(data26_F, c("cohort", "age"))
  d26_F.popcount.c <- cast(d26_F.popcount, cohort~age, value="freq")
  
  #### Analysis BMI all covariates
  cc.Lbmi_01nssec3_F.ftable <- apc.indiv.Ftable(data26_F, datatype="AP hexag",
                                                dep.var="Lbmi", covariates=n3.covariates,
                                                n.coh.excl.start = 5, n.coh.excl.end = 5)
  cc.Lbmi_01nssec3_F.apc.collin <- apc.indiv.design.collinear(data26_F, 
                                                              datatype="AP hexag",
                                                              n.coh.excl.end = 5, n.coh.excl.start=5)
  cc.Lbmi_01nssec3_F.apc.model <- apc.indiv.design.model(
    cc.Lbmi_01nssec3_F.apc.collin, dep.var = "Lbmi", 
    covariates = n3.covariates, model.design = "APC")
  cc.Lbmi_01nssec3_F.apc.fit <- apc.indiv.fit.model(
    cc.Lbmi_01nssec3_F.apc.model, model.family="gaussian",
    n.coh.excl.start = 5, n.coh.excl.end = 5)
  cc.Lbmi_01nssec3_F.apc.plot <- var.apc.plot.fit(cc.Lbmi_01nssec3_F.apc.fit, 
                                                  main.outer = paste(
                                                    "APC model for Log BMI on nssec3, women, seed=",
                                                    k, sep=""))
  cc.Lbmi_01nssec3_F.apc.cov <- round(
    cc.Lbmi_01nssec3_F.apc.fit$coefficients.covariates, 4)
  
  # print plot
  dev.copy(postscript, paste(storage, "cc_bmi_01nssec3_Feq", k,
                             "_apc_ethhabits_plot.eps", sep=""))
  dev.off()
  
  # print tables
  xtable.cc.Lbmi_01nssec3_F.ftable <- xtable(cc.Lbmi_01nssec3_F.ftable, 
                                             display = xdisplay(cc.Lbmi_01nssec3_F.ftable), 
                                             align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec3_F.ftable)+1)), 
                                             caption=paste("Log BMI on APC and nssec3, women, seed=", 
                                                           k, sep=""), 
                                             label=paste("cc.Lbmi_01nssec3_Feq", k, ".ftable", sep=""))
  print.xtable(xtable.cc.Lbmi_01nssec3_F.ftable, file=paste(storage, 
                                                            "cc.Lbmi_01nssec3_Feq", k, ".ftable.tex", sep=""), 
               booktabs=TRUE, caption.placement="top")
  
  xtable.cc.Lbmi_01nssec3_F.apc.cov <- xtable(cc.Lbmi_01nssec3_F.apc.cov,
                                              display=xdisplay(cc.Lbmi_01nssec3_F.apc.cov), 
                                              align=rep("c", (ncol(cc.Lbmi_01nssec3_F.apc.cov)+1)),
                                              caption=paste("Log BMI on APC and nssec3, women, seed=",
                                                            k, sep=""), 
                                              label=paste("cc.Lbmi_01nssec3_Feq", k, ".apc.cov", sep=""))
  print.xtable(xtable.cc.Lbmi_01nssec3_F.apc.cov, file=paste(storage,
                                                             "cc.Lbmi_01nssec3_Feq", k, ".apc.cov.tex", sep=""),
               booktabs=TRUE, caption.placement = "top")
  
}

#Clear
rm(list=ls(pattern="Lbmi_01nssec3"))

## Use the full age range ####

## Data adjustments
# Drop income
data27_F <- data15_F[!names(data15_F) %in% c("eqvinc", "Deqvinc", 
                                             "LDeqvinc", "LDeqvinc2")]
# Censor observations with NSSEC NA 
data27_F <- data27_F[!(is.na(data27_F$nssec3)), ]

# Censor five cohorts each end to improve stability of estimates
data28_F <- data27_F[data27_F$cohort<= (max(data27_F$cohort)-5) &
                       data27_F$cohort>= (min(data27_F$cohort)+5), ]

## Variable adjustments and addition
# Convert NSSEC3 factor to dummy variables, rename
vars.nssec3_F <- model.matrix(~nssec3-1,data28_F)
vars.nssec3_F <- vars.nssec3_F[, -4] # set routine and manual as reference group
colnames(vars.nssec3_F) <- gsub(" ", "_", colnames(vars.nssec3_F))
# Access label
list.nssec3 <- colnames(vars.nssec3_F)

# Construct more variables that will be needed in later specifications
Lbmi <- log(data28_F$bmivalid)
Lwtvalid <- log(data28_F$wtvalid)
htvalidm <- data28_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data28_F$age.fin.ed^2

# Add all variables to data
data28_Fbdh <- cbind(data28_F, vars.nssec3_F, Lbmi, Lwtvalid, 
                     Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data27_F, data28_F, vars.nssec3_F,
   age.fin.ed_sq, htvalidm, Lbmi, Lhtvalid, Lhtvalid_sq, Lwtvalid)

## Analysis on log BMI

# list covariates to avoid repetition
n3.covariates <- c(
  ethnicity, education, list.nssec3, "drink.rare", "drink.never", 
  "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_01nssec320_F.ethhabits.ftable <- apc.indiv.Ftable(
  data28_Fbdh, datatype="AP hexag", dep.var="Lbmi", covariates=n3.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nssec320_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data28_Fbdh, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nssec320_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_01nssec320_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = n3.covariates, model.design = "APC")

cc.Lbmi_01nssec320_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nssec320_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nssec320_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_01nssec320_F.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with nssec3 01-14, women, detrended, age 20-80")

cc.Lbmi_01nssec320_F.apc.ethhabits.cov <- round(
  cc.Lbmi_01nssec320_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nssec320_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nssec320_F.ethhabits.ftable <- xtable(
  cc.Lbmi_01nssec320_F.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_01nssec320_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nssec320_F.ethhabits.ftable)+1)), 
  caption="log BMI on APC and nssec3, women, 01-14, age 20-80", 
  label="cc.Lbmi_01nssec320_F.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_01nssec320_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_01nssec320_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_01nssec320_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_01nssec320_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_01nssec320_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_01nssec320_F.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and nssec3, women, 01-14, age 20-80", 
  label="cc.Lbmi_01nssec320_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_01nssec320_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_01nssec320_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nssec320"))
rm(data28_Fbdh)

## Use the full BMI data and no covariates ####

## Final data tidying
# Censor age as per main analysis
dataBMI3_F <- dataBMI2_F[dataBMI2_F$age >=28, ]

# Shorten by period to ensure commensurate
dataBMI3_F <- dataBMI3_F[dataBMI3_F$period >=2001, ]

# Censor five cohorts each end to improve stability of estimates
dataBMI4_F <- dataBMI3_F[dataBMI3_F$cohort<= (max(dataBMI3_F$cohort)-5) &
                           dataBMI3_F$cohort>= (min(dataBMI3_F$cohort)+5), ]


# Construct more variables that will be needed in later specifications
Lbmi <- log(dataBMI4_F$bmivalid)
Lwtvalid <- log(dataBMI4_F$wtvalid)
htvalidm <- dataBMI4_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2

# Add all variables to data
dataBMI5_F <- cbind(dataBMI4_F, Lbmi, Lwtvalid, 
                    Lhtvalid, Lhtvalid_sq)

# drop construction tools
rm(dataBMI3_F, dataBMI4_F, htvalidm, Lbmi, Lhtvalid, Lhtvalid_sq, Lwtvalid)

## Analysis on log BMI

# Ftable
cc.Lbmi_01nocovsBD_F.ftable <- apc.indiv.Ftable(
  dataBMI5_F, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nocovsBD_F.apc.collin <- apc.indiv.design.collinear(
  dataBMI5_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nocovsBD_F.apc.model <- apc.indiv.design.model(
  cc.Lbmi_01nocovsBD_F.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_01nocovsBD_F.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nocovsBD_F.apc.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nocovsBD_F.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_01nocovsBD_F.apc.fit, 
  main.outer = "log BMI on APC no covariates 01-14, women, detrended, all data")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nocovsBD_F_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nocovsBD_F.ftable <- xtable(
  cc.Lbmi_01nocovsBD_F.ftable, 
  display = xdisplay(cc.Lbmi_01nocovsBD_F.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nocovsBD_F.ftable)+1)), 
  caption="log BMI on APC no covariates, women, 01-14, all data", 
  label="cc.Lbmi_01nocovsBD_F.ftable")
print.xtable(xtable.cc.Lbmi_01nocovsBD_F.ftable, 
             file=paste(storage, "cc.Lbmi_01nocovsBD_F.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nocovsBD"))
rm(dataBMI5_F)


## no covariates, original data ####

## Analysis on log BMI

# Ftable
cc.Lbmi_01nocovsSD_F.ftable <- apc.indiv.Ftable(
  data18F, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_01nocovsSD_F.apc.collin <- apc.indiv.design.collinear(
  data18F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_01nocovsSD_F.apc.model <- apc.indiv.design.model(
  cc.Lbmi_01nocovsSD_F.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_01nocovsSD_F.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_01nocovsSD_F.apc.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_01nocovsSD_F.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_01nocovsSD_F.apc.fit, 
  main.outer = 
    "log BMI on APC no covariates 01-14, women, detrended, small data")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_01nocovsSD_F_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_01nocovsSD_F.ftable <- xtable(
  cc.Lbmi_01nocovsSD_F.ftable, 
  display = xdisplay(cc.Lbmi_01nocovsSD_F.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_01nocovsSD_F.ftable)+1)), 
  caption="log BMI on APC no covariates, women, 01-14, small data", 
  label="cc.Lbmi_01nocovsSD_F.ftable")
print.xtable(xtable.cc.Lbmi_01nocovsSD_F.ftable, 
             file=paste(storage, "cc.Lbmi_01nocovsSD_F.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_01nocovsSD"))


# -----------------------------------------------------------------------------
# EXTRA MODELS USING DIFFERENT DATA
# -----------------------------------------------------------------------------
## Get data ####
#### MEN ####
## Log BMI, income, 1997 ####
## Data modifications 

## Drop NSSEC
data29_M <- data15_M[!names(data15_M) %in% c("nssec8", "nssec3")]

## Censor observations with income NA 
# Note it is the same observations for both 3 and 8
data30_M <- data29_M[!(is.na(data29_M$eqvinc)), ]
data30_M <- data30_M[!(is.na(data30_M$LDeqvinc)), ]

# Check for perfect separation
men.cell.name.count <- as.data.frame(with(data30_M,table(cell.name, obese)))
men.cell.name.zeros <- men.cell.name.count[men.cell.name.count$Freq==0, ]
View(men.cell.name.zeros)

# Select age range to reflect main analysis
data30_M <- data30_M[data30_M$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data31_M <- data30_M[data30_M$cohort<= (max(data30_M$cohort)-5) &
                       data30_M$cohort>= (min(data30_M$cohort)+5), ]

## Variable adjustments and addition

# Construct more variables that will be needed in later specifications
Lbmi <- log(data31_M$bmivalid)
Lwtvalid <- log(data31_M$wtvalid)
htvalidm <- data31_M$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data31_M$age.fin.ed^2

# Add all variables to data
data32_M <- cbind(data31_M, Lbmi, Lwtvalid, 
                  Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data29_M, data30_M, data31_M, age.fin.ed_sq, htvalidm, Lbmi,
   Lhtvalid, Lhtvalid_sq, Lwtvalid)

# list covariates to avoid repetition
inc.covariates <- c(
  ethnicity, education, "LDeqvinc", "LDeqvinc2", "drink.rare", 
  "drink.never", "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_97inc_M.ethhabits.ftable <- apc.indiv.Ftable(
  data32_M, datatype="AP hexag", dep.var="Lbmi", covariates=inc.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_97inc_M.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data32_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_97inc_M.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_97inc_M.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = inc.covariates, model.design = "APC")

cc.Lbmi_97inc_M.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_97inc_M.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_97inc_M.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_97inc_M.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with income 97-14, men, detrended")

cc.Lbmi_97inc_M.apc.ethhabits.cov <- round(
  cc.Lbmi_97inc_M.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_97inc_M_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_97inc_M.ethhabits.ftable <- xtable(
  cc.Lbmi_97inc_M.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_97inc_M.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_97inc_M.ethhabits.ftable)+1)), 
  caption="log BMI on APC and income, men, 97-14", 
  label="cc.Lbmi_97inc_M.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_97inc_M.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_97inc_M.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_97inc_M.apc.ethhabits.cov <- xtable(
  cc.Lbmi_97inc_M.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_97inc_M.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_97inc_M.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and income, men, 97-14", 
  label="cc.Lbmi_97inc_M.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_97inc_M.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_97inc_M.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_97inc"))

## Log BMI, no covariates, 1992 ####

## Final data tidying
# Censor age as per main analysis
dataBMI6_M <- dataBMI2_M[dataBMI2_M$age >=28, ]

# Censor five cohorts each end to improve stability of estimates
dataBMI7_M <- dataBMI6_M[dataBMI6_M$cohort<= (max(dataBMI6_M$cohort)-5) &
                           dataBMI6_M$cohort>= (min(dataBMI6_M$cohort)+5), ]

# Construct more variables that will be needed in later specifications
Lbmi <- log(dataBMI7_M$bmivalid)

# Add all variables to data
dataBMI8_M <- cbind(dataBMI7_M, Lbmi)

# drop construction tools
rm(dataBMI6_M, dataBMI7_M, Lbmi)

## Analysis on log BMI

# Ftable
cc.Lbmi_92nocovsBD_M.ftable <- apc.indiv.Ftable(
  dataBMI8_M, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_92nocovsBD_M.apc.collin <- apc.indiv.design.collinear(
  dataBMI8_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_92nocovsBD_M.apc.model <- apc.indiv.design.model(
  cc.Lbmi_92nocovsBD_M.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_92nocovsBD_M.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_92nocovsBD_M.apc.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_92nocovsBD_M.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_92nocovsBD_M.apc.fit, 
  main.outer = "log BMI on APC no covariates 92-14, men, detrended, all data")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_92nocovsBD_M_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_92nocovsBD_M.ftable <- xtable(
  cc.Lbmi_92nocovsBD_M.ftable, 
  display = xdisplay(cc.Lbmi_92nocovsBD_M.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_92nocovsBD_M.ftable)+1)), 
  caption="log BMI on APC no covariates, men, 92-14, all data", 
  label="cc.Lbmi_92nocovsBD_M.ftable")
print.xtable(xtable.cc.Lbmi_92nocovsBD_M.ftable, 
             file=paste(storage, "cc.Lbmi_92nocovsBD_M.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_92nocovsBD"))
rm(dataBMI8_M)

## Log BMI, no covariates, 1992, cohorts restricted ####

## Final data tidying
# Censor age as per main analysis
dataBMI6_M <- dataBMI2_M[dataBMI2_M$age >=28, ]
# Censor cohort as per main analysis. 1912 --> 1921 i.e. 9
dataBMI6_M <- dataBMI6_M[dataBMI6_M$cohort >=1921, ]

# Censor five cohorts each end to improve stability of estimates
dataBMI7_M <- dataBMI6_M[dataBMI6_M$cohort<= (max(dataBMI6_M$cohort)-5) &
                           dataBMI6_M$cohort>= (min(dataBMI6_M$cohort)+5), ]

# Construct more variables that will be needed in later specifications
Lbmi <- log(dataBMI7_M$bmivalid)

# Add all variables to data
dataBMI8_M <- cbind(dataBMI7_M, Lbmi)

# drop construction tools
rm(dataBMI6_M, dataBMI7_M, Lbmi)

## Analysis on log BMI

# Ftable
cc.Lbmi_92nocovsCOH21_M.ftable <- apc.indiv.Ftable(
  dataBMI8_M, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = (5+9), n.coh.excl.end = 5)

# APC model
cc.Lbmi_92nocovsCOH21_M.apc.collin <- apc.indiv.design.collinear(
  dataBMI8_M, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=(5+9))

cc.Lbmi_92nocovsCOH21_M.apc.model <- apc.indiv.design.model(
  cc.Lbmi_92nocovsCOH21_M.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_92nocovsCOH21_M.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_92nocovsCOH21_M.apc.model, model.family="gaussian",
  n.coh.excl.start = (5+9), n.coh.excl.end = 5)

cc.Lbmi_92nocovsCOH21_M.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_92nocovsCOH21_M.apc.fit, 
  main.outer = "log BMI on APC no covariates 92-14, men, detrended, cohort limited")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_92nocovsCOH21_M_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_92nocovsCOH21_M.ftable <- xtable(
  cc.Lbmi_92nocovsCOH21_M.ftable, 
  display = xdisplay(cc.Lbmi_92nocovsCOH21_M.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_92nocovsCOH21_M.ftable)+1)), 
  caption="log BMI on APC no covariates, men, 92-14, cohort limited", 
  label="cc.Lbmi_92nocovsCOH21_M.ftable")
print.xtable(xtable.cc.Lbmi_92nocovsCOH21_M.ftable, 
             file=paste(storage, "cc.Lbmi_92nocovsCOH21_M.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_92nocovsCOH21"))
rm(dataBMI8_M)
#### WOMEN ####
## Log BMI, income, 1997 ####
## Data modifications 

## Drop NSSEC
data29_F <- data15_F[!names(data15_F) %in% c("nssec8", "nssec3")]

## Censor observations with income NA 
# Note it is the same observations for both 3 and 8
data30_F <- data29_F[!(is.na(data29_F$eqvinc)), ]
data30_F <- data30_F[!(is.na(data30_F$LDeqvinc)), ]

# Check for perfect separation
women.cell.name.count <- as.data.frame(with(data30_F,table(cell.name, obese)))
women.cell.name.zeros <- women.cell.name.count[women.cell.name.count$Freq==0, ]
View(women.cell.name.zeros)

# Select age range in line with main analysis
data30_F <- data30_F[data30_F$age>=28, ]

## Censor five cohorts each end to improve stability of estimates
data31_F <- data30_F[data30_F$cohort<= (max(data30_F$cohort)-5) &
                       data30_F$cohort>= (min(data30_F$cohort)+5), ]

## Variable adjustments and addition

# Construct more variables that will be needed in later specifications
Lbmi <- log(data31_F$bmivalid)
Lwtvalid <- log(data31_F$wtvalid)
htvalidm <- data31_F$htvalid/100
Lhtvalid <- log(htvalidm)
Lhtvalid_sq <- Lhtvalid^2
age.fin.ed_sq <- data31_F$age.fin.ed^2

# Add all variables to data
data32_F <- cbind(data31_F, Lbmi, Lwtvalid, 
                  Lhtvalid, Lhtvalid_sq, age.fin.ed_sq)

# drop construction tools
rm(data29_F, data30_F, data31_F, age.fin.ed_sq, htvalidm, Lbmi,
   Lhtvalid, Lhtvalid_sq, Lwtvalid)

# list covariates to avoid repetition
inc.covariates <- c(
  ethnicity, education, "LDeqvinc", "LDeqvinc2", "drink.rare", 
  "drink.never", "drink.freq", "ever.smoked", "now.smoke")

# Ftable
cc.Lbmi_97inc_F.ethhabits.ftable <- apc.indiv.Ftable(
  data32_F, datatype="AP hexag", dep.var="Lbmi", covariates=inc.covariates,
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_97inc_F.apc.ethhabits.collin <- apc.indiv.design.collinear(
  data32_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_97inc_F.apc.ethhabits.model <- apc.indiv.design.model(
  cc.Lbmi_97inc_F.apc.ethhabits.collin, dep.var = "Lbmi", 
  covariates = inc.covariates, model.design = "APC")

cc.Lbmi_97inc_F.apc.ethhabits.fit <- apc.indiv.fit.model(
  cc.Lbmi_97inc_F.apc.ethhabits.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_97inc_F.apc.ethhabits.plot <- var.apc.plot.fit(
  cc.Lbmi_97inc_F.apc.ethhabits.fit, 
  main.outer = "log BMI on APC with income 97-14, women, detrended")

cc.Lbmi_97inc_F.apc.ethhabits.cov <- round(
  cc.Lbmi_97inc_F.apc.ethhabits.fit$coefficients.covariates, 4)

dev.copy(postscript,
         paste(storage, "cc_Lbmi_97inc_F_apc_ethhabits_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_97inc_F.ethhabits.ftable <- xtable(
  cc.Lbmi_97inc_F.ethhabits.ftable, 
  display = xdisplay(cc.Lbmi_97inc_F.ethhabits.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_97inc_F.ethhabits.ftable)+1)), 
  caption="log BMI on APC and income, women, 97-14", 
  label="cc.Lbmi_97inc_F.ethhabits.ftable")
print.xtable(xtable.cc.Lbmi_97inc_F.ethhabits.ftable, 
             file=paste(storage, "cc.Lbmi_97inc_F.ethhabits.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

xtable.cc.Lbmi_97inc_F.apc.ethhabits.cov <- xtable(
  cc.Lbmi_97inc_F.apc.ethhabits.cov, 
  display=xdisplay(cc.Lbmi_97inc_F.apc.ethhabits.cov), 
  align=rep("c", (ncol(cc.Lbmi_97inc_F.apc.ethhabits.cov)+1)),
  caption="log BMI on APC and income, women, 97-14", 
  label="cc.Lbmi_97inc_F.apc.ethhabits.cov")
print.xtable(xtable.cc.Lbmi_97inc_F.apc.ethhabits.cov, 
             file=paste(storage, "cc.Lbmi_97inc_F.apc.ethhabits.cov.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement = "top")

# Clear
rm(list=ls(pattern="cc.Lbmi_97inc"))

## Log BMI, no covariates, 1992 ####

## Final data tidying
# Censor age as per main analysis
dataBMI6_F <- dataBMI2_F[dataBMI2_F$age >=28, ]

# Censor five cohorts each end to improve stability of estimates
dataBMI7_F <- dataBMI6_F[dataBMI6_F$cohort<= (max(dataBMI6_F$cohort)-5) &
                           dataBMI6_F$cohort>= (min(dataBMI6_F$cohort)+5), ]

# Construct more variables that will be needed in later specifications
Lbmi <- log(dataBMI7_F$bmivalid)

# Add all variables to data
dataBMI8_F <- cbind(dataBMI7_F, Lbmi)

# drop construction tools
rm(dataBMI6_F, dataBMI7_F, Lbmi)

## Analysis on log BMI

# Ftable
cc.Lbmi_92nocovsBD_F.ftable <- apc.indiv.Ftable(
  dataBMI8_F, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

# APC model
cc.Lbmi_92nocovsBD_F.apc.collin <- apc.indiv.design.collinear(
  dataBMI8_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=5)

cc.Lbmi_92nocovsBD_F.apc.model <- apc.indiv.design.model(
  cc.Lbmi_92nocovsBD_F.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_92nocovsBD_F.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_92nocovsBD_F.apc.model, model.family="gaussian",
  n.coh.excl.start = 5, n.coh.excl.end = 5)

cc.Lbmi_92nocovsBD_F.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_92nocovsBD_F.apc.fit, 
  main.outer = "log BMI on APC no covariates 92-14, women, detrended, all data")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_92nocovsBD_F_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_92nocovsBD_F.ftable <- xtable(
  cc.Lbmi_92nocovsBD_F.ftable, 
  display = xdisplay(cc.Lbmi_92nocovsBD_F.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_92nocovsBD_F.ftable)+1)), 
  caption="log BMI on APC no covariates, women, 92-14, all data", 
  label="cc.Lbmi_92nocovsBD_F.ftable")
print.xtable(xtable.cc.Lbmi_92nocovsBD_F.ftable, 
             file=paste(storage, "cc.Lbmi_92nocovsBD_F.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_92nocovsBD"))
rm(dataBMI8_F)


## Log BMI, no covariates, 1992, cohorts restricted ####

## Final data tidying
# Censor age as per main analysis
dataBMI6_F <- dataBMI2_F[dataBMI2_F$age >=28, ]
# Censor cohort as per main analysis. 1912 --> 1921 i.e. 9
dataBMI6_F <- dataBMI6_F[dataBMI6_F$cohort >=1921, ]

# Censor five cohorts each end to improve stability of estimates
dataBMI7_F <- dataBMI6_F[dataBMI6_F$cohort<= (max(dataBMI6_F$cohort)-5) &
                           dataBMI6_F$cohort>= (min(dataBMI6_F$cohort)+5), ]

# Construct more variables that will be needed in later specifications
Lbmi <- log(dataBMI7_F$bmivalid)

# Add all variables to data
dataBMI8_F <- cbind(dataBMI7_F, Lbmi)

# drop construction tools
rm(dataBMI6_F, dataBMI7_F, Lbmi)

## Analysis on log BMI

# Ftable
cc.Lbmi_92nocovsCOH21_F.ftable <- apc.indiv.Ftable(
  dataBMI8_F, datatype="AP hexag", dep.var="Lbmi",
  n.coh.excl.start = (5+9), n.coh.excl.end = 5)

# APC model
cc.Lbmi_92nocovsCOH21_F.apc.collin <- apc.indiv.design.collinear(
  dataBMI8_F, datatype="AP hexag", n.coh.excl.end = 5, n.coh.excl.start=(5+9))

cc.Lbmi_92nocovsCOH21_F.apc.model <- apc.indiv.design.model(
  cc.Lbmi_92nocovsCOH21_F.apc.collin, dep.var = "Lbmi", model.design = "APC")

cc.Lbmi_92nocovsCOH21_F.apc.fit <- apc.indiv.fit.model(
  cc.Lbmi_92nocovsCOH21_F.apc.model, model.family="gaussian",
  n.coh.excl.start = (5+9), n.coh.excl.end = 5)

cc.Lbmi_92nocovsCOH21_F.apc.plot <- var.apc.plot.fit(
  cc.Lbmi_92nocovsCOH21_F.apc.fit, 
  main.outer = "log BMI on APC no covariates 92-14, women, detrended, cohort limited")

dev.copy(postscript,
         paste(storage, "cc_Lbmi_92nocovsCOH21_F_apc_plot.eps", sep=""))
dev.off()

# print tables
xtable.cc.Lbmi_92nocovsCOH21_F.ftable <- xtable(
  cc.Lbmi_92nocovsCOH21_F.ftable, 
  display = xdisplay(cc.Lbmi_92nocovsCOH21_F.ftable), 
  align = rep("p{1.5cm}", (ncol(cc.Lbmi_92nocovsCOH21_F.ftable)+1)), 
  caption="log BMI on APC no covariates, women, 92-14, cohort limited", 
  label="cc.Lbmi_92nocovsCOH21_F.ftable")
print.xtable(xtable.cc.Lbmi_92nocovsCOH21_F.ftable, 
             file=paste(storage, "cc.Lbmi_92nocovsCOH21_F.ftable.tex",
                        sep=""), 
             booktabs=TRUE, caption.placement="top")

# Clear
rm(list=ls(pattern="cc.Lbmi_92nocovsCOH21"))
rm(dataBMI8_F)

# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------