# -----------------------------------------------------------------------------
# Project: APC modelling and covariates with application to obesity in England
# Script: further_functions.R
# Date started: 17/05/18
# Last edited: 06/12/18
# Author: Zoe Fannon
# -----------------------------------------------------------------------------
# This script contains two functions relating to specification tests and two
# functions that produce Latex versions of the tables to compare all APC models
# and submodels by F-tests and AIC (normal models) or LR-tests and AIC (logit
# models). These are:
#   tidy.spec.test: runs both RESET and White tests
#   messy.spec.table: combines results from tidy.spec.test and JB test in table
#   xtablify.F: creates Latex table of model comparisons for normal model
#   xtablify.LR: creates Latex table of model comparisons for logit model
# -----------------------------------------------------------------------------

#### tidy.spec.test ####
tidy.spec.test <- function(data, fit.model, dep.var, covariates,
                            n.coh.excl.start=0, n.coh.excl.end=0,
                            model.design="APC", datatype){
  ##################
  # This function constructs a RESET test (dependent variable on fitted values
  # from APC + covariates and higher powers) and a White-type test
  # (squared residuals from APC + covariates on all covariates, their squares,
  # and interactions). These check model specification and heteroskedasticity
  # respectively. 
  ##################
  covariates.list <- covariates
  
  #### RESET test ####
  
  # Extract predicted values from original model
  predicted <- fit.model$fitted.values
  predicted_sq <- predicted^2
  predicted_cb <- predicted^3
    
  data_p <- cbind(data, predicted, predicted_sq, predicted_cb)
  
  # Model: original dependent variable on original explanatory variables plus
  # predicted values from original model and powers of that
  OVB.test.collin <- apc.indiv.design.collinear(data_p, datatype=datatype,
                                        n.coh.excl.end =n.coh.excl.end,
                                        n.coh.excl.start=n.coh.excl.start)
  OVB.test.model <- apc.indiv.design.model(OVB.test.collin, dep.var = dep.var,
                                   covariates =c(covariates.list, 
                                                 "predicted_sq", 
                                                 "predicted_cb"),
                                   model.design=model.design)
  OVB.test.fit <- apc.indiv.fit.model(OVB.test.model, 
                                      n.coh.excl.start = n.coh.excl.start, 
                                      n.coh.excl.end = n.coh.excl.end,
                                      model.family = "gaussian")
    
  # RESET: F-test
  big.model.RSS <- sum(OVB.test.fit$residuals^2)
  small.model.RSS <- sum(fit.model$residuals^2)
  big.model.nparams <- length(OVB.test.fit$coefficients)
  small.model.nparams <- length(fit.model$coefficients)
  sample.N <- length(OVB.test.fit$residuals)
  
  df.num <- big.model.nparams - small.model.nparams
  df.denom <- sample.N - big.model.nparams
  df <- paste("(", paste(as.character(df.num), 
                         as.character(df.denom), sep=", "), ")", sep="")
  
  fstat.num <- (small.model.RSS - big.model.RSS)/df.num
  fstat.denom <- (big.model.RSS - 0)/df.denom
  fstat <- fstat.num/fstat.denom
  
  OVB.p.value <- pf(fstat, df1 = df.num, df2 = df.denom, lower.tail = FALSE)
  
  OVB.fstat <- fstat
  OVB.df <- df  

  #### White test ####
  
  # Extract residual squares from original model
  residuals <- fit.model$residuals
  residuals_sq <- residuals^2
    
  # Construct interactions
  # get the constituent components and matrix all.interactions for storage
  to_inter <- data[, names(data) %in% covariates.list]
  count_interactions <- sum((ncol(to_inter)-1):1)
  all.interactions <- as.data.frame(matrix(nrow=nrow(to_inter), 
                                           ncol=count_interactions))
  k <- 1
  # loop to interact each variable with all others, except final
  for(c in 1:(ncol(to_inter)-2)){
    int <- to_inter[,c]*to_inter[, (c+1):ncol(to_inter)]
    colnames(int) <- paste(names(to_inter)[c], names(int), sep="*")
    all.interactions[, k:(k+ncol(int)-1)] <- int
    colnames(all.interactions)[k:(k+ncol(int)-1)] <- colnames(int)
    k <- k + ncol(int)
  }
  # final treated separately bc not automatically a matrix
  c <- ncol(to_inter)-1
  int <- to_inter[,c]*to_inter[, (c+1):ncol(to_inter)]
  int <- as.data.frame(int)
  names(int) <- paste(names(to_inter)[c], names(to_inter)[c+1], sep="*")
  all.interactions[, k:(k+ncol(int)-1)] <- int
  colnames(all.interactions)[k:(k+ncol(int)-1)] <- colnames(int)
  k <- k + ncol(int)
  # get names so can use in regression later
  internames <- colnames(all.interactions)
  
  # Construct squares
  squares <- as.data.frame(to_inter^2)
  colnames(squares) <- paste(colnames(to_inter), "_sq", sep="")
  # get names to use in regression later
  squarenames <- colnames(squares)
    
  # Model: squared residuals on intercept, squares, and interactions
  hetero.full.design <- cbind(1, squares, all.interactions)
  hetero.full.fit <- glm.fit(hetero.full.design, residuals_sq, 
                             family=gaussian())
  # Model: squared residuals on intercept only
  hetero.intercept.fit <- glm.fit(rep(1, nrow(data)), residuals_sq, 
                                  family=gaussian())
    
  # White hetero: F-test
  big.model.RSS <- sum(hetero.full.fit$residuals^2)
  small.model.RSS <- sum(hetero.intercept.fit$residuals^2)
  big.model.nparams <- length(hetero.full.fit$coefficients)
  small.model.nparams <- length(hetero.intercept.fit$coefficients)
  sample.N <- length(hetero.intercept.fit$y)
  
  df.num <- big.model.nparams - small.model.nparams
  df.denom <- sample.N - big.model.nparams
  df <- paste("(", paste(as.character(df.num), as.character(df.denom), 
                         sep=", "), ")", sep="")
  
  fstat.num <- (small.model.RSS - big.model.RSS)/df.num
  fstat.denom <- (big.model.RSS - 0)/df.denom
  fstat <- fstat.num/fstat.denom
  
  hetero.p.value <- pf(fstat, df1 = df.num, df2 = df.denom, lower.tail = FALSE)
  
  hetero.fstat <- fstat
  hetero.df <- df
    
  #### Extract valuables ####
  
  valuables <- list(RESET.fstat = OVB.fstat,
                    RESET.df = OVB.df,
                    RESET.p = OVB.p.value,
                    hetero.fstat = hetero.fstat,
                    hetero.df = hetero.df,
                    hetero.p = hetero.p.value)  
  
  return(valuables)       
}

#### messy.spec.table ####
messy.spec.table <- function(JB, reset.hetero){
  ##################
  # This function builds a table with pre-estimated specification tests
  ##################
  line.JB <- c("Normality test", NA, round(JB$statistic, 4), JB$parameter, 
               round(JB$p.value, 4))
  line.RESET <- c("RESET test", NA, round(reset.hetero$RESET.fstat, 4), 
                  reset.hetero$RESET.df, round(reset.hetero$RESET.p, 4))
  line.hetero <- c("hetero test", NA, round(reset.hetero$hetero.fstat, 4), 
                   reset.hetero$hetero.df, round(reset.hetero$hetero.p, 4))
  table <- rbind(line.JB, line.RESET, line.hetero)
  colnames(table) <- c("Test", " ", "statistic", "df", "p")
  return(table)
}

#### xtablify.F ####
xtablify.F <- function(ftable, filename){
  ##################
  # This function generates a Latex table of model comparisons (normal)
  ##################
  # extract values for degrees of freedom
  TShead <- colnames(ftable)[2]
  df.TS <- regmatches(TShead, regexpr("[[:digit:]]+", TShead))
  
  APChead <- colnames(ftable)[5]
  df.APC <- regmatches(APChead, regexpr("[[:digit:]]+", APChead))
  
  # extract names of models which minimize AIC
  find <- as.matrix(apply(ftable, 2, which.min))[7]
  modelmin <- rownames(ftable)[find]
  
  nextbestset <- ftable[-find, ]
  find2 <- as.matrix(apply( nextbestset, 2, which.min))[7] 
  model2min <- rownames(ftable)[find2]
  
  # build table
  colnames(ftable) <- c("F", "df", "p", "F", "df", "p", "AIC", "Loglikelihood")

  emptycol <- as.data.frame(rep(NA, nrow(ftable)))
  colnames(emptycol) <- " "
  
  spreadtable <- cbind( ftable[, 1:3],
                       emptycol, ftable[, 4:6],
                       emptycol, ftable[, 7:8])
  
  xtabled <- xtable(
    spreadtable, 
    align = c("l", rep("r", ncol(spreadtable)-2), "c", "c"),
    digits = c(0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 2))
  
  addtorow <- list()
  addtorow$pos <- list(0, 0, 0, 16)
  addtorow$command <- c("& \\multicolumn{3}{c}{Against TS}  && \\multicolumn{3}{c}{Against APC} &&&  \\\\\n",
                        "\\cmidrule(lr){2-4} \\cmidrule(lr){6-8} ",
                        "&    F &  df &    p &&    F &  df &    p && AIC & $\\ell$ \\\\\n",
                        paste("% Degrees of freedom are (\\textit{column 3}, ", df.TS, 
                              ") for TS and (\\textit{column 6}, ", df.APC, ") for APC. The AIC is minimized at model ",
                              modelmin, "; model ", model2min, " has the next lowest AIC value. \\\\\n" ,sep=""))
  
  # save table
  print(xtabled,
        floating=FALSE,
        file=paste(storage, filename, ".tex",
                   sep=""), 
        booktabs=TRUE,
        include.rownames=TRUE,
        include.colnames=FALSE,
        add.to.row=addtorow)
  
  # save footnote with info about AIC minimization
  footnote <- paste("Degrees of freedom are (\\textit{column 3}, ", df.TS, 
        ") for TS and (\\textit{column 6}, ", df.APC, ") for APC. The AIC is minimized at model ",
        modelmin, "; model ", model2min, " has the next lowest AIC value. \\\\\n" ,sep="")
  writeLines(footnote, paste(storage, filename, "_foot",
                              ".tex", sep=""))
}

#### xtablify.LR #### 
xtablify.LR <- function(LRtable, filename){
  ##################
  # This function generates a Latex table of model comparisons (logit)
  ##################
  # extract models which minimise AIC
  find <- as.matrix(apply(LRtable, 2, which.min))[7]
  modelmin <- rownames(LRtable)[find]
  
  nextbestset <- LRtable[-find, ]
  find2 <- as.matrix(apply( nextbestset, 2, which.min))[7] 
  model2min <- rownames(LRtable)[find2]
  
  # build table
  colnames(LRtable) <- c("LR", "df", "p", "LR", "df", "p", "AIC", "Loglikelihood")
  
  emptycol <- as.data.frame(rep(NA, nrow(LRtable)))
  colnames(emptycol) <- " "
  
  spreadtable <- cbind( LRtable[, 1:3],
                        emptycol, LRtable[, 4:6],
                        emptycol, LRtable[, 7:8])
  
  xtabled <- xtable(
    spreadtable, 
    align = c("l", rep("r", ncol(spreadtable)-2), "c", "c"),
    digits = c(0, 2, 0, 2, 0, 2, 0, 2, 0, 2, 2))
  
  addtorow <- list()
  addtorow$pos <- list(0, 0, 0, 16)
  addtorow$command <- c("& \\multicolumn{3}{c}{Against TS}  && \\multicolumn{3}{c}{Against APC} &&&  \\\\\n",
                        "\\cmidrule(lr){2-4} \\cmidrule(lr){6-8} ",
                        "&    LR &  df &    p &&    LR &  df &    p && AIC & $\\ell$ \\\\\n",
                        paste("% The AIC is minimized at model ",
                              modelmin, "; model ", model2min, " has the next lowest AIC value. \\\\\n" ,sep=""))
  
  #save table
  print(xtabled,
        floating=FALSE,
        file=paste(storage, filename, ".tex",
                   sep=""), 
        booktabs=TRUE,
        include.rownames=TRUE,
        include.colnames=FALSE,
        add.to.row=addtorow)
  
  # save footnote
  footnote <- paste("The AIC is minimized at model ",
              modelmin, "; model ", model2min, " has the next lowest AIC value. \\\\\n" ,sep="")
  writeLines(footnote, paste(storage, filename, "_foot",
                             ".tex", sep=""))
  
}



# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------