# -----------------------------------------------------------------------------
# Project: APC modelling and covariates with application to obesity in England
# Script: revised.functions2.R
# Date started: 26/03/18
# Last edited: 06/12/18
# Author: Zoe Fannon
# -----------------------------------------------------------------------------
# Writes the functions used for APC analysis of the normal model. Based on
# canonical parametrization of Kuang, Nielsen, and Nielsen (2008a) referred to 
# as KNN. Draws on 'apc' package.
# List of functions: 
#     apc.indiv.design.collinear: collinear version of X design matrix (KNN)
#     apc.indiv.design.model: X design matrix for model of interest
#     apc.indiv.fit.model: estimates model using glm.fit
#     apc.indiv.ftest.fullapc: test APC submodel against full APC model
#     var.apc.plot.fit: modifications to apc.plot.fit from 'apc' package
#     apc.indiv.estimate.TS: estimates time-saturated model
#     apc.indiv.ftest.TS: test APC submodel against time-saturated model
#     apc.indiv.Ftable: table comparing all APC submodels by F, AIC
# -----------------------------------------------------------------------------

# Libraries
library(apc)
library(plyr)

##### write apc.indiv.design.collinear #####
apc.indiv.design.collinear <- function(data, unit=1, datatype, 
                                           n.coh.excl.start=0, n.coh.excl.end=0){
  ##################
  # This function generates a collinear design matrix which encompasses all possible APC submodels
  ##################
  # Step 1: Set-up
  
  # check data has appropriate variable names
  if(isTRUE(("age" %in% colnames(data)) 
            && ("period" %in% colnames(data))
            && ("cohort" %in% colnames(data))) == FALSE)
    stop("apc.error: data missing one of age, period, cohort")
  
  # check datatpe
  datatype.list <- c("AP", "AC rectangular", "CP", "AC triangular", "AP hexag")
  if (!isTRUE(datatype %in% datatype.list))
    stop("datatype not recognised; must be one of 'AP' 'AC rectangular' 'CP' 'AC triangular' 'AP hexag'. ")
  
  # add cell.name
  if (!"cell.name" %in% colnames(data)) {
    cell.name <- paste("ik", as.character(data$age), as.character(data$cohort), sep="_")
    data <- cbind(cell.name, data)
  } else {
    warning("Variable cell.name must be unique identifier of age-cohort cells; if preexisting variable cell.name has alternate meaning please rename")
  }
  
  # get contextual information about data  
  age1 <- min(data$age)
  per1 <- min(data$period)  
  coh1 <- min(data$cohort)
  
  # set dimensionality of data
  I <- as.numeric(length(unique(data$age)))
  J <- as.numeric(length(unique(data$period)))
  K <- as.numeric(length(unique(data$cohort)))
  
  ##################
  # Step 2: create index matrix based on structure of data
  
  if (datatype == "AC rectangular")
  { 
    L=0       
    i.index <- 1:I
    k.index <- 1:K
    i.value.mu <- rep(i.index, each=K)
    k.value.mu <- rep(k.index, I)
    j.value.mu <- i.value.mu + k.value.mu - 1
    mu.index <- as.data.frame(cbind(i.value.mu, j.value.mu, k.value.mu))
  } 
  # AC rectangular
  if (datatype == "AC triangular")
  {
    L=0       
    k.value.mu <- vector(length=(K*(K+1)/2))
    startpoint <- 1
    for(k in 0:(K-1)){
      length <- K-k
      k.value.mu[startpoint:(startpoint+length-1)] <- c(1:(K-k))
      startpoint <- startpoint+length
    }
    i.value.mu <- rep(1:I, seq(K, 1))
    j.value.mu <- i.value.mu + k.value.mu - 1
    mu.index <- as.data.frame(cbind(i.value.mu, j.value.mu, k.value.mu))
  }
  # AC triangular
  if (datatype == "AP")
  {
    L <- I-1  
    i.index <- 1:I
    j.index <- (L+1):(L+J)
    i.value.mu <- rep(i.index, each=J)
    j.value.mu <- rep(j.index, I)
    k.value.mu <- j.value.mu - i.value.mu + 1
    mu.index <- as.data.frame(cbind(i.value.mu, j.value.mu, k.value.mu))
  } 
  # AP
  if (datatype == "CP")
  {
    L=K-1 
    k.index <- 1:K
    j.index <- (L+1):(L+J)
    k.value.mu <- rep(k.index, each=J)
    j.value.mu <- rep(j.index, K)
    i.value.mu <- j.value.mu - k.value.mu + 1
    mu.index <- as.data.frame(cbind(i.value.mu, j.value.mu, k.value.mu))
  } 
  # CP 
  if (datatype == "AP hexag")
  {
    if (n.coh.excl.end==0 & n.coh.excl.start==0) stop("datatype is AP hexag but no cohorts excluded")
    L <- I-1  
    i.index <- 1:I
    j.index <- (L+1):(L+J)
    i.value.mu <- rep(i.index, each=J)
    j.value.mu <- rep(j.index, I)
    k.value.mu <- j.value.mu - i.value.mu + 1
    mu.index <- as.data.frame(cbind(i.value.mu, j.value.mu, k.value.mu))
    
    max.k <- max(k.value.mu)  
    mu.index1 <- mu.index[mu.index$k.value.mu > n.coh.excl.start, ]
    mu.index2 <- mu.index1[mu.index1$k.value.mu <= (max.k - n.coh.excl.end), ]
    mu.index <- mu.index2
  }
  # AP hexag (some early and late cohorts excluded)
  
  stopifnot(exists("L")==TRUE)
  #construct U, the reference point of the linear plane
  U <- as.integer((L+3)/2)
  
  ##################
  # Step 3: create and fill design matrix
  #create space of design matrix
  n.rows <- nrow(mu.index)
  n.param.design <- I+J+K-2 
  design <- matrix(data=0, nrow=n.rows, ncol=n.param.design+3) # extra 3 are for index
  
  #begin by defining L.odd, max.i, max.j, max.k
  L.odd <- !L %% 2 == 0 
  age.max <- I
  coh.max <- K + n.coh.excl.start + n.coh.excl.end 
  per.max <- J
  
  #fill row-by-row
  for (row in 1:n.rows) {
    i <- mu.index[row, 1]
    j <- mu.index[row, 2]
    k <- mu.index[row, 3]
    design[row, 1] <- 1
    design[row, 2] <- i - U
    design[row, 4] <- k - U
    design[row, 3] <- design[row, 2] + design[row, 4]
    
    #age DDs
    if (i < U) 
      design[row, (4 + i):(4 + U - 1)] <- seq(1, U - i)
    if (i > U + 1) 
      design[row, (4 + U):(4 + U + i - U - 2)] <- seq(i - U - 1, 1)
    
    #period DDs
    if (L.odd && j == 2 * (U - 1)) 
      design[row, (2 + age.max + 1)] <- 1
    if (j > 2 * U) 
      design[row, (2 + age.max + L.odd + 
                     1):(2 + age.max + L.odd + j - 2 * U)] <- seq(j - 2 * U, 1)
    
    #cohort DDs
    if (k < U) 
      design[row, (age.max + per.max + k - n.coh.excl.start):(age.max +per.max + U - 1 - n.coh.excl.start)] <- seq(1, U - k)
    if (k > U + 1) 
      design[row, (age.max + per.max + U - n.coh.excl.start):(age.max + 
                                                                per.max + U + k - U - 2 - n.coh.excl.start)] <- seq(k - U - 1, 1)
    
    #index
    design[row, n.param.design+1] <- i
    design[row, n.param.design+2] <- j
    design[row, n.param.design+3] <- k
  }
  
  designdf <- as.data.frame(design)
  
  # assign names to variables in design dataframe
  firstfour <- c("level", "age slope", "period slope", "cohort slope")
  age.names <- paste("DD_age", (age1+2):(age1+2+I-2-1), sep="_")
  per.names <- paste("DD_period", (per1+2):(per1+2+J-2-1), sep="_")
  coh.names <- paste("DD_cohort", (coh1+2):(coh1+2+K-2-1), sep="_")
  index <- c("i.value", "j.value", "k.value")
  colnames(designdf) <- c(firstfour, age.names, per.names, coh.names, index)
  
  ##################
  # Step 4: join design matrix with full dataset based on ijk index values
  
  # define adjustments between apc and ijk
  age.adjustment <- max(data$age) - max(mu.index$i.value.mu)
  period.adjustment <- max(data$period) - max(mu.index$j.value.mu)
  cohort.adjustment <- max(data$cohort) - max(mu.index$k.value.mu)
  
  # redefine these vectors to be length of data rather than mu.index
  i.value <- data$age - age.adjustment
  j.value <- data$period - period.adjustment
  k.value <- data$cohort - cohort.adjustment
  
  ijk.data <- as.data.frame(cbind(data, i.value, j.value, k.value))
  
  # associates APC design matrix with each individual datapoint as needed
  data.with.design <- join(ijk.data, designdf, by=c("i.value", "j.value", "k.value"))
  
  # drop information that is redundant in future commands
  exclude.all <- c("X", "indiv.ID", "age", "period", "cohort", "i.value", "j.value", "k.value")
  first.exclusion <- names(data.with.design) %in% c(exclude.all)
  full.design.collinear <- data.with.design[!first.exclusion]
  
  # check join was successful
  if (anyNA(full.design.collinear)) stop("NA in design matrix, check datatype or n.coh.excl")
  
  ##################
  # Return valuables
  valuables <- list(structure.design.collinear = designdf, 
                    full.design.collinear = full.design.collinear, 
                    unit = unit,
                    age1 = age1,
                    per1 = per1,
                    coh1 = coh1,
                    age.max = age.max,
                    per.max = per.max,
                    coh.max = coh.max,
                    per.zero = L,
                    per.odd = L.odd,
                    U = U)
  
  return (valuables)
}


##### write apc.indiv.design.model #####
apc.indiv.design.model <- function(apc.indiv.design.collinear, model.design = "APC",
                                       dep.var = NULL, covariates = NULL){
  ##################
  # This function reduces the collinear design matrix to the design matrix for the desired model
  ##################
  # Step 1: set-up
  # check model design
  design.list <- c("APC", "AP", "AC", "PC", "Ad", "Pd", "Cd", "A", "P", "C", "t", "tA", "tP", "tC", "1")
  if (!isTRUE(model.design %in% design.list))
    stop("model.design not recognised")
  
  # Extract elements from apc.indiv.design.collinear
  structure.design.collinear <- apc.indiv.design.collinear$structure.design.collinear 
  full.design.collinear <- apc.indiv.design.collinear$full.design.collinear
  
  set.coh.DDs <- colnames(structure.design.collinear)[grep("^DD_cohort_", colnames(structure.design.collinear))]
  set.age.DDs <- colnames(structure.design.collinear)[grep("^DD_age_", colnames(structure.design.collinear))]
  set.per.DDs <- colnames(structure.design.collinear)[grep("^DD_period_", colnames(structure.design.collinear))]
  ##################
  # Step 2: Select model inclusions
  if(model.design=="APC")	{	slopes <- c(1,0,1); difdif <- c(1,1,1);	}
  if(model.design=="AP" )	{	slopes <- c(1,0,1); difdif <- c(1,1,0);	}
  if(model.design=="AC" )	{	slopes <- c(1,0,1); difdif <- c(1,0,1);	}
  if(model.design=="PC" )	{	slopes <- c(1,0,1); difdif <- c(0,1,1);	}
  if(model.design=="Ad" )	{	slopes <- c(1,0,1); difdif <- c(1,0,0);	}
  if(model.design=="Pd" )	{	slopes <- c(1,0,1); difdif <- c(0,1,0);	}
  if(model.design=="Cd" )	{	slopes <- c(1,0,1); difdif <- c(0,0,1);	}
  if(model.design=="A"  )	{	slopes <- c(1,0,0); difdif <- c(1,0,0);	}
  if(model.design=="P"  )	{	slopes <- c(0,1,0); difdif <- c(0,1,0);	}
  if(model.design=="C"  )	{	slopes <- c(0,0,1); difdif <- c(0,0,1);	}
  if(model.design=="t"  )	{	slopes <- c(1,0,1); difdif <- c(0,0,0);	}
  if(model.design=="tA" )	{	slopes <- c(1,0,0); difdif <- c(0,0,0);	}
  if(model.design=="tP" )	{	slopes <- c(0,1,0); difdif <- c(0,0,0);	}
  if(model.design=="tC" )	{	slopes <- c(0,0,1); difdif <- c(0,0,0);	}
  if(model.design=="1"  )	{	slopes <- c(0,0,0); difdif <- c(0,0,0);	}
  
  incl <- vector(mode="character")
  incl <- c(incl, "level")
  if (slopes[1]) {incl <- c(incl, "age slope")}
  if (slopes[2]) {incl <- c(incl, "period slope")}
  if (slopes[3]) {incl <- c(incl, "cohort slope")}
  if (difdif[1]) {incl <- c(incl, set.age.DDs)}
  if (difdif[2]) {incl <- c(incl, set.per.DDs)}
  if (difdif[3]) {incl <- c(incl, set.coh.DDs)}
  
  full.inclusion <- names(full.design.collinear) %in% c(incl, covariates)
  final.design <- full.design.collinear[full.inclusion]
  
  # warn if no DV specification. No stop because can introduce DV in fit stage
  if (is.null(dep.var)){
    warning("Dependent variable unspecified")
    DV <- dep.var   # ie assign NULL
  } else DV <- full.design.collinear[dep.var]
  ##################
  # Return valuables
  valuables <- list(full.design = final.design,
                    DV = DV,
                    slopes = slopes,
                    difdif = difdif,
                    xi.dim = length(incl),
                    model.design = model.design,
                    
                    unit = apc.indiv.design.collinear$unit,
                    age1 = apc.indiv.design.collinear$age1,
                    per1 = apc.indiv.design.collinear$per1,
                    coh1 = apc.indiv.design.collinear$coh1,
                    age.max = apc.indiv.design.collinear$age.max,
                    per.max = apc.indiv.design.collinear$per.max,
                    coh.max = apc.indiv.design.collinear$coh.max,
                    per.zero = apc.indiv.design.collinear$per.zero,
                    per.odd = apc.indiv.design.collinear$per.odd,
                    U = apc.indiv.design.collinear$U)
  return(valuables)
}


##### write apc.indiv.fit.model #####
apc.indiv.fit.model <- function (apc.indiv.design.model, model.family=NULL, n.coh.excl.start = 0, n.coh.excl.end = 0, DV=NULL){
  ##################
  # This function estimates the model developed in apc.indiv.design.model
  ##################
  # Step 1: Set up
  # Check model.design
  family.list <- c("gaussian", "binomial")
  if (!isTRUE(model.family %in% family.list))
    stop("model.family must be either 'gaussian' or 'binomial'")
  
  # Extract elements from apc.indiv.design.model
  design <- apc.indiv.design.model$full.design
  if(is.null(DV)) {
    DV <- apc.indiv.design.model$DV}
  xi.dim1 <- apc.indiv.design.model$xi.dim
  model.design <- apc.indiv.design.model$model.design
  
  difdif <- apc.indiv.design.model$difdif
  slopes <- apc.indiv.design.model$slopes
  age.max <- apc.indiv.design.model$age.max
  per.max <- apc.indiv.design.model$per.max
  coh.max <- apc.indiv.design.model$coh.max
  age1 <- apc.indiv.design.model$age1
  per1 <- apc.indiv.design.model$per1
  coh1 <- apc.indiv.design.model$coh1
  unit <- apc.indiv.design.model$unit
  
  if (is.null(DV)) stop("Dependent variable unspecified")
  ##################
  # Step 2: Estimation
  # Regression using glm.fit
  if (model.family == "binomial")
    fit <- glm.fit(design, DV[, 1], family=binomial())
  if (model.family == "gaussian")
    fit <- glm.fit(design, DV[, 1], family=gaussian())
  
  # Extract coefficients and covariance
  coefficients	<- summary.glm(fit)$coefficients
  covariance	<- summary.glm(fit)$cov.scaled
  
  n.coeff <- length(coefficients[, 1])
  n.coeff.canonical <- xi.dim1
  
  # Manipulate coefficients and covariance based on model design
  # First case: model design is 1
  if (model.design == "1"){
    coefficients.canonical	<- t(coefficients[(n.coeff-n.coeff.canonical+1):n.coeff, ])
    covariance.canonical	<- summary.glm(fit)$cov.scaled[(n.coeff-n.coeff.canonical+1):n.coeff, 
                                                        (n.coeff-n.coeff.canonical+1):n.coeff]  
    
    coefficients.covariates <- t(coefficients[1:(n.coeff-n.coeff.canonical), ])
    
    #	get standard errors 
    coefficients.canonical[,2]	<- sqrt(covariance.canonical)
    #	get t-statistics
    coefficients.canonical[,3]	<- coefficients.canonical[,1] 	/ coefficients.canonical[,2]
    #	get p-values
    coefficients.canonical[,4]	<- 2*pnorm(abs(coefficients.canonical[  ,3]),lower.tail=FALSE)
  }
  # Second case: model design is not 1
  if (!model.design == "1"){
    coefficients.canonical	<- summary.glm(fit)$coefficients[(n.coeff-n.coeff.canonical+1):n.coeff, ]
    covariance.canonical	<- summary.glm(fit)$cov.scaled[(n.coeff-n.coeff.canonical+1):n.coeff, 
                                                        (n.coeff-n.coeff.canonical+1):n.coeff]  
    
    coefficients.covariates <- coefficients[1:(n.coeff-n.coeff.canonical), ]
    
    #	get standard errors 
    coefficients.canonical[,2]	<- sqrt(diag(covariance.canonical))
    #	get t-statistics
    coefficients.canonical[,3]	<- coefficients.canonical[,1] 	/ coefficients.canonical[,2]
    #	get p-values
    coefficients.canonical[,4]	<- 2*pnorm(abs(coefficients.canonical[  ,3]),lower.tail=FALSE)
  }
  ##################
  # Step 3: Use output thus far to get dates for use in plotting later 

  index.age	<- NULL
  index.per	<- NULL
  index.coh	<- NULL
  
  # redefine coh.max 
  coh.max.from.earlier <- coh.max
  coh.max <- coh.max.from.earlier - n.coh.excl.start - n.coh.excl.end
  
  # changes to index based on max
  start		<- 1+sum(slopes)
  if(difdif[1])	{	index.age	<- start+seq(1,age.max-2);	start	<- start+age.max-2	}
  if(difdif[2])	{	index.per	<- start+seq(1,per.max-2);	start	<- start+per.max-2	}
  if(difdif[3])	{	index.coh	<- start+seq(1,coh.max-2);	start	<- start+coh.max-2	}
  xi.dim2		<- start
  # use index, max, unit, xi.dim2, difdif to get dates
  dates		<- matrix(data=NA,nrow=xi.dim2,ncol=1)			
  if(difdif[1])	dates[index.age,1]	<- age1+seq(2,age.max-1)*unit	
  if(difdif[2])	dates[index.per,1]	<- per1+seq(2,per.max-1)*unit
  if(difdif[3])	dates[index.coh,1]	<- coh1+seq(2,coh.max-1)*unit
  ##################
  # Construct likelihood
  trueRSS <- sum(fit$residuals^2)
  N <- length(fit$residuals)
  lik <- -(N/2)*log(2*pi*trueRSS/N) - (N/2)
  # Return valuables
  valuables <- c(fit, list(coefficients.canonical = coefficients.canonical,
                           covariance.canonical = covariance.canonical,
                           dates = dates,
                           index.age = index.age,
                           index.coh = index.coh,
                           index.per = index.per,
                           
                           coefficients.covariates = coefficients.covariates, 
                           
                           model.family = model.family,
                           
                           difdif = difdif,
                           slopes = slopes,
                           age1 = age1,
                           per1 = per1,
                           coh1 = coh1,
                           unit = unit,
                           age.max = age.max,
                           per.max = per.max,
                           coh.max = coh.max,
                           
                           model.design = apc.indiv.design.model$model.design,
                           per.zero = apc.indiv.design.model$per.zero,
                           per.odd = apc.indiv.design.model$per.odd,
                           U = apc.indiv.design.model$U,
                           
                           likelihood = lik))
  return(valuables)
}


##### write apc.indiv.ftest.fullapc #####
apc.indiv.ftest.fullapc <- function(data, datatype, model.design="APC", reduced.model.design,
                                    dep.var, covariates=NULL, model.family="gaussian", unit=1, 
                                    n.coh.excl.start=0, n.coh.excl.end=0,
                                    existing.apc.indiv.fit.model=NULL, existing.apcreduced.fit.indiv=NULL,
                                    existing.collinear=NULL){
  ######################	
  # This functions runs an F-test comparing the fit of a single APC submodel to the full APC model.
  ######################	
  # Step 1: Fit reduced APC model (the submodel)
  
  if(is.null(existing.apcreduced.fit.indiv)){
    if(is.null(existing.collinear)){
      collinear.R <- apc.indiv.design.collinear(data, datatype=datatype, unit = unit,
                                                    n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end)
    } else
      collinear.R <- existing.collinear
    design.R <- apc.indiv.design.model(apc.indiv.design.collinear = collinear.R, 
                                           model.design = reduced.model.design, dep.var=dep.var,
                                           covariates=covariates)
    fitted.R <- apc.indiv.fit.model(design.R, model.family=model.family, n.coh.excl.start = n.coh.excl.start,
                              n.coh.excl.end = n.coh.excl.end)
  } else 
    fitted.R <- existing.apcreduced.fit.indiv
  
  # Get RSS, number of parameters
  RSS.APC.R <- sum(fitted.R$residuals^2)
  nparam.APC.R <- length(fitted.R$coefficients)
  ######################	
  # Step 2: Fit full APC model
  if(is.null(existing.apc.indiv.fit.model)){
    # note: can use same collinear design matrix for full model as for submodel
    design.U <- apc.indiv.design.model(apc.indiv.design.collinear = collinear.R, 
                                           model.design = model.design, dep.var=dep.var,
                                           covariates=covariates)
    fitted.U <- apc.indiv.fit.model(design.U, model.family=model.family, n.coh.excl.start = n.coh.excl.start,
                              n.coh.excl.end = n.coh.excl.end)
  } else 
    fitted.U <- existing.apc.indiv.fit.model
  
  # Get RSS, number of parameters, number of observations
  RSS.APC.U <- sum(fitted.U$residuals^2)
  nparam.APC.U <- length(fitted.U$coefficients)
  sample.N.APC.U <- length(fitted.U$y)
  ######################	
  # Step 3: Run F-test
  
  # Get elements of F-test
  big.model.RSS <- RSS.APC.U
  small.model.RSS <- RSS.APC.R
  big.model.nparams <- nparam.APC.U
  small.model.nparams <- nparam.APC.R
  sample.N <- sample.N.APC.U
  
  df.num <- big.model.nparams - small.model.nparams
  df.denom <- sample.N - big.model.nparams
  df <- paste("(", paste(as.character(df.num), as.character(df.denom), sep=", "), ")", sep="")
  
  # Construct F-statistic
  fstat.num <- (small.model.RSS - big.model.RSS)/df.num
  fstat.denom <- (big.model.RSS - 0)/df.denom
  fstat <- fstat.num/fstat.denom
  
  # Get p-value by comparing F-statistic to F-distribution
  p.value <- pf(fstat, df1 = df.num, df2 = df.denom, lower.tail = FALSE)
  ######################	
  # valuables
  valuables <- list(fstat = fstat,
                    df = df,
                    df.num = df.num,
                    df.denom = df.denom,
                    p.value = p.value,
                    aic.U = fitted.U$aic,
                    aic.R = fitted.R$aic,
                    lik.U = fitted.U$likelihood,
                    lik.R = fitted.R$likelihood)
  return(valuables)
}


##### write var.apc.plot.fit ####
var.apc.plot.fit	<- function(apc.fit.model,scale=FALSE,sdv.at.zero=TRUE,type="detrend",sub.plot=NULL,main.outer=NULL,
                              main.sub=NULL,cex=NULL,cex.axis=NULL, cex.main=2, mgp=c(2, 1, 0), theight=1, 
                              mar=c(4, 3, 2, 0), oma = c(0, 0, 5, 1), title.pos=NA)
{
  ##################
  # This fuction is based on apc.plot.fit from package 'apc', with a few alterations to visuals
  ##################
  #	change type
  if(type=="ss.dd")	type<-"sum.sum"
  #################
  #	get values from fit
  coefficients.canonical	<- apc.fit.model$coefficients.canonical	
  slopes					<- apc.fit.model$slopes					
  difdif					<- apc.fit.model$difdif					
  index.age				<- apc.fit.model$index.age 				
  index.per				<- apc.fit.model$index.per 				
  index.coh				<- apc.fit.model$index.coh 				
  dates					<- apc.fit.model$dates
  model.design			<- apc.fit.model$model.design
  model.family			<- apc.fit.model$model.family
  age1					<- apc.fit.model$age1
  per1					<- apc.fit.model$per1
  coh1					<- apc.fit.model$coh1
  unit					<- apc.fit.model$unit
  age.max					<- apc.fit.model$age.max
  per.max					<- apc.fit.model$per.max
  coh.max					<- apc.fit.model$coh.max	
  per.odd					<- apc.fit.model$per.odd
  U						<- apc.fit.model$U
  #################
  # 	identify fit
  apc.id	<- apc.identify(apc.fit.model)
  index.age.max			<- apc.id$index.age.max 				
  index.per.max			<- apc.id$index.per.max 				
  index.coh.max			<- apc.id$index.coh.max 				
  dates.max				<- apc.id$dates.max
  index.age.sub	 		<- apc.id$index.age.sub	  		 
  index.per.sub			<- apc.id$index.per.sub	  		 
  index.coh.sub			<- apc.id$index.coh.sub	  		 
  dates.sub				<- apc.id$dates.sub		  		 
  index.age.dif	 		<- apc.id$index.age.dif	 		 
  index.per.dif			<- apc.id$index.per.dif	 		 
  index.coh.dif			<- apc.id$index.coh.dif	 		 
  dates.dif				<- apc.id$dates.dif		 		 
  coefficients.ssdd		<- apc.id$coefficients.ssdd	
  coefficients.detrend	<- apc.id$coefficients.detrend	
  coefficients.demean		<- apc.id$coefficients.demean	
  coefficients.dif		<- apc.id$coefficients.dif		
  ##############################
  #	check model design
  if(isTRUE(type %in% c("dif")))
  {	if(model.design=="APC")
    return(cat("apc.error: differences not identified when model.design is APC.  Type cannot be demean or dif \n"))
    if(model.design %in% c("Ad","Pd","Cd","A","P","C","t","tA","tP","tC","1"))	
      return(cat("apc.error: types demean and dif not implemented for model designs At, Pt, Ct, A, P, C, t, tA, tP, tC, 1 \n"))
  }
  ###########################################
  #	construct ingredients to plot depending on type
  mixed	<- FALSE
  if(model.family=="poisson.response")	mixed	<- TRUE
  ###########################################
  #	declare variables
  v.do.plot		<- vector(length=9)
  l.dates			<- list(a=1,b=1,c=1,d=1,e=1,f=1,g=1,h=1,i=1)
  l.coefficients	<- list(a=1,b=1,c=1,d=1,e=1,f=1,g=1,h=1,i=1)
  v.main.sub		<- vector(length=9) 
  v.xlab			<- vector(length=9)								  
  v.intercept		<- vector(length=9)
  v.tau			<- vector(length=9)
  ###########################################
  #	type is "detrend" or "sum.sum"	
  if(type %in% c("detrend","sum.sum"))
  {	if(type=="detrend")
    main	<- paste("APC canonical parameters & detrended representation","\n","model.design=",model.design, "(1/2 std blue/red)")
  if(type=="sum.sum")
    main	<- paste("APC canonical parameters & standard representation","\n","model.design=",model.design, "(1/2 std blue/red)")	
  ##################
  #	do plot?
  v.do.plot[1:3]	<- difdif	
  v.do.plot[4]	<- isTRUE(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","A","P","t","tA","tP"))
  v.do.plot[5]	<- TRUE
  v.do.plot[6]	<- isTRUE(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","C","t","tC"))
  v.do.plot[7:9]	<- difdif	
  ##################
  #	sub.main
  v.main.sub[1]	<- expression(paste("(a) ",Delta^2,alpha, " (x-axis:age)"))
  v.main.sub[2]	<- expression(paste("(b) ",Delta^2,beta, " (x-axis:period)"))
  v.main.sub[3]	<- expression(paste("(c) ",Delta^2,gamma, " (x-axis:cohort)"))
  if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t","A","tA"))
    v.main.sub[4]	<- "(d)  first linear trend (x-axis:age)"
  if(model.design %in% c("A","tA"))
    v.main.sub[4]	<-"(d)  age linear trend (x-axis:age)"
  if(model.design %in% c("P","tP"))									
    v.main.sub[4]	<- "(d)  period linear trend (x-axis:period)"	
  if(!mixed)
    v.main.sub[5]	<- "(e)  level"
  if(mixed)
    v.main.sub[5]	<- "(e)  aggregate mean"
  if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t"))
    v.main.sub[6]	<- "(f)  second linear trend (x-axis:cohort)"
  if(model.design %in% c("C","tC"))									
    v.main.sub[6]	<- "(f)  cohort linear trend (x-axis:cohort)"
  if(type=="detrend")
  {	v.main.sub[7]	<- expression(paste("(g) detrended ",Sigma^2,Delta^2,alpha, " (x-axis:age)"))
  v.main.sub[8]	<- expression(paste("(h) detrended ",Sigma^2,Delta^2,beta, " (x-axis:period)"))
  v.main.sub[9]	<- expression(paste("(i) detrended ",Sigma^2,Delta^2,gamma, " (x-axis:cohort)"))
  }	
  if(type=="sum.sum")
  {	v.main.sub[7]	<- expression(paste("(g) ",Sigma^2,Delta^2,alpha))
  v.main.sub[8]	<- expression(paste("(h) ",Sigma^2,Delta^2,beta))
  v.main.sub[9]	<- expression(paste("(i) ",Sigma^2,Delta^2,gamma))
  }
  ##################
  #	dates
  l.dates[[1]]	<- dates[index.age,1]
  l.dates[[2]]	<- dates[index.per,1]
  l.dates[[3]]	<- dates[index.coh,1]
  if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t","A","tA"))
    l.dates[[4]]	<- age1+seq(0,age.max-1)*unit
  if(model.design %in% c("P","tP"))									
    l.dates[[4]]	<- per1+seq(0,per.max-1)*unit
  l.dates[[5]]	<- c(0,1)  # matrix(data=c(0,1)		     ,nrow=2	  ,ncol=1)
  l.dates[[6]]	<- coh1+seq(0,coh.max-1)*unit
  l.dates[[7]]	<- dates.max[index.age.max,1]
  l.dates[[8]]	<- dates.max[index.per.max,1]
  l.dates[[9]]	<- dates.max[index.coh.max,1]		
  ##################
  #	coefficients
  l.coefficients[[1]]	<- coefficients.canonical[index.age,]
  l.coefficients[[2]]	<- coefficients.canonical[index.per,]
  l.coefficients[[3]]	<- coefficients.canonical[index.coh,]
  if(type=="detrend")
  {	coefficients.sum.sum	<- coefficients.detrend
  UU	<- 1
  }
  if(type=="sum.sum")
  {	coefficients.sum.sum	<- coefficients.ssdd
  UU <- U
  }
  if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t","A","tA"))
    l.coefficients[[4]]	<- matrix(data=seq(1,age.max)-UU  		,nrow=age.max,ncol=1) %*% coefficients.sum.sum[2,]
  if(model.design %in% c("P","tP"))									
    l.coefficients[[4]]	<- matrix(data=seq(1,per.max)-per.odd-1	,nrow=per.max,ncol=1) %*% coefficients.sum.sum[2,]
  l.coefficients[[5]]		<- matrix(data=c(1,1)		       		,nrow=2	     ,ncol=1) %*% coefficients.sum.sum[1,]
  if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t"))
    l.coefficients[[6]]	<- matrix(data=seq(1,coh.max)-UU 		,nrow=coh.max,ncol=1) %*% coefficients.sum.sum[3,]
  if(model.design %in% c("C","tC"))									
    l.coefficients[[6]]	<- matrix(data=seq(1,coh.max)-UU 	 	,nrow=coh.max,ncol=1) %*% coefficients.sum.sum[2,]		
  l.coefficients[[7]]	<- coefficients.sum.sum[index.age.max,]
  l.coefficients[[8]]	<- coefficients.sum.sum[index.per.max,]
  l.coefficients[[9]]	<- coefficients.sum.sum[index.coh.max,]
  ####################
  #	xlab
  v.xlab[1:3]	<- c("age","period","cohort")
  if(model.design %in% c("APC","AP","AC","PC","Ad","Pd","Cd","t","A","tA"))
    v.xlab[4]	<- "age"
  if(model.design %in% c("P","tP"))									
    v.xlab[4]	<- "period"
  if(!mixed)
    v.xlab[5]	<- "age, period, cohort"
  if(mixed)
    v.xlab[5]		<- ""
  v.xlab[6]	<- "cohort"
  v.xlab[7:9]	<- c("age","period","cohort")
  ####################
  #	intercept
  v.intercept[5]	<- TRUE
  ####################
  #	tau
  if(mixed)
    v.tau[5]	<- TRUE
  } 
  ###########################################
  #	type is "dif"	
  if(type %in% c("dif"))
  {	main	<- paste("Difference parameters & demeaned representation","\n","model.design=",model.design, "(1/2 std blue/red)")
  ##################
  #	do plot?
  v.do.plot[1:3]	<- difdif
  v.do.plot[5]	<- TRUE
  v.do.plot[7:9]	<- difdif
  ##################
  #	sub.main
  v.main.sub[1]	<- expression(paste("(a) ",Delta,alpha))
  v.main.sub[2]	<- expression(paste("(b) ",Delta,beta))
  v.main.sub[3]	<- expression(paste("(c) ",Delta,gamma))
  if(!mixed)	v.main.sub[5]	<- "(e)  level"
  if(mixed)	v.main.sub[5]	<- "(e)  aggregate mean"
  v.main.sub[7]	<- expression(paste("(g) demeaned ",Sigma,Delta,alpha))
  v.main.sub[8]	<- expression(paste("(h) demeaned ",Sigma,Delta,beta))
  v.main.sub[9]	<- expression(paste("(i) demeaned ",Sigma,Delta,gamma))
  ##################
  #	dates
  l.dates[[1]]	<- dates.dif[index.age.dif,1]
  l.dates[[2]]	<- dates.dif[index.per.dif,1]
  l.dates[[3]]	<- dates.dif[index.coh.dif,1]
  l.dates[[5]]	<- c(0,1)  # matrix(data=c(0,1)		     ,nrow=2	  ,ncol=1)
  l.dates[[7]]	<- dates.sub[index.age.sub,1]
  l.dates[[8]]	<- dates.sub[index.per.sub,1]
  l.dates[[9]]	<- dates.sub[index.coh.sub,1]		
  ##################
  #	coefficients
  l.coefficients[[1]]	<- coefficients.dif[index.age.dif,]
  l.coefficients[[2]]	<- coefficients.dif[index.per.dif,]
  l.coefficients[[3]]	<- coefficients.dif[index.coh.dif,]
  l.coefficients[[5]]		<- matrix(data=c(1,1)		     ,nrow=2	  ,ncol=1) %*% coefficients.demean[1,]
  l.coefficients[[7]]	<- coefficients.demean[index.age.sub,]
  l.coefficients[[8]]	<- coefficients.demean[index.per.sub,]
  l.coefficients[[9]]	<- coefficients.demean[index.coh.sub,]
  ####################
  #	xlab
  v.xlab[1:3]	<- c("age","period","cohort")
  if(!mixed)	v.xlab[5]	<- "age, period, cohort"
  if(mixed) 	v.xlab[5]		<- ""
  v.xlab[7:9]	<- c("age","period","cohort")
  ####################
  #	intercept
  v.intercept[5]	<- TRUE
  ####################
  #	tau
  if(mixed)
    v.tau[5]	<- TRUE
  } 
  #############################################
  #	use arguments of function
  if(is.null(main.outer)==FALSE)
    main	<- main.outer
  if(is.null(main.sub)==FALSE)
    v.main.sub	<- main.sub
  if(scale==1 && model.family=="binomial.dose.response")	scale <- 2	
  #######################################################
  #	Internal function to plot estimates with sdv
  #######################################################   
  function.plot.est.sdv	<- function(dates,coefficients,xlab="",main="",scale=0,sdv.at.zero=FALSE,intercept=FALSE,tau=FALSE,cex=NULL,cex.axis=NULL)
    #	BN 2 Dec 2013
  {	#	function.plot.est.sdv
    #	define function that can move to exponential scale
    function.scale	<- function(x,scale=0)
    {	if(scale==0)	x.scale <- x
    if(scale==1)	x.scale <- exp(x)
    if(scale==2)	x.scale <- exp(x)/(1+exp(x))
    return(x.scale)
    }
    ################
    #	IF MORE THAN ONE OBSERVATION
    if(length(dates)>1)
    {
      ################
      #	get estimates and sdv
      dat	<- as.vector(dates)
      est	<- as.vector(coefficients[,1])
      sdv <- as.vector(coefficients[,2])
      #	get center for sdv	
      sdv0	<- (1-sdv.at.zero)*est		
      ################
      #	set ylim
      y.lower	<- min(0,min(function.scale(est,scale)),max(2*min(function.scale(est,scale)),max(function.scale(sdv0-sdv,scale),na.rm=TRUE)))
      y.upper	<- max(0,max(function.scale(est,scale)),min(2*max(function.scale(est,scale)),min(function.scale(sdv0+sdv,scale),na.rm=TRUE)))
      if(max(est)-min(est)<min(sdv,na.rm=TRUE)/2)
        cat("apc.plot.fit warning: sdv large in for plot",i,"- possibly not plotted\n")
      ################
      
      #	plot
      plot(dat,function.scale(est,scale),type="l",ann=FALSE, axes=FALSE,ylim=c(y.lower,y.upper),cex.axis=cex.axis)
      #if(intercept == FALSE) mtext(side = 1, text = xlab, line = mgp[1]  ,cex=cex.axis) 
              # get rid of writing at bottom of subplot
      title(main=list(main, cex=cex), line=theight) 
      if(intercept == FALSE) axis(1, cex.axis=cex.axis, mgp = mgp)
      axis(2, las=2, cex.axis=cex.axis, at=round(c(y.lower, median(c(y.lower, y.upper)), y.upper), 2),
           tck = -.01)   # the rounding value affects display
      box()
      if(tau==FALSE)
      {	lines(dat,function.scale(sdv0+  sdv,scale),lty=2,col="blue" )
        lines(dat,function.scale(sdv0-1*sdv,scale),lty=2,col="blue" )
        lines(dat,function.scale(sdv0+2*sdv,scale),lty=3,col="red",lwd=2)
        lines(dat,function.scale(sdv0-2*sdv,scale),lty=3,col="red",lwd=2)
      }	
      abline(0,0)
    }
    ################
    #	IF ONLY ONE OBSERVATION
    if(length(dates)==1)
    {
      ################
      #	get estimates and sdv
      dat	<- dates
      est	<- coefficients[1]
      sdv <- coefficients[2]
      #	get center for sdv	
      sdv0	<- (1-sdv.at.zero)*est		
      ################
      #	set ylim
      y.lower	<- min(0,min(function.scale(est,scale)),max( 2*min(function.scale(est,scale)),max(function.scale(sdv0-sdv,scale),na.rm=TRUE) ))
      y.upper	<- max(0,max(function.scale(est,scale)),min( 2*max(function.scale(est,scale)),min(function.scale(sdv0-sdv,scale),na.rm=TRUE) ))
      ################
      #	remove tick marks if intercept
      xaxt="s"
      if(intercept==TRUE)	xaxt <- "n"
      #	plot
      plot(dat,function.scale(est,scale),type="p",ann=FALSE, axes=FALSE,xaxt=xaxt,ylim=c(y.lower,y.upper),xlim=c(dat-1,dat+1),pch=19,cex.axis=cex.axis)
      if (intercept == FALSE) mtext(side = 1, text = xlab, line = mgp[1]  ,cex=cex.axis) 
      title(main=list(main, cex=cex), line=theight) 
      if (intercept == FALSE) axis(1, cex.axis=cex.axis, mgp = mgp)
      axis(2, las=2, cex.axis=cex.axis, at=round(c(y.lower, mean(c(y.lower, y.upper)), y.upper), 1))
      if(tau==FALSE)
      {	points(dat,function.scale(sdv0+  sdv,scale),col="blue" )
        points(dat,function.scale(sdv0-1*sdv,scale),col="blue" )
        points(dat,function.scale(sdv0+2*sdv,scale),col="red")
        points(dat,function.scale(sdv0-2*sdv,scale),col="red")
      }
      abline(0,0)
    }	
  }	#	function.plot.est.sdv
  #############################################
  #	plots
  if(is.null(sub.plot)==TRUE)
  {
    par(mfrow=c(3,3)); par(mar=mar,oma=oma);
    if(is.null(cex)==TRUE) 		cex 		<- 1
    if(is.null(cex.axis)==TRUE) cex.axis 	<- 1		
    for(i in 1:9)
    {		
      if(v.do.plot[i]==TRUE)
        function.plot.est.sdv(l.dates[[i]],l.coefficients[[i]],xlab=v.xlab[i],main=v.main.sub[i],intercept=v.intercept[i],tau=v.tau[i],scale=scale,sdv.at.zero=sdv.at.zero,cex=cex,cex.axis=cex.axis)
      else
        frame()
    }		
    title(main=list(main, cex=cex.main), outer=TRUE, line=title.pos)
  }
  else
  {	if(sub.plot=="a")	i <- 1
  if(sub.plot=="b")	i <- 2
  if(sub.plot=="c")	i <- 3
  if(sub.plot=="d")	i <- 4
  if(sub.plot=="e")	i <- 5
  if(sub.plot=="f")	i <- 6
  if(sub.plot=="g")	i <- 7
  if(sub.plot=="h")	i <- 8
  if(sub.plot=="i")	i <- 9
  par(mfrow=c(1,1));	par(mar=c(4,5,3,1),oma=c(0,0,0,0)); cex <- NULL
  main	<- main.sub
  if(is.null(main)==TRUE)	main <- v.main.sub[i]
  if(v.do.plot[i]==TRUE)
    function.plot.est.sdv(l.dates[[i]],l.coefficients[[i]],xlab=v.xlab[i],main=main,scale=scale,sdv.at.zero=sdv.at.zero,cex=cex)
  else
    return(cat("apc.plot.fit error: cannot draw this sub.plot. Check sub.plot is correct \n"))
  }
}	#	var.apc.plot.fit

##### write apc.indiv.estimate.TS #####
apc.indiv.estimate.TS <- function(data, dep.var, covariates=NULL){
  ######################	
  # This function estimates the temporally-saturated model.
  ######################	
  # add cell.name: age-cohort cell identifier (if not already there)
  if (!"cell.name" %in% colnames(data)) {
    cell.name <- paste("ik", as.character(data$age), as.character(data$cohort), sep="_")
    data <- cbind(cell.name, data)
  } else {
    warning("Variable cell.name must be unique identifier of age-cohort cells; if preexisting variable cell.name has alternate meaning please rename")
  }
  
  # get n.group, ie the number of people in each ik (age-cohort) cell.
  # this will be needed to conduct effective regression on X_TS (time effects design matrix)
  get.n.group <- ddply(data, .variables = c("cell.name"), 
                       function(dfr, colnm){length(dfr[,colnm])}, dep.var)
  colnames(get.n.group)[2] <- "n.group"  
  ######################	
  #### Case with covariates (covariates)
  # Essentially a walk-through of multivariate regression.
  if(!is.null(covariates)){
    ######################	
    # Step 1: Effective regression of covariates on X_TS. 
    # Note special property of X_TS that OLS estimator of coefficient of regression of covariates
          # on X_TS (phi) is equivalent to means of ik cells.
    
    part1 <- get.n.group
    # Get sum each covariate value for each ik cell: groupsum.i
    for (i in covariates){
      get.sum.c2 <- ddply(data, .variables = c("cell.name"),
                          function(dfr, colnm){sum(dfr[, colnm])}, i)
      colnames(get.sum.c2)[2] <- paste("groupsum", i, sep=".")
      part1 <- join(part1, get.sum.c2, by="cell.name")
    }
    
    # Use groupsum.i and n.group to get mean of each covariate for each ik cell: groupmean.i
    groupmeans.matrix <- as.data.frame(matrix(nrow=nrow(part1), ncol=length(covariates)))
    for (i in 1:length(covariates)){
      cbar <- as.matrix(part1[, 2+i] / part1[,2]) # this divides each groupsum.i by n.group
      groupmeans.matrix[, i] <- cbar
      colnames(groupmeans.matrix)[i] <- paste("groupmean", covariates[i], sep = ".")
    }
    # These groupmeans are regression coefficients.
    
    # Further, because X_TS is a matrix of unit vectors, the predicted value of the covariate
          # (needed for next step) is the relevant element of the estimated coefficient vector.
  
    part2 <- cbind(part1, groupmeans.matrix)
    data.and.first.coeff <- join(data, part2, by="cell.name") # data, n.group, groupmeans.i
    
    # use predicted values of covariate (ie groupmeans.i) to get residuals from regression of 
          # covariate on X_TS. This is performed element-by-element for the full covariate matrix.
    residuals.matrix <- as.data.frame(matrix(nrow=nrow(data.and.first.coeff), ncol=length(covariates)))
    for (i in 1:length(covariates)){
      true <- data.and.first.coeff[covariates[i]]
      predicted.name <- paste("groupmean", covariates[i], sep=".")
      predicted <- data.and.first.coeff[predicted.name]
      resid <- true - predicted
      residuals.matrix[, i] <- resid
      colnames(residuals.matrix)[i] <- paste("resid", covariates[i], sep=".")
    }
    
    data.resid.c.on.x <- cbind(data.and.first.coeff, residuals.matrix) # data, n.group, groupmeans.i, resid.i
    ######################	
    # Step 2: Regression of Y on residuals from regression of C on X_TS. Since this is the covariate
          # matrix with X_TS partialled out, it gives the OLS estimator for the coefficient vector on
          # the covariate matrix in the multivariate regression (here lambda).
    
    stage2.dep.var <- data.resid.c.on.x[dep.var]
    stage2.evar <- residuals.matrix
    stage2.regress <- glm.fit(as.matrix(stage2.evar), as.matrix(stage2.dep.var), family = gaussian())
    truelambdahat <- stage2.regress$coefficients
    ######################	
    # Step 3: Effective regression of Y on X_TS. Since covariates have not been partialled out, this does not
        # give the OLS estimator for the coefficient on X_TS in the multivariate regression. Instead
        # it gives a coefficient vector we call rho. We use the same method for regression on X_TS used in
        # Step 1 above.
    
    # get sum of Y for each ik cell: groupsum.y
    get.sum.y <-  ddply(data.resid.c.on.x, .variables = c("cell.name"), 
                        function(dfr, colnm){sum(dfr[,colnm])}, dep.var)
    colnames(get.sum.y)[2] <- paste("groupsum", dep.var, sep=".")    
    
    # Use groupsum.y and n.group to get mean of Y for each ik cell. By the same logic outlined in step 1 this 
        # is equal to the OLS estimator of the coefficient of the regression of Y on X_TS, rho.
    ysum.and.count <- join(get.n.group, get.sum.y, by="cell.name")
    truerhohat <- ysum.and.count[, 3]/ysum.and.count[, 2] # mean of Y for each ik cell
    yinfo.and.rho <- cbind(ysum.and.count, truerhohat)
    ######################	
    # Step 4: Get OLS estimator of coefficient on X_TS in multivariate model of Y on X_TS and c (kappa) by 
        # combining existing estimators: phi (from step 1), lambda (from step 2), rho (from step 3)
    conformable.lambda <- (as.matrix(as.numeric(truelambdahat)))
    conformable.phi <- as.matrix(groupmeans.matrix)
    phi.times.lambda <- conformable.phi %*% conformable.lambda
    
    truekappahat <- truerhohat - phi.times.lambda
    yinfo.and.kappa <- cbind(yinfo.and.rho, truekappahat)
    data.all.coeffs <- join(data.resid.c.on.x, yinfo.and.kappa, by="cell.name")
    # data, n.group, groupmeans.i, resid.i, groupsum.y, truerhohat, truekappahat
    ######################	
    # Step 5: calculate residuals from multivariate model
    # first method makes use of covariates, lambda, X_TS, and kappa: y.residuals
    predicted.y.from.covariates <- as.matrix(data.all.coeffs[covariates]) %*% as.matrix(truelambdahat)
    y.residuals <- data.all.coeffs[dep.var] - predicted.y.from.covariates - data.all.coeffs["truekappahat"]
    colnames(y.residuals) <- "y.residuals"
    
    # second method makes use of residuals from regression of covariates on X_TS, lambda, X_TS, rho: y.residuals.nokappa
    predicted.y.from.ctilde <- as.matrix(residuals.matrix) %*% as.matrix(truelambdahat)
    y.residuals.nokappa <- data.all.coeffs[dep.var] - predicted.y.from.ctilde - data.all.coeffs["truerhohat"]
    colnames(y.residuals.nokappa) <- "y.residuals.nokappa"
    
    final.data <- cbind(data.all.coeffs, y.residuals, y.residuals.nokappa)
    
  } 
  ######################	
  #### Case without covariates
  else{
    
    # Effective regression of Y on X_TS. Again can use means of Y for each ik cell as OLS estimators
    
    # construct sums of Y for each ik cell
    get.sum.y <-  ddply(data, .variables = c("cell.name"), 
                        function(dfr, colnm){sum(dfr[,colnm])}, dep.var)
    colnames(get.sum.y)[2] <- paste("groupsum", dep.var, sep=".")    
    
    # Construct means of Y for each ik cell, i.e. OLS estimator of rho.
    ysum.and.count <- join(get.n.group, get.sum.y, by="cell.name")
    truerhohat <- ysum.and.count[, 3]/ysum.and.count[, 2]
    yinfo.and.rho <- cbind(ysum.and.count, truerhohat)
  
    data.all.coeffs <- join(data, yinfo.and.rho, by="cell.name")
    
    # Construct residuals from regression of Y on X_TS
    y.residuals <- data.all.coeffs[dep.var] - data.all.coeffs["truerhohat"]
    colnames(y.residuals) <- "y.residuals"
    
    final.data <- cbind(data.all.coeffs, y.residuals)
    
    truelambdahat <- NA
    truekappahat <- NA
  }
  
  ######################
  # Calculate likelihood and AIC
  trueRSS <- sum(final.data["y.residuals"]^2)
  n.coeff <- length(truerhohat) + length(truelambdahat) - is.na(truelambdahat[1]) #because length(NA)=1
  N <- nrow(final.data)
  
  lik <- -(N/2)*log(2*pi*trueRSS/N) - (N/2)
  aic <- -2*lik + 2*(n.coeff + 1)
  
  ######################	
  # Return valuables
  valuables <- list(n.cells = length(unique(final.data$cell.name)),
                    TSS = sum(final.data[dep.var]^2),
                    trueRSS = trueRSS,
                    truelambdahat = truelambdahat,
                    truerhohat = truerhohat,
                    truekappahat= truekappahat,
                    likelihood = lik,
                    aic = aic)
}

##### write apc.indiv.ftest.TS #####
apc.indiv.ftest.TS <- function(data, datatype, model.design="APC", dep.var, covariates=NULL,
                            model.family="gaussian", unit=1, n.coh.excl.start=0, n.coh.excl.end = 0,
                            existing.apc.indiv.fit.model=NULL, existing.TS=NULL, existing.collinear=NULL){
  ######################	
  # This function runs an F-test comparing the fit of a single APC model or submodel to the temporally-saturated model.
  ######################	
  # Step 1: Fit APC model
  
  if(is.null(existing.apc.indiv.fit.model)){
    if(is.null(existing.collinear)){
      collinear <- apc.indiv.design.collinear(data, datatype=datatype, unit = unit,
                                                  n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end)
    } else collinear <- existing.collinear
    design <- apc.indiv.design.model(collinear, model.design = model.design, dep.var=dep.var, covariates=covariates)
    fitted <- apc.indiv.fit.model(design, model.family=model.family, n.coh.excl.start = n.coh.excl.start, 
                            n.coh.excl.end = n.coh.excl.end)
  } else 
    fitted <- existing.apc.indiv.fit.model
  
  # get RSS, number of parameters, number of observations for APC model.
  RSS.APC <- sum(fitted$residuals^2)

  nparam.APC <- length(fitted$coefficients)
  sample.N.APC <- length(fitted$y)
  ######################	
  # Step 2: Fit TS model
  
  if(is.null(existing.TS)){
    dummymodel <- apc.indiv.estimate.TS(data, dep.var = dep.var, covariates = covariates)
  } else
    dummymodel <- existing.TS
  
  # get RSS, number of parameters from TS model.
  RSS.dummy <- dummymodel$trueRSS
  if (!is.na(dummymodel$truelambdahat[1])){
    nparam.dummy <- dummymodel$n.cells+length(dummymodel$truelambdahat)
  } else{
    nparam.dummy <- dummymodel$n.cells
  }
  ######################	
  # step 3: Run F-test
  
  # Elements of F-test
  big.model.RSS <- RSS.dummy
  small.model.RSS <- RSS.APC
  big.model.nparams <- nparam.dummy
  small.model.nparams <- nparam.APC
  sample.N <- sample.N.APC
  
  df.num <- big.model.nparams - small.model.nparams
  df.denom <- sample.N - big.model.nparams
  df <- paste("(", paste(as.character(df.num), as.character(df.denom), sep=", "), ")", sep="")
  
  # Combine elements in F-statistic
  fstat.num <- (small.model.RSS - big.model.RSS)/df.num
  fstat.denom <- (big.model.RSS - 0)/df.denom
  fstat <- fstat.num/fstat.denom
  
  # Get p-value by comparing F-statistic to F-distribution
  p.value <- pf(fstat, df1 = df.num, df2 = df.denom, lower.tail = FALSE)
  ######################	
  # valuables
  valuables <- list(fstat = fstat,
                    df = df,
                    df.num = df.num,
                    df.denom = df.denom,
                    p.value = p.value,
                    aic.APC = fitted$aic,
                    aic.TS = dummymodel$aic,
                    lik.APC = fitted$likelihood,
                    lik.TS = dummymodel$likelihood)
  return(valuables)
}

##### write apc.indiv.Ftable #####
apc.indiv.Ftable <- function(data, datatype, dep.var, covariates=NULL, unit=1, 
                                   n.coh.excl.start=0, n.coh.excl.end=0){
  ######################	
  # This function generates a table comparing all APC submodels to the TS model and the full APC model
      # in terms of an F-test of fit.
  ######################	
  # Step 1: write function that uses output from an F-test against the TS and an F-test against the full
      # APC model to generate a line suitable for the final table.
  get.table.line <- function(ftest1, ftest2, first=FALSE, second=FALSE){
    if(isTRUE(first)) # first line is TS model so aic only
      line <- c(NA, NA, NA, NA, NA, NA, round(ftest1$aic.TS, 3), round(ftest1$lik.TS, 3)) 
    else if(isTRUE(second)) # second line is full APC model so not compared to itself
      line <- c(round(ftest1$fstat, 3), ftest1$df.num, round(ftest1$p.value,3), NA,
                NA, NA, round(ftest1$aic.APC,3), round(ftest1$lik.APC, 3))
    else
      line <- c(round(ftest1$fstat, 3), ftest1$df.num, round(ftest1$p.value,3), round(ftest2$fstat, 3),
                ftest2$df.num, round(ftest2$p.value, 3), round(ftest2$aic.R,3), round(ftest2$lik.R, 3))
    return(line)
  }
  ######################	
  # Step 2: Other setup
  
  # List of submodels to be investigated
  model.design.list	<- c("TS", "APC","AP","AC","PC","Ad","Pd","Cd","A","P","C","t","tA","tP","tC", "1")
  # Empty table
  fit.tab <- matrix(nrow=length(model.design.list),ncol=8,data=NA)
  # Full APC model for comparison
  fullAPCcollinear <- apc.indiv.design.collinear(data, datatype=datatype, unit=unit,
                                                     n.coh.excl.start=n.coh.excl.start, n.coh.excl.end=n.coh.excl.end)
  fullAPCdesign <- apc.indiv.design.model(fullAPCcollinear, dep.var = dep.var, covariates = covariates)
  fullAPCfit <- apc.indiv.fit.model(fullAPCdesign, model.family="gaussian", n.coh.excl.start = n.coh.excl.start,
                              n.coh.excl.end = n.coh.excl.end)
  # TS model for comparison
  TSfit <- apc.indiv.estimate.TS(data, dep.var=dep.var, covariates=covariates)
  ######################	
  # Step 3: Generate table
  
  # First line: TS model
  ftest.full.vs.TS <- apc.indiv.ftest.TS(existing.apc.indiv.fit.model = fullAPCfit, existing.TS = TSfit)
  first.line <- get.table.line(ftest1 = ftest.full.vs.TS, first=TRUE)
  fit.tab[1, 1:8] <- first.line
  # Second line: full APC model
  second.line <- get.table.line(ftest1 = ftest.full.vs.TS, second=TRUE)
  fit.tab[2, 1:8] <- second.line
  # Remaining submodels
  for (i in 3:length(model.design.list)){
    againstTS <- apc.indiv.ftest.TS(data, datatype = datatype, model.design=model.design.list[i],
                                 dep.var = dep.var,covariates = covariates, unit = unit,
                                 n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end,
                                 existing.TS = TSfit, existing.collinear = fullAPCcollinear)
    againstAPC <- apc.indiv.ftest.fullapc(data, datatype=datatype, reduced.model.design = model.design.list[i],
                                          dep.var=dep.var, covariates=covariates, unit = unit, 
                                          n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end,
                                          existing.apc.indiv.fit.model = fullAPCfit, existing.collinear = fullAPCcollinear)
    fit.tab[i, 1:8] <- get.table.line(againstTS, againstAPC)
  }
  # Change table column and row names 
  df.againstTS <- paste("DF ( * , ", as.character(againstTS$df.denom), ")", sep="")
  df.againstAPC <- paste("DF ( * , ", as.character(againstAPC$df.denom), ")", sep="")
  
  table.colnames <- c("F-test vs TS", df.againstTS, "p-value", "F-test vs APC", 
                      df.againstAPC, "p-value", "AIC", "lik")
  
  colnames(fit.tab) <- table.colnames
  rownames(fit.tab) <- model.design.list
  ######################	
  return(fit.tab)
}


# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------
