# -----------------------------------------------------------------------------
# Project: APC modelling and covariates with application to obesity in England
# Script: TS_logit_functions.R
# Date started: 07/05/17
# Last edited: 06/12/18
# Author: Zoe Fannon
# -----------------------------------------------------------------------------
 # Writes the functions used for APC analysis of the logit model. Based on
# canonical parametrization of Kuang, Nielsen, and Nielsen (2008a) referred to 
# as KNN. Draws on 'apc' package.
# List of functions: 
#     apc.indiv.logit.TS: estimates time-saturated (TS) model by iteration
#     apc.indiv.LRtest.TS: compares APC to TS by likelihood ratio test
#     apc.indiv.LRtest.fullapc: compares APC submodel to full APC model
#     apc.indiv.LRtable.TS: compares all APC submodels by LR, AIC
# -----------------------------------------------------------------------------

#### apc.indiv.logit.TS ####
apc.indiv.logit.TS <- function(data, dep.var, covariates, maxit.loop=10, 
                              maxit.linesearch=30, tolerance=.002, init="ols",
                                    inv.tol=NULL, d1.tol=.002){
  ##################
  # This function breaks down the logit estimator step-by-step to exploit the 
  # identity structure of the TS model. Y is the dependent variable, mu the 
  # linear predictor of form mu = kappa*T + lambda*Z where T are the time 
  # dummies and Z are the covariates. 
  ##################  
  
  if(is.null(inv.tol)){
    inv.tol <- .Machine$double.eps
  }  
  
  #### Calculate things that will be used repeatedly ####
  
  ## get Y and Z
  Y <- as.matrix(data[dep.var])
  Z <- as.matrix(data[names(data) %in% covariates])
  
  # Zrange <- apply(Z, 2, range)
  # Zrange <- Zrange[2, ] - Zrange[1, ]
  
  ## get T
  # add cell.name to data: age-cohort cell identifier (if not already there)
  if (!"cell.name" %in% colnames(data)) {
    cell.name <- paste("ik", as.character(data$age), as.character(data$cohort),
                       sep="_")
    data <- cbind(cell.name, data)
  } else {
    warning("Variable cell.name must be unique identifier of age-cohort cells;
            if preexisting variable cell.name has alternate meaning please 
            rename")
  }
  # factor by cell.name
  cell.f <- factor(data$cell.name)
  # create dummies
  T <- model.matrix(~cell.f-1)
  
  ## first element of first derivative
  d1e1_top <- t(T) %*% Y
  d1e1_bot <- t(Z) %*% Y
  
  #### Get initial starting values ####
  
  if (init == "ols"){
    # use estimate.TS once to get estimated kappa and lambda
    initial.TS <- apc.indiv.estimate.TS(data, dep.var = dep.var, 
                                        covariates = covariates)
    kappa <- as.matrix(initial.TS$truekappahat)
    lambda <- as.matrix(initial.TS$truelambdahat) 
  } else if (init == "zero"){
    lambda <- rep(0, ncol(Z)) 
    kappa <- rep(0, ncol(T))
  } else if (init == "custom"){
    lambda <- custom.lambda
    kappa <- custom.kappa
  } else stop("init must be one of 'ols', 'zero', 'custom'")
  
  # set loop iteration counter
  i <- 1
  
  # get Nx1 vector of linear predictors
  mu <- T %*% kappa  + Z %*% lambda
  colnames(mu) <- "mu"
  
  # evaluate the log-likelihood at the estimated values of kappa and lambda: 
  lik <- (t(Y) %*% mu) - sum(log(1+exp(mu)))
  
  # --------------------------
  
  #### The loop ####
  
  while (i <= maxit.loop){
    
    
    ## Step 1: Elements of updating ##
    
    # get Nx1 vector of probabilities
    pi <- exp(mu)/(1+exp(mu))
    colnames(pi) <- "pi"
    
    # get matrix W (diagonal matrix)
    w.element <- pi*(1-pi)
    colnames(w.element) <- "w.element"
    
    ## Step 2: Derivatives ##
    
    ## First
    # second element of first derivative
    d1e2_top <- t(T) %*% pi
    d1e2_bot <- t(Z) %*% pi
    
    # complete first derivative
    d1_top <- d1e1_top - d1e2_top
    d1_bot <- d1e1_bot - d1e2_bot
    
    ## Second
    # use matrices for now but there is an alternative method
    # (see notes 28/03/17 black book)
    
    data.w.pi <- cbind(data, pi, w.element)
    
    # top-left element of second derivative (diagonal matrix)
    get.sum.Welm <- ddply(data.w.pi, .variables = c("cell.name"),
                          function(dfr, colnm){sum(dfr[, colnm])}, "w.element")
    colnames(get.sum.Welm)[2] <- paste("groupsum", "w.element", sep=".")
    
    tl2 <- diag(get.sum.Welm[, 2])
    
    
    # top-right element of second derivative
    WelmZ <- t(t(Z) * as.vector(w.element))
    colnames(WelmZ) <- paste("weighted", colnames(Z), sep=".")
    data.pi.Z <- cbind(data.w.pi, WelmZ)
    
    cell.sums <- as.data.frame(get.sum.Welm)
    
    for (k in colnames(WelmZ)){
      get.sum.cov <- ddply(data.pi.Z, .variables = c("cell.name"),
                           function(dfr, colnm){sum(dfr[, colnm])}, k)
      colnames(get.sum.cov)[2] <- paste("groupsum", k, sep=".")
      cell.sums <- join(cell.sums, get.sum.cov, by="cell.name")
    }
    
    tr2 <- as.matrix(cell.sums[, 3:ncol(cell.sums)])
    
    # bottom-left element of second derivative
    bl2 <- t(tr2)
    
    # bottom-right element of second derivative
    br2 <- t(WelmZ) %*% Z
    
    ## Step 3: Inversion of Second derivative ##
    
    # Invert top-left of second derivative
    inv.tl2 <- solve(tl2, tol=inv.tol)
    
    # Schur complement
    schur <- br2 - bl2 %*% inv.tl2 %*% tr2 
    inv.schur <- solve(schur, tol=inv.tol)
    
    # top-left element of second derivative inverse
    tl2inv <- inv.tl2 + inv.tl2 %*% tr2 %*% inv.schur %*% bl2 %*% inv.tl2
    
    # top-right element of second derivative inverse
    tr2inv <- - inv.tl2 %*% tr2 %*% inv.schur
    
    # bottom-left element of second derivative inverse
    bl2inv <- - inv.schur %*% bl2 %*% inv.tl2
    
    # bottom-right element of second derivative inverse
    br2inv <- inv.schur
    
    
    ## Step 4: Update, including linesearch ##
    # note this can be done in blocks
    
    ## Starting values
    # set linesearch parameter
    linesearch <- 1
    # set linesearch iteration counter
    j <- 1
    
    ## Loop over linesearch
    while (j <= maxit.linesearch){
      # Kappa (TS parameter)
      kappa_update <- tl2inv %*% d1_top + tr2inv %*% d1_bot
      kappa_new <- kappa + linesearch*kappa_update
      
      # Lambda (covariate parameter)
      lambda_update <- bl2inv %*% d1_top + br2inv %*% d1_bot
      lambda_new <- lambda + linesearch*lambda_update
      
      # evaluate the likelihood at new values
      mu_new <- T %*% kappa_new  + Z %*% lambda_new
      lik_new <- (t(Y) %*% mu_new) - sum(log(1+exp(mu_new)))
      
      # compare likelihoods: only to see if need to re-enter linesearch
      if (lik_new - lik < 0){
        # New likelihood is lower, have overstepped. Enter linesearch
        linesearch <- linesearch/2
        j <- j+1
      } else break
    }
    
    ## Update pi and first derivative
    
    # get Nx1 vector of probabilities
    pi_new <- exp(mu_new)/(1+exp(mu_new))
    colnames(pi_new) <- "pi"
    
    # get matrix W (diagonal matrix)
    w.element_new <- pi_new*(1-pi_new)
    colnames(w.element_new) <- "w.element"
    
    # second element of first derivative
    d1e2_top_new <- t(T) %*% pi_new
    d1e2_bot_new <- t(Z) %*% pi_new
    
    # complete first derivative
    d1_top_new <- d1e1_top - d1e2_top_new
    d1_bot_new <- d1e1_bot - d1e2_bot_new
    d1_new <- c(d1_top_new, d1_bot_new)    
    norm.d1 <- norm(as.matrix(d1_new), type="F")
    
    ## Step 5: Compare results of updating ##
    # Case 1: difference exceeds tolerance, update and re-enter loop
    if (lik_new - lik > tolerance){
      kappa <- kappa_new
      lambda <- lambda_new
      mu <- mu_new
      lik <- lik_new
      i <- i+1
      rm(kappa_new, lambda_new, mu_new, lik_new, pi_new, w.element_new,
         d1e2_top_new, d1e2_bot_new, d1_top_new, d1_bot_new)
      result <- "exceed lik tolerance, re-enter loop"
      r2 <- "at likelihood"
    } else if (lik_new - lik < 0){
      # Case 2: old likelihood higher, linesearch unsuccessful, terminate
      print(paste("overstepped and linesearch iteration limit reached,
                  exiting after", i-1, "iterations", sep=" "))
      i <- maxit.loop+4   # sets i too high for loop to continue
      result <- "overstep"
    } else if (lik_new - lik <= tolerance & lik_new - lik >= 0){
      # Case 3: likelihood condition satisfied, check first derivative
      # Case 3a: first derivative condition not satisfied, re-enter loop
      if (norm.d1 > d1.tol){
        kappa <- kappa_new
        lambda <- lambda_new
        mu <- mu_new
        lik <- lik_new
        i <- i+1
        rm(kappa_new, lambda_new, mu_new, lik_new, pi_new, w.element_new,
           d1e2_top_new, d1e2_bot_new, d1_top_new, d1_bot_new)
        result <- "exceed d1 tolerance, re-enter loop"
        r2 <- "at first derivative"
      } 
      # Case 3b: first derivative condition satisfied, terminate
      if (norm.d1 <= d1.tol){
        print(paste("converged after", i, "iterations", sep=" "))
        i <- maxit.loop+4 # sets i too high for loop to continue
        result <- "converge"
      }
    }
    # end of loop
  }
  
  if (i==maxit.loop+1)
    print(paste("max iterations exceeded, did not converge", r2, sep=" "))
  # at this point one ought to use the final values as the estimates and
  # also construct the SE based on these, but in the interests of expedience
  # I don't
  
  variance <- c(diag(tl2), diag(br2))
  std.error <- sqrt(variance)
  
  # --------------------------
  #### Return objects of interest ####
  
  #Define
  param.dimension <- length(kappa)+length(lambda)
  aic <- -2*lik + 2*param.dimension
  
  #Deleted values
  if(!exists("lik_new")) lik_new <- NULL
  if(!exists("kappa_new")) kappa_new <- NULL
  if(!exists("lambda_new")) lambda_new <- NULL
  
  valuables <- list(likelihood = lik,
                    kappa = kappa,
                    lambda = lambda,
                    n.loop.iterations = i-1,
                    n.linesearch.iterations = j-1,
                    new.likelihood = lik_new,
                    new.kappa = kappa_new,
                    new.lambda = lambda_new,
                    param.dimension = param.dimension,
                    aic = aic,
                    std.error = std.error,
                    d1_new = d1_new,
                    norm.d1 = norm.d1,
                    result = result)
  
  return (valuables)
  }

#### apc.indiv.LRtest.TS ####

apc.indiv.LRtest.TS <- function(data, datatype, model.design="APC", dep.var, covariates=NULL,
                                model.family="binomial", unit=1, n.coh.excl.start=0, n.coh.excl.end=0,
                                existing.apc.indiv.fit.model=NULL, existing.TS=NULL, existing.collinear=NULL,
                                maxit.loop.TS=10, maxit.linesearch.TS=30, init.TS="ols"){
  
  ##################
  # This function runs an LR test comparing the APC to the TS model 
  ################## 
  # step 1: fit APC model
  if(is.null(existing.apc.indiv.fit.model)){
    if(is.null(existing.collinear)){
      collinear <- apc.indiv.design.collinear(data, datatype=datatype, unit = unit,
                                              n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end)
    } else collinear <- existing.collinear
    design <- apc.indiv.design.model(collinear, model.design = model.design, dep.var=dep.var, covariates=covariates)
    APC.model <- apc.indiv.fit.model(design, model.family=model.family, n.coh.excl.start = n.coh.excl.start, 
                                     n.coh.excl.end = n.coh.excl.end)
  } else 
    APC.model <- existing.apc.indiv.fit.model
  lik.APC <- -0.5*APC.model$deviance

  ##################   
  # step 2: fit TS model
  if(is.null(existing.TS)){
    TS.model <- apc.indiv.logit.TS(data, dep.var=dep.var, covariates=covariates, maxit.loop = maxit.loop.TS,
                                   maxit.linesearch = maxit.linesearch.TS, init = init.TS)
  } else
    TS.model <- existing.TS

  ##################   
  # step 3: run LR test
  diff.df <- TS.model$param.dimension - length(APC.model$coefficients)
  diff.lik <- lik.APC - TS.model$likelihood
  p.value <- pchisq(-2*diff.lik, df = diff.df, lower.tail = FALSE)
  
  aic.apc <- APC.model$aic
  aic.TS <- TS.model$aic

  ##################   
  # step 4: extract valuables
  valuables <- list(LR = -2*diff.lik,
                    df = diff.df,
                    p.value = p.value,
                    aic.APC = aic.apc,
                    aic.TS = aic.TS,
                    lik.APC = lik.APC,
                    lik.TS = TS.model$likelihood)
  return(valuables)
}

#### apc.indiv.LRtest.fullapc ####

apc.indiv.LRtest.fullapc <- function(data, datatype, model.design="APC", reduced.model.design,
                                     dep.var, covariates=NULL, model.family="binomial", unit=1,
                                     n.coh.excl.start=0, n.coh.excl.end=0, existing.apc.indiv.fit.model=NULL,
                                     existing.apcreduced.fit.indiv=NULL, existing.collinear=NULL){
  ################## 
  # This function runs an LR test to compare an APC submodel to the full APC model
  ################## 
  # step 1: fit reduced model
  
  if(is.null(existing.apcreduced.fit.indiv)){
    if(is.null(existing.collinear)){
      collinear.R <- apc.indiv.design.collinear(data, datatype=datatype, unit = unit,
                                                n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end)
    } else
      collinear.R <- existing.collinear
    design.R <- apc.indiv.design.model(apc.indiv.design.collinear = collinear.R, 
                                       model.design = reduced.model.design, dep.var=dep.var,
                                       covariates=covariates)
    reduced.model <- apc.indiv.fit.model(design.R, model.family=model.family, n.coh.excl.start = n.coh.excl.start,
                                         n.coh.excl.end = n.coh.excl.end)
  } else 
    reduced.model <- existing.apcreduced.fit.indiv
  
  ################## 
  # step 2: fit APC model
  if(is.null(existing.apc.indiv.fit.model)){
    # note: can use same collinear design matrix for full model as for submodel
    design.U <- apc.indiv.design.model(apc.indiv.design.collinear = collinear.R, 
                                       model.design = model.design, dep.var=dep.var,
                                       covariates=covariates)
    APC.model <- apc.indiv.fit.model(design.U, model.family=model.family, n.coh.excl.start = n.coh.excl.start,
                                     n.coh.excl.end = n.coh.excl.end)
  } else 
    APC.model <- existing.apc.indiv.fit.model  
  
  ################## 
  # step 3: run LR test
  lik.reduced <- -0.5*reduced.model$deviance
  lik.APC <- -0.5*APC.model$deviance
  
  diff.df <- length(APC.model$coefficients) - length(reduced.model$coefficients)
  diff.lik <- lik.reduced - lik.APC
  p.value <- pchisq(-2*diff.lik, df=diff.df, lower.tail=FALSE)
  
  aic.reduced <- reduced.model$aic
  
  ################## 
  # step 4: extract valuables
  valuables <- list(LR= -2*diff.lik,
                    df = diff.df,
                    p.value = p.value,
                    aic.reduced = aic.reduced,
                    lik.reduced = lik.reduced,
                    lik.APC = lik.APC)
}

#### apc.indiv.LRtable.TS ####
apc.indiv.LRtable.TS <- function(data, datatype, dep.var, covariates=NULL, unit=1, 
                                 n.coh.excl.start=0, n.coh.excl.end=0, maxit.loop.TS=10,
                                 maxit.linesearch.TS=30, init.TS="ols"){
  ################## 
  # This function generates a table comparing all APC submodels to the TS model and the full APC model
  # in terms of an LR-test of fit. 
  ################## 
  # Step 1: function to write table lines
  get.table.line <- function(LRtest.TS, LRtest.APC, first=FALSE, second=FALSE){
    if(isTRUE(first)) # first line is TS model so not compared to itself/APC submodel
      line <- c(NA, NA, NA, NA, NA, NA, round(LRtest.TS$aic.TS, 3), round(LRtest.TS$lik.TS, 3))
    else if(isTRUE(second)) # second line is full APC model so not compared to itself
      line <- c(round(LRtest.TS$LR, 3), LRtest.TS$df, round(LRtest.TS$p.value, 3), NA,
                NA, NA, round(LRtest.TS$aic.APC, 3), round(LRtest.TS$lik.APC, 3))
    else
      line <- c(round(LRtest.TS$LR, 3), LRtest.TS$df, round(LRtest.TS$p.value, 3), round(LRtest.APC$LR, 3),
                LRtest.APC$df, round(LRtest.APC$p.value, 3), round(LRtest.APC$aic.reduced, 3),
                round(LRtest.APC$lik.reduced, 3))
    return(line)
  }
  ######################	
  # Step 2: other setup
  
  # Submodel list
  model.design.list <- c("TS", "APC", "AP", "AC", "PC", "Ad","Pd", "Cd", "A", "P", "C", "t", "tA", "tP", "tC", "1")
  # Empty table
  fit.tab <- matrix(nrow=length(model.design.list), ncol=8, data=NA)
  # Full APC model for comparison
  fullAPCcollinear <- apc.indiv.design.collinear(data, datatype=datatype, unit=unit, 
                                                 n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end)
  fullAPCdesign <- apc.indiv.design.model(fullAPCcollinear, dep.var = dep.var, covariates = covariates)
  fullAPCfit <- apc.indiv.fit.model(fullAPCdesign, model.family="binomial", n.coh.excl.start = n.coh.excl.start,
                                    n.coh.excl.end = n.coh.excl.end)
  # TS model for comparison
  TSfit <- apc.indiv.logit.TS(data, dep.var=dep.var, covariates=covariates, maxit.loop = maxit.loop.TS,
                              maxit.linesearch = maxit.linesearch.TS, init = init.TS)
  ######################	
  # Step 3: Generate table
  
  # first line, TS model and second line, full APC model
  LRtest.full.vs.TS <- apc.indiv.LRtest.TS(existing.apc.indiv.fit.model = fullAPCfit, existing.TS = TSfit)
  first.line <- get.table.line(LRtest.TS=LRtest.full.vs.TS, first=TRUE)
  second.line <- get.table.line(LRtest.TS=LRtest.full.vs.TS, second=TRUE)
  fit.tab[1, 1:8] <- first.line
  fit.tab[2, 1:8] <- second.line
  # Remaining submodels
  for (i in 3:length(model.design.list)){
    againstTS <- apc.indiv.LRtest.TS(data, datatype = datatype, model.design=model.design.list[i],
                                     dep.var = dep.var,covariates = covariates, unit = unit,
                                     n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end,
                                     existing.TS = TSfit, existing.collinear = fullAPCcollinear)
    againstAPC <- apc.indiv.LRtest.fullapc(data, datatype=datatype, reduced.model.design = model.design.list[i],
                                           dep.var=dep.var, covariates=covariates, unit = unit, 
                                           n.coh.excl.start = n.coh.excl.start, n.coh.excl.end = n.coh.excl.end,
                                           existing.apc.indiv.fit.model = fullAPCfit, existing.collinear = fullAPCcollinear)
    fit.tab[i, 1:8] <- get.table.line(againstTS, againstAPC)
  }
  # Change table column and row names
  
  table.colnames <- c("LR-test vs TS", "df", "p-value", "LR-test vs APC", 
                      "df", "p-value", "AIC", "Loglihood")
  colnames(fit.tab) <- table.colnames
  rownames(fit.tab) <- model.design.list
  ####################
  return(fit.tab)
}

# -----------------------------------------------------------------------------
# -----------------------------------------------------------------------------